Class: NewStoreApi::AddItemItemPrice
- Defined in:
- lib/new_store_api/models/add_item_item_price.rb
Overview
AddItemItemPrice Model.
Instance Attribute Summary collapse
-
#source ⇒ SourceEnum
Price source.
-
#source_id ⇒ String
Price source ID, e.g.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(source = SKIP, source_id = SKIP) ⇒ AddItemItemPrice
constructor
A new instance of AddItemItemPrice.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(source = SKIP, source_id = SKIP) ⇒ AddItemItemPrice
Returns a new instance of AddItemItemPrice.
41 42 43 44 |
# File 'lib/new_store_api/models/add_item_item_price.rb', line 41 def initialize(source = SKIP, source_id = SKIP) @source = source unless source == SKIP @source_id = source_id unless source_id == SKIP end |
Instance Attribute Details
#source ⇒ SourceEnum
Price source
14 15 16 |
# File 'lib/new_store_api/models/add_item_item_price.rb', line 14 def source @source end |
#source_id ⇒ String
Price source ID, e.g. name of pricebook
18 19 20 |
# File 'lib/new_store_api/models/add_item_item_price.rb', line 18 def source_id @source_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/new_store_api/models/add_item_item_price.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. source = hash.key?('source') ? hash['source'] : SKIP source_id = hash.key?('source_id') ? hash['source_id'] : SKIP # Create object from extracted values. AddItemItemPrice.new(source, source_id) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/new_store_api/models/add_item_item_price.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['source'] = 'source' @_hash['source_id'] = 'source_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/new_store_api/models/add_item_item_price.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/new_store_api/models/add_item_item_price.rb', line 29 def self.optionals %w[ source source_id ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
66 67 68 69 |
# File 'lib/new_store_api/models/add_item_item_price.rb', line 66 def inspect class_name = self.class.name.split('::').last "<#{class_name} source: #{@source.inspect}, source_id: #{@source_id.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
60 61 62 63 |
# File 'lib/new_store_api/models/add_item_item_price.rb', line 60 def to_s class_name = self.class.name.split('::').last "<#{class_name} source: #{@source}, source_id: #{@source_id}>" end |