Class: NewStoreApi::AddItemResponseBody
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- NewStoreApi::AddItemResponseBody
- Defined in:
- lib/new_store_api/models/add_item_response_body.rb
Overview
AddItemResponseBody Model.
Instance Attribute Summary collapse
-
#messages ⇒ Array[String]
TODO: Write general description for this method.
-
#warnings ⇒ Array[String]
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(messages = nil, warnings = nil) ⇒ AddItemResponseBody
constructor
A new instance of AddItemResponseBody.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(messages = nil, warnings = nil) ⇒ AddItemResponseBody
Returns a new instance of AddItemResponseBody.
41 42 43 44 |
# File 'lib/new_store_api/models/add_item_response_body.rb', line 41 def initialize( = nil, warnings = nil) @messages = @warnings = warnings end |
Instance Attribute Details
#messages ⇒ Array[String]
TODO: Write general description for this method
14 15 16 |
# File 'lib/new_store_api/models/add_item_response_body.rb', line 14 def @messages end |
#warnings ⇒ Array[String]
TODO: Write general description for this method
18 19 20 |
# File 'lib/new_store_api/models/add_item_response_body.rb', line 18 def warnings @warnings end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/new_store_api/models/add_item_response_body.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. = hash.key?('messages') ? hash['messages'] : nil warnings = hash.key?('warnings') ? hash['warnings'] : nil # Create object from extracted values. AddItemResponseBody.new(, warnings) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/new_store_api/models/add_item_response_body.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['messages'] = 'messages' @_hash['warnings'] = 'warnings' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 37 38 39 |
# File 'lib/new_store_api/models/add_item_response_body.rb', line 34 def self.nullables %w[ messages warnings ] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/new_store_api/models/add_item_response_body.rb', line 29 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
66 67 68 69 |
# File 'lib/new_store_api/models/add_item_response_body.rb', line 66 def inspect class_name = self.class.name.split('::').last "<#{class_name} messages: #{@messages.inspect}, warnings: #{@warnings.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
60 61 62 63 |
# File 'lib/new_store_api/models/add_item_response_body.rb', line 60 def to_s class_name = self.class.name.split('::').last "<#{class_name} messages: #{@messages}, warnings: #{@warnings}>" end |