Class: NewStoreApi::AtpKey

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/new_store_api/models/atp_key.rb

Overview

ATP key is the combination of product id and fulfillment node id.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(fulfillment_node_id = nil, product_id = nil) ⇒ AtpKey

Returns a new instance of AtpKey.



38
39
40
41
# File 'lib/new_store_api/models/atp_key.rb', line 38

def initialize(fulfillment_node_id = nil, product_id = nil)
  @fulfillment_node_id = fulfillment_node_id
  @product_id = product_id
end

Instance Attribute Details

#fulfillment_node_idString

The id of the fulfillment node.

Returns:

  • (String)


14
15
16
# File 'lib/new_store_api/models/atp_key.rb', line 14

def fulfillment_node_id
  @fulfillment_node_id
end

#product_idString

The id of the product.

Returns:

  • (String)


18
19
20
# File 'lib/new_store_api/models/atp_key.rb', line 18

def product_id
  @product_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



44
45
46
47
48
49
50
51
52
53
54
55
# File 'lib/new_store_api/models/atp_key.rb', line 44

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  fulfillment_node_id =
    hash.key?('fulfillment_node_id') ? hash['fulfillment_node_id'] : nil
  product_id = hash.key?('product_id') ? hash['product_id'] : nil

  # Create object from extracted values.
  AtpKey.new(fulfillment_node_id,
             product_id)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/new_store_api/models/atp_key.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['fulfillment_node_id'] = 'fulfillment_node_id'
  @_hash['product_id'] = 'product_id'
  @_hash
end

.nullablesObject

An array for nullable fields



34
35
36
# File 'lib/new_store_api/models/atp_key.rb', line 34

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
# File 'lib/new_store_api/models/atp_key.rb', line 29

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



64
65
66
67
68
# File 'lib/new_store_api/models/atp_key.rb', line 64

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} fulfillment_node_id: #{@fulfillment_node_id.inspect}, product_id:"\
  " #{@product_id.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



58
59
60
61
# File 'lib/new_store_api/models/atp_key.rb', line 58

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} fulfillment_node_id: #{@fulfillment_node_id}, product_id: #{@product_id}>"
end