Class: NewStoreApi::AuditEventList

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/new_store_api/models/audit_event_list.rb

Overview

One page of audit log events, ordered newest first.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(items = nil, next_cursor = SKIP) ⇒ AuditEventList

Returns a new instance of AuditEventList.



41
42
43
44
# File 'lib/new_store_api/models/audit_event_list.rb', line 41

def initialize(items = nil, next_cursor = SKIP)
  @items = items
  @next_cursor = next_cursor unless next_cursor == SKIP
end

Instance Attribute Details

#itemsArray[AuditEvent]

The audit log events in this page, newest first.

Returns:



14
15
16
# File 'lib/new_store_api/models/audit_event_list.rb', line 14

def items
  @items
end

#next_cursorString

Opaque cursor for the next page. Pass it back as the cursor query parameter to continue paging. Absent when the last page has been reached.

Returns:

  • (String)


19
20
21
# File 'lib/new_store_api/models/audit_event_list.rb', line 19

def next_cursor
  @next_cursor
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/new_store_api/models/audit_event_list.rb', line 47

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  items = nil
  unless hash['items'].nil?
    items = []
    hash['items'].each do |structure|
      items << (AuditEvent.from_hash(structure) if structure)
    end
  end

  items = nil unless hash.key?('items')
  next_cursor = hash.key?('next_cursor') ? hash['next_cursor'] : SKIP

  # Create object from extracted values.
  AuditEventList.new(items,
                     next_cursor)
end

.namesObject

A mapping from model property names to API property names.



22
23
24
25
26
27
# File 'lib/new_store_api/models/audit_event_list.rb', line 22

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['items'] = 'items'
  @_hash['next_cursor'] = 'next_cursor'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/new_store_api/models/audit_event_list.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



30
31
32
33
34
# File 'lib/new_store_api/models/audit_event_list.rb', line 30

def self.optionals
  %w[
    next_cursor
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



75
76
77
78
# File 'lib/new_store_api/models/audit_event_list.rb', line 75

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} items: #{@items.inspect}, next_cursor: #{@next_cursor.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



69
70
71
72
# File 'lib/new_store_api/models/audit_event_list.rb', line 69

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} items: #{@items}, next_cursor: #{@next_cursor}>"
end