Class: NewStoreApi::AvailabilityRow
- Defined in:
- lib/new_store_api/models/availability_row.rb
Overview
ATP row for a product at a location.
Instance Attribute Summary collapse
-
#fulfillment_node_id ⇒ String
Location that holds the available quantity.
-
#product_id ⇒ String
Catalog product identifier for the availability row.
-
#quantity ⇒ Integer
Available quantity at the location for the product.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(fulfillment_node_id = nil, product_id = nil, quantity = nil) ⇒ AvailabilityRow
constructor
A new instance of AvailabilityRow.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(fulfillment_node_id = nil, product_id = nil, quantity = nil) ⇒ AvailabilityRow
Returns a new instance of AvailabilityRow.
43 44 45 46 47 |
# File 'lib/new_store_api/models/availability_row.rb', line 43 def initialize(fulfillment_node_id = nil, product_id = nil, quantity = nil) @fulfillment_node_id = fulfillment_node_id @product_id = product_id @quantity = quantity end |
Instance Attribute Details
#fulfillment_node_id ⇒ String
Location that holds the available quantity.
14 15 16 |
# File 'lib/new_store_api/models/availability_row.rb', line 14 def fulfillment_node_id @fulfillment_node_id end |
#product_id ⇒ String
Catalog product identifier for the availability row.
18 19 20 |
# File 'lib/new_store_api/models/availability_row.rb', line 18 def product_id @product_id end |
#quantity ⇒ Integer
Available quantity at the location for the product.
22 23 24 |
# File 'lib/new_store_api/models/availability_row.rb', line 22 def quantity @quantity end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/new_store_api/models/availability_row.rb', line 50 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. fulfillment_node_id = hash.key?('fulfillment_node_id') ? hash['fulfillment_node_id'] : nil product_id = hash.key?('product_id') ? hash['product_id'] : nil quantity = hash.key?('quantity') ? hash['quantity'] : nil # Create object from extracted values. AvailabilityRow.new(fulfillment_node_id, product_id, quantity) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/new_store_api/models/availability_row.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['fulfillment_node_id'] = 'fulfillment_node_id' @_hash['product_id'] = 'product_id' @_hash['quantity'] = 'quantity' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/new_store_api/models/availability_row.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/new_store_api/models/availability_row.rb', line 34 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
73 74 75 76 77 |
# File 'lib/new_store_api/models/availability_row.rb', line 73 def inspect class_name = self.class.name.split('::').last "<#{class_name} fulfillment_node_id: #{@fulfillment_node_id.inspect}, product_id:"\ " #{@product_id.inspect}, quantity: #{@quantity.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
66 67 68 69 70 |
# File 'lib/new_store_api/models/availability_row.rb', line 66 def to_s class_name = self.class.name.split('::').last "<#{class_name} fulfillment_node_id: #{@fulfillment_node_id}, product_id: #{@product_id},"\ " quantity: #{@quantity}>" end |