Class: NewStoreApi::BillingAddress

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/new_store_api/models/billing_address.rb

Overview

The consumer's billing address for the returned order. As billing address is optional for an order, this field is set to null when the order doesn't have an explicit billing address set.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(name = nil) ⇒ BillingAddress

Returns a new instance of BillingAddress.



35
36
37
# File 'lib/new_store_api/models/billing_address.rb', line 35

def initialize(name = nil)
  @name = name
end

Instance Attribute Details

#nameString

TODO: Write general description for this method

Returns:

  • (String)


16
17
18
# File 'lib/new_store_api/models/billing_address.rb', line 16

def name
  @name
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



40
41
42
43
44
45
46
47
48
# File 'lib/new_store_api/models/billing_address.rb', line 40

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  name = hash.key?('name') ? hash['name'] : nil

  # Create object from extracted values.
  BillingAddress.new(name)
end

.namesObject

A mapping from model property names to API property names.



19
20
21
22
23
# File 'lib/new_store_api/models/billing_address.rb', line 19

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['name'] = 'name'
  @_hash
end

.nullablesObject

An array for nullable fields



31
32
33
# File 'lib/new_store_api/models/billing_address.rb', line 31

def self.nullables
  []
end

.optionalsObject

An array for optional fields



26
27
28
# File 'lib/new_store_api/models/billing_address.rb', line 26

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



57
58
59
60
# File 'lib/new_store_api/models/billing_address.rb', line 57

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} name: #{@name.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



51
52
53
54
# File 'lib/new_store_api/models/billing_address.rb', line 51

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} name: #{@name}>"
end