Class: NewStoreApi::BulkProfileLookupResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- NewStoreApi::BulkProfileLookupResponse
- Defined in:
- lib/new_store_api/models/bulk_profile_lookup_response.rb
Overview
BulkProfileLookupResponse Model.
Instance Attribute Summary collapse
-
#email ⇒ String
Email of the customer.
-
#id ⇒ String
The profile identifier.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(email = nil, id = nil) ⇒ BulkProfileLookupResponse
constructor
A new instance of BulkProfileLookupResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(email = nil, id = nil) ⇒ BulkProfileLookupResponse
Returns a new instance of BulkProfileLookupResponse.
38 39 40 41 |
# File 'lib/new_store_api/models/bulk_profile_lookup_response.rb', line 38 def initialize(email = nil, id = nil) @email = email @id = id end |
Instance Attribute Details
#email ⇒ String
Email of the customer.
14 15 16 |
# File 'lib/new_store_api/models/bulk_profile_lookup_response.rb', line 14 def email @email end |
#id ⇒ String
The profile identifier.
18 19 20 |
# File 'lib/new_store_api/models/bulk_profile_lookup_response.rb', line 18 def id @id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/new_store_api/models/bulk_profile_lookup_response.rb', line 44 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. email = hash.key?('email') ? hash['email'] : nil id = hash.key?('id') ? hash['id'] : nil # Create object from extracted values. BulkProfileLookupResponse.new(email, id) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/new_store_api/models/bulk_profile_lookup_response.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['email'] = 'email' @_hash['id'] = 'id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/new_store_api/models/bulk_profile_lookup_response.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/new_store_api/models/bulk_profile_lookup_response.rb', line 29 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
63 64 65 66 |
# File 'lib/new_store_api/models/bulk_profile_lookup_response.rb', line 63 def inspect class_name = self.class.name.split('::').last "<#{class_name} email: #{@email.inspect}, id: #{@id.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
57 58 59 60 |
# File 'lib/new_store_api/models/bulk_profile_lookup_response.rb', line 57 def to_s class_name = self.class.name.split('::').last "<#{class_name} email: #{@email}, id: #{@id}>" end |