Class: NewStoreApi::CartLinks
- Defined in:
- lib/new_store_api/models/cart_links.rb
Overview
CartLinks Model.
Instance Attribute Summary collapse
-
#add_item ⇒ Link
TODO: Write general description for this method.
-
#change_cart ⇒ Link
TODO: Write general description for this method.
-
#items ⇒ Link
TODO: Write general description for this method.
-
#mself ⇒ Link
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(items = nil, mself = nil, add_item = SKIP, change_cart = SKIP) ⇒ CartLinks
constructor
A new instance of CartLinks.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(items = nil, mself = nil, add_item = SKIP, change_cart = SKIP) ⇒ CartLinks
Returns a new instance of CartLinks.
51 52 53 54 55 56 57 |
# File 'lib/new_store_api/models/cart_links.rb', line 51 def initialize(items = nil, mself = nil, add_item = SKIP, change_cart = SKIP) @add_item = add_item unless add_item == SKIP @change_cart = change_cart unless change_cart == SKIP @items = items @mself = mself end |
Instance Attribute Details
#add_item ⇒ Link
TODO: Write general description for this method
14 15 16 |
# File 'lib/new_store_api/models/cart_links.rb', line 14 def add_item @add_item end |
#change_cart ⇒ Link
TODO: Write general description for this method
18 19 20 |
# File 'lib/new_store_api/models/cart_links.rb', line 18 def change_cart @change_cart end |
#items ⇒ Link
TODO: Write general description for this method
22 23 24 |
# File 'lib/new_store_api/models/cart_links.rb', line 22 def items @items end |
#mself ⇒ Link
TODO: Write general description for this method
26 27 28 |
# File 'lib/new_store_api/models/cart_links.rb', line 26 def mself @mself end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/new_store_api/models/cart_links.rb', line 60 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. items = Link.from_hash(hash['items']) if hash['items'] mself = Link.from_hash(hash['self']) if hash['self'] add_item = Link.from_hash(hash['add_item']) if hash['add_item'] change_cart = Link.from_hash(hash['change_cart']) if hash['change_cart'] # Create object from extracted values. CartLinks.new(items, mself, add_item, change_cart) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/new_store_api/models/cart_links.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['add_item'] = 'add_item' @_hash['change_cart'] = 'change_cart' @_hash['items'] = 'items' @_hash['mself'] = 'self' @_hash end |
.nullables ⇒ Object
An array for nullable fields
47 48 49 |
# File 'lib/new_store_api/models/cart_links.rb', line 47 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 42 43 44 |
# File 'lib/new_store_api/models/cart_links.rb', line 39 def self.optionals %w[ add_item change_cart ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
84 85 86 87 88 |
# File 'lib/new_store_api/models/cart_links.rb', line 84 def inspect class_name = self.class.name.split('::').last "<#{class_name} add_item: #{@add_item.inspect}, change_cart: #{@change_cart.inspect},"\ " items: #{@items.inspect}, mself: #{@mself.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
77 78 79 80 81 |
# File 'lib/new_store_api/models/cart_links.rb', line 77 def to_s class_name = self.class.name.split('::').last "<#{class_name} add_item: #{@add_item}, change_cart: #{@change_cart}, items: #{@items},"\ " mself: #{@mself}>" end |