Class: NewStoreApi::CashboxReleaseV1Dto

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/new_store_api/models/cashbox_release_v1_dto.rb

Overview

CashboxReleaseV1Dto Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(acknowledge_fiscal_printer_reset = nil) ⇒ CashboxReleaseV1Dto

Returns a new instance of CashboxReleaseV1Dto.



38
39
40
# File 'lib/new_store_api/models/cashbox_release_v1_dto.rb', line 38

def initialize(acknowledge_fiscal_printer_reset = nil)
  @acknowledge_fiscal_printer_reset = acknowledge_fiscal_printer_reset
end

Instance Attribute Details

#acknowledge_fiscal_printer_resetTrueClass | FalseClass

Confirmation that the fiscal printer was deactivated/reset by an authorised technician and is legally ready to be reassigned to another store. NewStore does not perform or verify the fiscal/legal deregistration; the retailer is responsible for completing all applicable fiscal authority requirements first.

Returns:

  • (TrueClass | FalseClass)


18
19
20
# File 'lib/new_store_api/models/cashbox_release_v1_dto.rb', line 18

def acknowledge_fiscal_printer_reset
  @acknowledge_fiscal_printer_reset
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



43
44
45
46
47
48
49
50
51
52
# File 'lib/new_store_api/models/cashbox_release_v1_dto.rb', line 43

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  acknowledge_fiscal_printer_reset =
    hash.key?('acknowledge_fiscal_printer_reset') ? hash['acknowledge_fiscal_printer_reset'] : nil

  # Create object from extracted values.
  CashboxReleaseV1Dto.new(acknowledge_fiscal_printer_reset)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/new_store_api/models/cashbox_release_v1_dto.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['acknowledge_fiscal_printer_reset'] =
    'acknowledge_fiscal_printer_reset'
  @_hash
end

.nullablesObject

An array for nullable fields



34
35
36
# File 'lib/new_store_api/models/cashbox_release_v1_dto.rb', line 34

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
# File 'lib/new_store_api/models/cashbox_release_v1_dto.rb', line 29

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



61
62
63
64
65
# File 'lib/new_store_api/models/cashbox_release_v1_dto.rb', line 61

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} acknowledge_fiscal_printer_reset:"\
  " #{@acknowledge_fiscal_printer_reset.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



55
56
57
58
# File 'lib/new_store_api/models/cashbox_release_v1_dto.rb', line 55

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} acknowledge_fiscal_printer_reset: #{@acknowledge_fiscal_printer_reset}>"
end