Class: NewStoreApi::ConfigurationFeatureFlags
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- NewStoreApi::ConfigurationFeatureFlags
- Defined in:
- lib/new_store_api/models/configuration_feature_flags.rb
Overview
ConfigurationFeatureFlags Model.
Instance Attribute Summary collapse
-
#dlv1_use_dlv2_bookings ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#dlv1_use_dlv2_options ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(dlv1_use_dlv2_bookings = true, dlv1_use_dlv2_options = true) ⇒ ConfigurationFeatureFlags
constructor
A new instance of ConfigurationFeatureFlags.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(dlv1_use_dlv2_bookings = true, dlv1_use_dlv2_options = true) ⇒ ConfigurationFeatureFlags
Returns a new instance of ConfigurationFeatureFlags.
41 42 43 44 |
# File 'lib/new_store_api/models/configuration_feature_flags.rb', line 41 def initialize(dlv1_use_dlv2_bookings = true, = true) @dlv1_use_dlv2_bookings = dlv1_use_dlv2_bookings unless dlv1_use_dlv2_bookings == SKIP @dlv1_use_dlv2_options = unless == SKIP end |
Instance Attribute Details
#dlv1_use_dlv2_bookings ⇒ TrueClass | FalseClass
TODO: Write general description for this method
14 15 16 |
# File 'lib/new_store_api/models/configuration_feature_flags.rb', line 14 def dlv1_use_dlv2_bookings @dlv1_use_dlv2_bookings end |
#dlv1_use_dlv2_options ⇒ TrueClass | FalseClass
TODO: Write general description for this method
18 19 20 |
# File 'lib/new_store_api/models/configuration_feature_flags.rb', line 18 def @dlv1_use_dlv2_options end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/new_store_api/models/configuration_feature_flags.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. dlv1_use_dlv2_bookings = hash['dlv1_use_dlv2_bookings'] ||= true = hash['dlv1_use_dlv2_options'] ||= true # Create object from extracted values. ConfigurationFeatureFlags.new(dlv1_use_dlv2_bookings, ) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/new_store_api/models/configuration_feature_flags.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['dlv1_use_dlv2_bookings'] = 'dlv1_use_dlv2_bookings' @_hash['dlv1_use_dlv2_options'] = 'dlv1_use_dlv2_options' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/new_store_api/models/configuration_feature_flags.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/new_store_api/models/configuration_feature_flags.rb', line 29 def self.optionals %w[ dlv1_use_dlv2_bookings dlv1_use_dlv2_options ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
67 68 69 70 71 |
# File 'lib/new_store_api/models/configuration_feature_flags.rb', line 67 def inspect class_name = self.class.name.split('::').last "<#{class_name} dlv1_use_dlv2_bookings: #{@dlv1_use_dlv2_bookings.inspect},"\ " dlv1_use_dlv2_options: #{@dlv1_use_dlv2_options.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
60 61 62 63 64 |
# File 'lib/new_store_api/models/configuration_feature_flags.rb', line 60 def to_s class_name = self.class.name.split('::').last "<#{class_name} dlv1_use_dlv2_bookings: #{@dlv1_use_dlv2_bookings}, dlv1_use_dlv2_options:"\ " #{@dlv1_use_dlv2_options}>" end |