Class: NewStoreApi::CountTaskLineItemResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- NewStoreApi::CountTaskLineItemResponse
- Defined in:
- lib/new_store_api/models/count_task_line_item_response.rb
Overview
CountTaskLineItemResponse Model.
Instance Attribute Summary collapse
-
#count ⇒ Integer
Counted quantity.
-
#expected ⇒ Integer
Expected quantity.
-
#id ⇒ String
Product identifier.
-
#variance ⇒ Integer
Quantity variance.
-
#zones ⇒ Array[String]
Count zones.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(count = nil, expected = nil, id = nil, variance = nil, zones = nil) ⇒ CountTaskLineItemResponse
constructor
A new instance of CountTaskLineItemResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(count = nil, expected = nil, id = nil, variance = nil, zones = nil) ⇒ CountTaskLineItemResponse
Returns a new instance of CountTaskLineItemResponse.
53 54 55 56 57 58 59 60 |
# File 'lib/new_store_api/models/count_task_line_item_response.rb', line 53 def initialize(count = nil, expected = nil, id = nil, variance = nil, zones = nil) @count = count @expected = expected @id = id @variance = variance @zones = zones end |
Instance Attribute Details
#count ⇒ Integer
Counted quantity.
14 15 16 |
# File 'lib/new_store_api/models/count_task_line_item_response.rb', line 14 def count @count end |
#expected ⇒ Integer
Expected quantity.
18 19 20 |
# File 'lib/new_store_api/models/count_task_line_item_response.rb', line 18 def expected @expected end |
#id ⇒ String
Product identifier.
22 23 24 |
# File 'lib/new_store_api/models/count_task_line_item_response.rb', line 22 def id @id end |
#variance ⇒ Integer
Quantity variance.
26 27 28 |
# File 'lib/new_store_api/models/count_task_line_item_response.rb', line 26 def variance @variance end |
#zones ⇒ Array[String]
Count zones.
30 31 32 |
# File 'lib/new_store_api/models/count_task_line_item_response.rb', line 30 def zones @zones end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/new_store_api/models/count_task_line_item_response.rb', line 63 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. count = hash.key?('count') ? hash['count'] : nil expected = hash.key?('expected') ? hash['expected'] : nil id = hash.key?('id') ? hash['id'] : nil variance = hash.key?('variance') ? hash['variance'] : nil zones = hash.key?('zones') ? hash['zones'] : nil # Create object from extracted values. CountTaskLineItemResponse.new(count, expected, id, variance, zones) end |
.names ⇒ Object
A mapping from model property names to API property names.
33 34 35 36 37 38 39 40 41 |
# File 'lib/new_store_api/models/count_task_line_item_response.rb', line 33 def self.names @_hash = {} if @_hash.nil? @_hash['count'] = 'count' @_hash['expected'] = 'expected' @_hash['id'] = 'id' @_hash['variance'] = 'variance' @_hash['zones'] = 'zones' @_hash end |
.nullables ⇒ Object
An array for nullable fields
49 50 51 |
# File 'lib/new_store_api/models/count_task_line_item_response.rb', line 49 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
44 45 46 |
# File 'lib/new_store_api/models/count_task_line_item_response.rb', line 44 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
89 90 91 92 93 |
# File 'lib/new_store_api/models/count_task_line_item_response.rb', line 89 def inspect class_name = self.class.name.split('::').last "<#{class_name} count: #{@count.inspect}, expected: #{@expected.inspect}, id:"\ " #{@id.inspect}, variance: #{@variance.inspect}, zones: #{@zones.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
82 83 84 85 86 |
# File 'lib/new_store_api/models/count_task_line_item_response.rb', line 82 def to_s class_name = self.class.name.split('::').last "<#{class_name} count: #{@count}, expected: #{@expected}, id: #{@id}, variance:"\ " #{@variance}, zones: #{@zones}>" end |