Class: NewStoreApi::CreatePackageTrackingEasypostAdapter
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- NewStoreApi::CreatePackageTrackingEasypostAdapter
- Defined in:
- lib/new_store_api/models/create_package_tracking_easypost_adapter.rb
Overview
CreatePackageTrackingEasypostAdapter Model.
Instance Attribute Summary collapse
-
#easypost_marker ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(easypost_marker = nil) ⇒ CreatePackageTrackingEasypostAdapter
constructor
A new instance of CreatePackageTrackingEasypostAdapter.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(easypost_marker = nil) ⇒ CreatePackageTrackingEasypostAdapter
Returns a new instance of CreatePackageTrackingEasypostAdapter.
33 34 35 |
# File 'lib/new_store_api/models/create_package_tracking_easypost_adapter.rb', line 33 def initialize(easypost_marker = nil) @easypost_marker = easypost_marker end |
Instance Attribute Details
#easypost_marker ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/new_store_api/models/create_package_tracking_easypost_adapter.rb', line 14 def easypost_marker @easypost_marker end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
38 39 40 41 42 43 44 45 46 47 |
# File 'lib/new_store_api/models/create_package_tracking_easypost_adapter.rb', line 38 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. easypost_marker = hash.key?('easypost_marker') ? hash['easypost_marker'] : nil # Create object from extracted values. CreatePackageTrackingEasypostAdapter.new(easypost_marker) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/new_store_api/models/create_package_tracking_easypost_adapter.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['easypost_marker'] = 'easypost_marker' @_hash end |
.nullables ⇒ Object
An array for nullable fields
29 30 31 |
# File 'lib/new_store_api/models/create_package_tracking_easypost_adapter.rb', line 29 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 |
# File 'lib/new_store_api/models/create_package_tracking_easypost_adapter.rb', line 24 def self.optionals [] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/new_store_api/models/create_package_tracking_easypost_adapter.rb', line 51 def self.validate(value) if value.instance_of? self return APIHelper.valid_type?(value.easypost_marker, ->(val) { val.instance_of? String }) end return false unless value.instance_of? Hash APIHelper.valid_type?(value['easypost_marker'], ->(val) { val.instance_of? String }) end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
70 71 72 73 |
# File 'lib/new_store_api/models/create_package_tracking_easypost_adapter.rb', line 70 def inspect class_name = self.class.name.split('::').last "<#{class_name} easypost_marker: #{@easypost_marker.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
64 65 66 67 |
# File 'lib/new_store_api/models/create_package_tracking_easypost_adapter.rb', line 64 def to_s class_name = self.class.name.split('::').last "<#{class_name} easypost_marker: #{@easypost_marker}>" end |