Class: NewStoreApi::CreatePaymentLinkRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/new_store_api/models/create_payment_link_request.rb

Overview

CreatePaymentLinkRequest Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(amount = nil, currency = nil, metadata = SKIP) ⇒ CreatePaymentLinkRequest

Returns a new instance of CreatePaymentLinkRequest.



47
48
49
50
51
# File 'lib/new_store_api/models/create_payment_link_request.rb', line 47

def initialize(amount = nil, currency = nil,  = SKIP)
  @amount = amount
  @currency = currency
  @metadata =  unless  == SKIP
end

Instance Attribute Details

#amountObject

TODO: Write general description for this method

Returns:

  • (Object)


14
15
16
# File 'lib/new_store_api/models/create_payment_link_request.rb', line 14

def amount
  @amount
end

#currencyString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/new_store_api/models/create_payment_link_request.rb', line 18

def currency
  @currency
end

#metadataProcessorMetadata

TODO: Write general description for this method

Returns:



22
23
24
# File 'lib/new_store_api/models/create_payment_link_request.rb', line 22

def 
  @metadata
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/new_store_api/models/create_payment_link_request.rb', line 54

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  amount = hash.key?('amount') ? APIHelper.deserialize_union_type(
    UnionTypeLookUp.get(:CreatePaymentLinkRequestAmount), hash['amount']
  ) : nil
  currency = hash.key?('currency') ? hash['currency'] : nil
   = ProcessorMetadata.from_hash(hash['metadata']) if hash['metadata']

  # Create object from extracted values.
  CreatePaymentLinkRequest.new(amount,
                               currency,
                               )
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/new_store_api/models/create_payment_link_request.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['amount'] = 'amount'
  @_hash['currency'] = 'currency'
  @_hash['metadata'] = 'metadata'
  @_hash
end

.nullablesObject

An array for nullable fields



41
42
43
44
45
# File 'lib/new_store_api/models/create_payment_link_request.rb', line 41

def self.nullables
  %w[
    metadata
  ]
end

.optionalsObject

An array for optional fields



34
35
36
37
38
# File 'lib/new_store_api/models/create_payment_link_request.rb', line 34

def self.optionals
  %w[
    metadata
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/new_store_api/models/create_payment_link_request.rb', line 72

def self.validate(value)
  if value.instance_of? self
    return (
      UnionTypeLookUp.get(:CreatePaymentLinkRequestAmount)
                     .validate(value.amount) and
        APIHelper.valid_type?(value.currency,
                              ->(val) { val.instance_of? String })
    )
  end

  return false unless value.instance_of? Hash

  (
    UnionTypeLookUp.get(:CreatePaymentLinkRequestAmount)
                   .validate(value['amount']) and
      APIHelper.valid_type?(value['currency'],
                            ->(val) { val.instance_of? String })
  )
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



99
100
101
102
103
# File 'lib/new_store_api/models/create_payment_link_request.rb', line 99

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} amount: #{@amount.inspect}, currency: #{@currency.inspect}, metadata:"\
  " #{@metadata.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



93
94
95
96
# File 'lib/new_store_api/models/create_payment_link_request.rb', line 93

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} amount: #{@amount}, currency: #{@currency}, metadata: #{@metadata}>"
end