Class: NewStoreApi::CreateSamlIdentityProviderConfig
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- NewStoreApi::CreateSamlIdentityProviderConfig
- Defined in:
- lib/new_store_api/models/create_saml_identity_provider_config.rb
Overview
CreateSamlIdentityProviderConfig Model.
Instance Attribute Summary collapse
-
#config_xml ⇒ String
base64 encoded SAML config.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(config_xml = nil) ⇒ CreateSamlIdentityProviderConfig
constructor
A new instance of CreateSamlIdentityProviderConfig.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(config_xml = nil) ⇒ CreateSamlIdentityProviderConfig
Returns a new instance of CreateSamlIdentityProviderConfig.
33 34 35 |
# File 'lib/new_store_api/models/create_saml_identity_provider_config.rb', line 33 def initialize(config_xml = nil) @config_xml = config_xml end |
Instance Attribute Details
#config_xml ⇒ String
base64 encoded SAML config
14 15 16 |
# File 'lib/new_store_api/models/create_saml_identity_provider_config.rb', line 14 def config_xml @config_xml end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
38 39 40 41 42 43 44 45 46 |
# File 'lib/new_store_api/models/create_saml_identity_provider_config.rb', line 38 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. config_xml = hash.key?('config_xml') ? hash['config_xml'] : nil # Create object from extracted values. CreateSamlIdentityProviderConfig.new(config_xml) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/new_store_api/models/create_saml_identity_provider_config.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['config_xml'] = 'config_xml' @_hash end |
.nullables ⇒ Object
An array for nullable fields
29 30 31 |
# File 'lib/new_store_api/models/create_saml_identity_provider_config.rb', line 29 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 |
# File 'lib/new_store_api/models/create_saml_identity_provider_config.rb', line 24 def self.optionals [] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/new_store_api/models/create_saml_identity_provider_config.rb', line 50 def self.validate(value) if value.instance_of? self return APIHelper.valid_type?(value.config_xml, ->(val) { val.instance_of? String }) end return false unless value.instance_of? Hash APIHelper.valid_type?(value['config_xml'], ->(val) { val.instance_of? String }) end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
69 70 71 72 |
# File 'lib/new_store_api/models/create_saml_identity_provider_config.rb', line 69 def inspect class_name = self.class.name.split('::').last "<#{class_name} config_xml: #{@config_xml.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
63 64 65 66 |
# File 'lib/new_store_api/models/create_saml_identity_provider_config.rb', line 63 def to_s class_name = self.class.name.split('::').last "<#{class_name} config_xml: #{@config_xml}>" end |