Class: NewStoreApi::CustomConfigAuthenticationDto

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/new_store_api/models/custom_config_authentication_dto.rb

Overview

CustomConfigAuthenticationDto Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(method = nil, password = nil, username = nil) ⇒ CustomConfigAuthenticationDto

Returns a new instance of CustomConfigAuthenticationDto.



43
44
45
46
47
# File 'lib/new_store_api/models/custom_config_authentication_dto.rb', line 43

def initialize(method = nil, password = nil, username = nil)
  @method = method
  @password = password
  @username = username
end

Instance Attribute Details

#methodCustomConfigAuthenticationMethodEnum

TODO: Write general description for this method



14
15
16
# File 'lib/new_store_api/models/custom_config_authentication_dto.rb', line 14

def method
  @method
end

#passwordString

Custom provider Basic authentication password.

Returns:

  • (String)


18
19
20
# File 'lib/new_store_api/models/custom_config_authentication_dto.rb', line 18

def password
  @password
end

#usernameString

Custom provider Basic authentication username.

Returns:

  • (String)


22
23
24
# File 'lib/new_store_api/models/custom_config_authentication_dto.rb', line 22

def username
  @username
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/new_store_api/models/custom_config_authentication_dto.rb', line 50

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  method = hash.key?('method') ? hash['method'] : nil
  password = hash.key?('password') ? hash['password'] : nil
  username = hash.key?('username') ? hash['username'] : nil

  # Create object from extracted values.
  CustomConfigAuthenticationDto.new(method,
                                    password,
                                    username)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/new_store_api/models/custom_config_authentication_dto.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['method'] = 'method'
  @_hash['password'] = 'password'
  @_hash['username'] = 'username'
  @_hash
end

.nullablesObject

An array for nullable fields



39
40
41
# File 'lib/new_store_api/models/custom_config_authentication_dto.rb', line 39

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
# File 'lib/new_store_api/models/custom_config_authentication_dto.rb', line 34

def self.optionals
  []
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/new_store_api/models/custom_config_authentication_dto.rb', line 66

def self.validate(value)
  if value.instance_of? self
    return (
      APIHelper.valid_type?(value.method,
                            ->(val) { CustomConfigAuthenticationMethodEnum.validate(val) }) and
        APIHelper.valid_type?(value.password,
                              ->(val) { val.instance_of? String }) and
        APIHelper.valid_type?(value.username,
                              ->(val) { val.instance_of? String })
    )
  end

  return false unless value.instance_of? Hash

  (
    APIHelper.valid_type?(value['method'],
                          ->(val) { CustomConfigAuthenticationMethodEnum.validate(val) }) and
      APIHelper.valid_type?(value['password'],
                            ->(val) { val.instance_of? String }) and
      APIHelper.valid_type?(value['username'],
                            ->(val) { val.instance_of? String })
  )
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



97
98
99
100
101
# File 'lib/new_store_api/models/custom_config_authentication_dto.rb', line 97

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} method: #{@method.inspect}, password: #{@password.inspect}, username:"\
  " #{@username.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



91
92
93
94
# File 'lib/new_store_api/models/custom_config_authentication_dto.rb', line 91

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} method: #{@method}, password: #{@password}, username: #{@username}>"
end