Class: NewStoreApi::DestinationRegion
- Defined in:
- lib/new_store_api/models/destination_region.rb
Overview
DestinationRegion Model.
Instance Attribute Summary collapse
-
#countries ⇒ Array[String]
Country in 2 chars (ISO 3166-1 alpha-2) definition.
-
#zip_code_region ⇒ String
Region identification that will cover that routing.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(countries = SKIP, zip_code_region = SKIP) ⇒ DestinationRegion
constructor
A new instance of DestinationRegion.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(countries = SKIP, zip_code_region = SKIP) ⇒ DestinationRegion
Returns a new instance of DestinationRegion.
42 43 44 45 |
# File 'lib/new_store_api/models/destination_region.rb', line 42 def initialize(countries = SKIP, zip_code_region = SKIP) @countries = countries unless countries == SKIP @zip_code_region = zip_code_region unless zip_code_region == SKIP end |
Instance Attribute Details
#countries ⇒ Array[String]
Country in 2 chars (ISO 3166-1 alpha-2) definition
14 15 16 |
# File 'lib/new_store_api/models/destination_region.rb', line 14 def countries @countries end |
#zip_code_region ⇒ String
Region identification that will cover that routing. Zip code region groups
is defined in zip_code_regions.
19 20 21 |
# File 'lib/new_store_api/models/destination_region.rb', line 19 def zip_code_region @zip_code_region end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
48 49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/new_store_api/models/destination_region.rb', line 48 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. countries = hash.key?('countries') ? hash['countries'] : SKIP zip_code_region = hash.key?('zip_code_region') ? hash['zip_code_region'] : SKIP # Create object from extracted values. DestinationRegion.new(countries, zip_code_region) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/new_store_api/models/destination_region.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['countries'] = 'countries' @_hash['zip_code_region'] = 'zip_code_region' @_hash end |
.nullables ⇒ Object
An array for nullable fields
38 39 40 |
# File 'lib/new_store_api/models/destination_region.rb', line 38 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 33 34 35 |
# File 'lib/new_store_api/models/destination_region.rb', line 30 def self.optionals %w[ countries zip_code_region ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
68 69 70 71 72 |
# File 'lib/new_store_api/models/destination_region.rb', line 68 def inspect class_name = self.class.name.split('::').last "<#{class_name} countries: #{@countries.inspect}, zip_code_region:"\ " #{@zip_code_region.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
62 63 64 65 |
# File 'lib/new_store_api/models/destination_region.rb', line 62 def to_s class_name = self.class.name.split('::').last "<#{class_name} countries: #{@countries}, zip_code_region: #{@zip_code_region}>" end |