Class: NewStoreApi::DownloadResponse
- Defined in:
- lib/new_store_api/models/download_response.rb
Overview
DownloadResponse Model.
Instance Attribute Summary collapse
-
#download_url ⇒ String
The presigned URL to redirect to, to download the requested offline products.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(download_url = nil) ⇒ DownloadResponse
constructor
A new instance of DownloadResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(download_url = nil) ⇒ DownloadResponse
Returns a new instance of DownloadResponse.
34 35 36 |
# File 'lib/new_store_api/models/download_response.rb', line 34 def initialize(download_url = nil) @download_url = download_url end |
Instance Attribute Details
#download_url ⇒ String
The presigned URL to redirect to, to download the requested offline products.
15 16 17 |
# File 'lib/new_store_api/models/download_response.rb', line 15 def download_url @download_url end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
39 40 41 42 43 44 45 46 47 |
# File 'lib/new_store_api/models/download_response.rb', line 39 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. download_url = hash.key?('download_url') ? hash['download_url'] : nil # Create object from extracted values. DownloadResponse.new(download_url) end |
.names ⇒ Object
A mapping from model property names to API property names.
18 19 20 21 22 |
# File 'lib/new_store_api/models/download_response.rb', line 18 def self.names @_hash = {} if @_hash.nil? @_hash['download_url'] = 'download_url' @_hash end |
.nullables ⇒ Object
An array for nullable fields
30 31 32 |
# File 'lib/new_store_api/models/download_response.rb', line 30 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
25 26 27 |
# File 'lib/new_store_api/models/download_response.rb', line 25 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
56 57 58 59 |
# File 'lib/new_store_api/models/download_response.rb', line 56 def inspect class_name = self.class.name.split('::').last "<#{class_name} download_url: #{@download_url.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
50 51 52 53 |
# File 'lib/new_store_api/models/download_response.rb', line 50 def to_s class_name = self.class.name.split('::').last "<#{class_name} download_url: #{@download_url}>" end |