Class: NewStoreApi::ExtendedAttributeModel

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/new_store_api/models/extended_attribute_model.rb

Overview

Key-value pair describing a custom attribute associated with the profile.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(data_type = nil, value = nil) ⇒ ExtendedAttributeModel

Returns a new instance of ExtendedAttributeModel.



38
39
40
41
# File 'lib/new_store_api/models/extended_attribute_model.rb', line 38

def initialize(data_type = nil, value = nil)
  @data_type = data_type
  @value = value
end

Instance Attribute Details

#data_typeString

Data type of the additional attribute.

Returns:

  • (String)


14
15
16
# File 'lib/new_store_api/models/extended_attribute_model.rb', line 14

def data_type
  @data_type
end

#valueString

Value of the additional attribute.

Returns:

  • (String)


18
19
20
# File 'lib/new_store_api/models/extended_attribute_model.rb', line 18

def value
  @value
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



44
45
46
47
48
49
50
51
52
53
54
# File 'lib/new_store_api/models/extended_attribute_model.rb', line 44

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  data_type = hash.key?('data_type') ? hash['data_type'] : nil
  value = hash.key?('value') ? hash['value'] : nil

  # Create object from extracted values.
  ExtendedAttributeModel.new(data_type,
                             value)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/new_store_api/models/extended_attribute_model.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['data_type'] = 'data_type'
  @_hash['value'] = 'value'
  @_hash
end

.nullablesObject

An array for nullable fields



34
35
36
# File 'lib/new_store_api/models/extended_attribute_model.rb', line 34

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
# File 'lib/new_store_api/models/extended_attribute_model.rb', line 29

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



63
64
65
66
# File 'lib/new_store_api/models/extended_attribute_model.rb', line 63

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} data_type: #{@data_type.inspect}, value: #{@value.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



57
58
59
60
# File 'lib/new_store_api/models/extended_attribute_model.rb', line 57

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} data_type: #{@data_type}, value: #{@value}>"
end