Class: NewStoreApi::ExternalFulfillmentSettingsResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/new_store_api/models/external_fulfillment_settings_response.rb

Overview

Current external-fulfillment configuration setting.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(updated_at = nil, value = nil) ⇒ ExternalFulfillmentSettingsResponse

Returns a new instance of ExternalFulfillmentSettingsResponse.



44
45
46
47
# File 'lib/new_store_api/models/external_fulfillment_settings_response.rb', line 44

def initialize(updated_at = nil, value = nil)
  @updated_at = updated_at
  @value = value
end

Instance Attribute Details

#updated_atString

Contains date-time in ISO8601 UTC format when config was updated at least once. Value can be null if config value has not been specified yet by the retailer.

Returns:

  • (String)


16
17
18
# File 'lib/new_store_api/models/external_fulfillment_settings_response.rb', line 16

def updated_at
  @updated_at
end

#valueTrueClass | FalseClass

Tenant-based release toggle for updating the status of a fulfillment request in NOM.

Returns:

  • (TrueClass | FalseClass)


21
22
23
# File 'lib/new_store_api/models/external_fulfillment_settings_response.rb', line 21

def value
  @value
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



50
51
52
53
54
55
56
57
58
59
60
# File 'lib/new_store_api/models/external_fulfillment_settings_response.rb', line 50

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  updated_at = hash.key?('updated_at') ? hash['updated_at'] : nil
  value = hash.key?('value') ? hash['value'] : nil

  # Create object from extracted values.
  ExternalFulfillmentSettingsResponse.new(updated_at,
                                          value)
end

.namesObject

A mapping from model property names to API property names.



24
25
26
27
28
29
# File 'lib/new_store_api/models/external_fulfillment_settings_response.rb', line 24

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['updated_at'] = 'updated_at'
  @_hash['value'] = 'value'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
40
41
42
# File 'lib/new_store_api/models/external_fulfillment_settings_response.rb', line 37

def self.nullables
  %w[
    updated_at
    value
  ]
end

.optionalsObject

An array for optional fields



32
33
34
# File 'lib/new_store_api/models/external_fulfillment_settings_response.rb', line 32

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



69
70
71
72
# File 'lib/new_store_api/models/external_fulfillment_settings_response.rb', line 69

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} updated_at: #{@updated_at.inspect}, value: #{@value.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



63
64
65
66
# File 'lib/new_store_api/models/external_fulfillment_settings_response.rb', line 63

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} updated_at: #{@updated_at}, value: #{@value}>"
end