Class: NewStoreApi::FallbackErrorDto
- Defined in:
- lib/new_store_api/models/fallback_error_dto.rb
Overview
FallbackErrorDto Model.
Instance Attribute Summary collapse
-
#error_code ⇒ TaxServiceErrorCodeEnum
TODO: Write general description for this method.
-
#message ⇒ String
The error message of the underlying tax provider.
-
#original_tax_provider ⇒ TaxCalculationStrategyEnum
The error message of the underlying tax provider.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(error_code = nil, message = nil, original_tax_provider = nil) ⇒ FallbackErrorDto
constructor
A new instance of FallbackErrorDto.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(error_code = nil, message = nil, original_tax_provider = nil) ⇒ FallbackErrorDto
Returns a new instance of FallbackErrorDto.
43 44 45 46 47 |
# File 'lib/new_store_api/models/fallback_error_dto.rb', line 43 def initialize(error_code = nil, = nil, original_tax_provider = nil) @error_code = error_code @message = @original_tax_provider = original_tax_provider end |
Instance Attribute Details
#error_code ⇒ TaxServiceErrorCodeEnum
TODO: Write general description for this method
14 15 16 |
# File 'lib/new_store_api/models/fallback_error_dto.rb', line 14 def error_code @error_code end |
#message ⇒ String
The error message of the underlying tax provider.
18 19 20 |
# File 'lib/new_store_api/models/fallback_error_dto.rb', line 18 def @message end |
#original_tax_provider ⇒ TaxCalculationStrategyEnum
The error message of the underlying tax provider.
22 23 24 |
# File 'lib/new_store_api/models/fallback_error_dto.rb', line 22 def original_tax_provider @original_tax_provider end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/new_store_api/models/fallback_error_dto.rb', line 50 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. error_code = hash.key?('error_code') ? hash['error_code'] : nil = hash.key?('message') ? hash['message'] : nil original_tax_provider = hash.key?('original_tax_provider') ? hash['original_tax_provider'] : nil # Create object from extracted values. FallbackErrorDto.new(error_code, , original_tax_provider) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/new_store_api/models/fallback_error_dto.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['error_code'] = 'error_code' @_hash['message'] = 'message' @_hash['original_tax_provider'] = 'original_tax_provider' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/new_store_api/models/fallback_error_dto.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/new_store_api/models/fallback_error_dto.rb', line 34 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
73 74 75 76 77 |
# File 'lib/new_store_api/models/fallback_error_dto.rb', line 73 def inspect class_name = self.class.name.split('::').last "<#{class_name} error_code: #{@error_code.inspect}, message: #{@message.inspect},"\ " original_tax_provider: #{@original_tax_provider.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
66 67 68 69 70 |
# File 'lib/new_store_api/models/fallback_error_dto.rb', line 66 def to_s class_name = self.class.name.split('::').last "<#{class_name} error_code: #{@error_code}, message: #{@message}, original_tax_provider:"\ " #{@original_tax_provider}>" end |