Class: NewStoreApi::FulfillmentConfigGetRoutingRulesSectionSampleResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- NewStoreApi::FulfillmentConfigGetRoutingRulesSectionSampleResponse
- Defined in:
- lib/new_store_api/models/fulfillment_config_get_routing_rules_section_sample_response.rb
Overview
FulfillmentConfigGetRoutingRulesSectionSampleResponse Model.
Instance Attribute Summary collapse
-
#routes ⇒ Array[Routes]
Routing rules specification.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(routes = nil) ⇒ FulfillmentConfigGetRoutingRulesSectionSampleResponse
constructor
A new instance of FulfillmentConfigGetRoutingRulesSectionSampleResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(routes = nil) ⇒ FulfillmentConfigGetRoutingRulesSectionSampleResponse
Returns a new instance of FulfillmentConfigGetRoutingRulesSectionSampleResponse.
33 34 35 |
# File 'lib/new_store_api/models/fulfillment_config_get_routing_rules_section_sample_response.rb', line 33 def initialize(routes = nil) @routes = routes end |
Instance Attribute Details
#routes ⇒ Array[Routes]
Routing rules specification
14 15 16 |
# File 'lib/new_store_api/models/fulfillment_config_get_routing_rules_section_sample_response.rb', line 14 def routes @routes end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/new_store_api/models/fulfillment_config_get_routing_rules_section_sample_response.rb', line 38 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it routes = nil unless hash['routes'].nil? routes = [] hash['routes'].each do |structure| routes << (Routes.from_hash(structure) if structure) end end routes = nil unless hash.key?('routes') # Create object from extracted values. FulfillmentConfigGetRoutingRulesSectionSampleResponse.new(routes) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/new_store_api/models/fulfillment_config_get_routing_rules_section_sample_response.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['routes'] = 'routes' @_hash end |
.nullables ⇒ Object
An array for nullable fields
29 30 31 |
# File 'lib/new_store_api/models/fulfillment_config_get_routing_rules_section_sample_response.rb', line 29 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 |
# File 'lib/new_store_api/models/fulfillment_config_get_routing_rules_section_sample_response.rb', line 24 def self.optionals [] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/new_store_api/models/fulfillment_config_get_routing_rules_section_sample_response.rb', line 59 def self.validate(value) if value.instance_of? self return APIHelper.valid_type?(value.routes, ->(val) { Routes.validate(val) }, is_model_hash: true, is_inner_model_hash: true) end return false unless value.instance_of? Hash APIHelper.valid_type?(value['routes'], ->(val) { Routes.validate(val) }, is_model_hash: true, is_inner_model_hash: true) end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
82 83 84 85 |
# File 'lib/new_store_api/models/fulfillment_config_get_routing_rules_section_sample_response.rb', line 82 def inspect class_name = self.class.name.split('::').last "<#{class_name} routes: #{@routes.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
76 77 78 79 |
# File 'lib/new_store_api/models/fulfillment_config_get_routing_rules_section_sample_response.rb', line 76 def to_s class_name = self.class.name.split('::').last "<#{class_name} routes: #{@routes}>" end |