Class: NewStoreApi::FulfillmentConfigGetRoutingRulesSectionSampleResponse1

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/new_store_api/models/fulfillment_config_get_routing_rules_section_sample_response1.rb

Overview

FulfillmentConfigGetRoutingRulesSectionSampleResponse1 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(sl_levels_priority = nil) ⇒ FulfillmentConfigGetRoutingRulesSectionSampleResponse1

Returns a new instance of FulfillmentConfigGetRoutingRulesSectionSampleResponse1.



34
35
36
# File 'lib/new_store_api/models/fulfillment_config_get_routing_rules_section_sample_response1.rb', line 34

def initialize(sl_levels_priority = nil)
  @sl_levels_priority = sl_levels_priority
end

Instance Attribute Details

#sl_levels_priorityArray[String]

Service levels priority. This is ordered according to which service level will be taken first

Returns:

  • (Array[String])


15
16
17
# File 'lib/new_store_api/models/fulfillment_config_get_routing_rules_section_sample_response1.rb', line 15

def sl_levels_priority
  @sl_levels_priority
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



39
40
41
42
43
44
45
46
47
48
# File 'lib/new_store_api/models/fulfillment_config_get_routing_rules_section_sample_response1.rb', line 39

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  sl_levels_priority =
    hash.key?('sl_levels_priority') ? hash['sl_levels_priority'] : nil

  # Create object from extracted values.
  FulfillmentConfigGetRoutingRulesSectionSampleResponse1.new(sl_levels_priority)
end

.namesObject

A mapping from model property names to API property names.



18
19
20
21
22
# File 'lib/new_store_api/models/fulfillment_config_get_routing_rules_section_sample_response1.rb', line 18

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['sl_levels_priority'] = 'sl_levels_priority'
  @_hash
end

.nullablesObject

An array for nullable fields



30
31
32
# File 'lib/new_store_api/models/fulfillment_config_get_routing_rules_section_sample_response1.rb', line 30

def self.nullables
  []
end

.optionalsObject

An array for optional fields



25
26
27
# File 'lib/new_store_api/models/fulfillment_config_get_routing_rules_section_sample_response1.rb', line 25

def self.optionals
  []
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



52
53
54
55
56
57
58
59
60
61
62
# File 'lib/new_store_api/models/fulfillment_config_get_routing_rules_section_sample_response1.rb', line 52

def self.validate(value)
  if value.instance_of? self
    return APIHelper.valid_type?(value.sl_levels_priority,
                                 ->(val) { val.instance_of? String })
  end

  return false unless value.instance_of? Hash

  APIHelper.valid_type?(value['sl_levels_priority'],
                        ->(val) { val.instance_of? String })
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



71
72
73
74
# File 'lib/new_store_api/models/fulfillment_config_get_routing_rules_section_sample_response1.rb', line 71

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} sl_levels_priority: #{@sl_levels_priority.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



65
66
67
68
# File 'lib/new_store_api/models/fulfillment_config_get_routing_rules_section_sample_response1.rb', line 65

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} sl_levels_priority: #{@sl_levels_priority}>"
end