Class: NewStoreApi::FulfillmentConfigGetRoutingRulesSectionSampleResponse2

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/new_store_api/models/fulfillment_config_get_routing_rules_section_sample_response2.rb

Overview

FulfillmentConfigGetRoutingRulesSectionSampleResponse2 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(location_groups = nil) ⇒ FulfillmentConfigGetRoutingRulesSectionSampleResponse2

Returns a new instance of FulfillmentConfigGetRoutingRulesSectionSampleResponse2.



33
34
35
# File 'lib/new_store_api/models/fulfillment_config_get_routing_rules_section_sample_response2.rb', line 33

def initialize(location_groups = nil)
  @location_groups = location_groups
end

Instance Attribute Details

#location_groupsHash[String, Object]

Location groups identifiers

Returns:

  • (Hash[String, Object])


14
15
16
# File 'lib/new_store_api/models/fulfillment_config_get_routing_rules_section_sample_response2.rb', line 14

def location_groups
  @location_groups
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



38
39
40
41
42
43
44
45
46
47
# File 'lib/new_store_api/models/fulfillment_config_get_routing_rules_section_sample_response2.rb', line 38

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  location_groups =
    hash.key?('location_groups') ? hash['location_groups'] : nil

  # Create object from extracted values.
  FulfillmentConfigGetRoutingRulesSectionSampleResponse2.new(location_groups)
end

.namesObject

A mapping from model property names to API property names.



17
18
19
20
21
# File 'lib/new_store_api/models/fulfillment_config_get_routing_rules_section_sample_response2.rb', line 17

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['location_groups'] = 'location_groups'
  @_hash
end

.nullablesObject

An array for nullable fields



29
30
31
# File 'lib/new_store_api/models/fulfillment_config_get_routing_rules_section_sample_response2.rb', line 29

def self.nullables
  []
end

.optionalsObject

An array for optional fields



24
25
26
# File 'lib/new_store_api/models/fulfillment_config_get_routing_rules_section_sample_response2.rb', line 24

def self.optionals
  []
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



51
52
53
54
55
56
57
58
59
60
61
# File 'lib/new_store_api/models/fulfillment_config_get_routing_rules_section_sample_response2.rb', line 51

def self.validate(value)
  if value.instance_of? self
    return APIHelper.valid_type?(value.location_groups,
                                 ->(val) { val.instance_of? Object })
  end

  return false unless value.instance_of? Hash

  APIHelper.valid_type?(value['location_groups'],
                        ->(val) { val.instance_of? Object })
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



70
71
72
73
# File 'lib/new_store_api/models/fulfillment_config_get_routing_rules_section_sample_response2.rb', line 70

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} location_groups: #{@location_groups.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



64
65
66
67
# File 'lib/new_store_api/models/fulfillment_config_get_routing_rules_section_sample_response2.rb', line 64

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} location_groups: #{@location_groups}>"
end