Class: NewStoreApi::FulfillmentConfigGetRoutingRulesSectionSampleResponse3

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/new_store_api/models/fulfillment_config_get_routing_rules_section_sample_response3.rb

Overview

FulfillmentConfigGetRoutingRulesSectionSampleResponse3 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(zip_code_regions = nil) ⇒ FulfillmentConfigGetRoutingRulesSectionSampleResponse3

Returns a new instance of FulfillmentConfigGetRoutingRulesSectionSampleResponse3.



34
35
36
# File 'lib/new_store_api/models/fulfillment_config_get_routing_rules_section_sample_response3.rb', line 34

def initialize(zip_code_regions = nil)
  @zip_code_regions = zip_code_regions
end

Instance Attribute Details

#zip_code_regionsHash[String, Object]

Zip code groups, in order to facilitate the identification routes per regions

Returns:

  • (Hash[String, Object])


15
16
17
# File 'lib/new_store_api/models/fulfillment_config_get_routing_rules_section_sample_response3.rb', line 15

def zip_code_regions
  @zip_code_regions
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



39
40
41
42
43
44
45
46
47
48
# File 'lib/new_store_api/models/fulfillment_config_get_routing_rules_section_sample_response3.rb', line 39

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  zip_code_regions =
    hash.key?('zip_code_regions') ? hash['zip_code_regions'] : nil

  # Create object from extracted values.
  FulfillmentConfigGetRoutingRulesSectionSampleResponse3.new(zip_code_regions)
end

.namesObject

A mapping from model property names to API property names.



18
19
20
21
22
# File 'lib/new_store_api/models/fulfillment_config_get_routing_rules_section_sample_response3.rb', line 18

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['zip_code_regions'] = 'zip_code_regions'
  @_hash
end

.nullablesObject

An array for nullable fields



30
31
32
# File 'lib/new_store_api/models/fulfillment_config_get_routing_rules_section_sample_response3.rb', line 30

def self.nullables
  []
end

.optionalsObject

An array for optional fields



25
26
27
# File 'lib/new_store_api/models/fulfillment_config_get_routing_rules_section_sample_response3.rb', line 25

def self.optionals
  []
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



52
53
54
55
56
57
58
59
60
61
62
# File 'lib/new_store_api/models/fulfillment_config_get_routing_rules_section_sample_response3.rb', line 52

def self.validate(value)
  if value.instance_of? self
    return APIHelper.valid_type?(value.zip_code_regions,
                                 ->(val) { val.instance_of? Object })
  end

  return false unless value.instance_of? Hash

  APIHelper.valid_type?(value['zip_code_regions'],
                        ->(val) { val.instance_of? Object })
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



71
72
73
74
# File 'lib/new_store_api/models/fulfillment_config_get_routing_rules_section_sample_response3.rb', line 71

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} zip_code_regions: #{@zip_code_regions.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



65
66
67
68
# File 'lib/new_store_api/models/fulfillment_config_get_routing_rules_section_sample_response3.rb', line 65

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} zip_code_regions: #{@zip_code_regions}>"
end