Class: NewStoreApi::FulfillmentTaskDocument
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- NewStoreApi::FulfillmentTaskDocument
- Defined in:
- lib/new_store_api/models/fulfillment_task_document.rb
Overview
FulfillmentTaskDocument Model.
Instance Attribute Summary collapse
-
#permalink ⇒ String
TODO: Write general description for this method.
-
#status ⇒ String
TODO: Write general description for this method.
-
#type ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(status = nil, type = nil, permalink = SKIP) ⇒ FulfillmentTaskDocument
constructor
A new instance of FulfillmentTaskDocument.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(status = nil, type = nil, permalink = SKIP) ⇒ FulfillmentTaskDocument
Returns a new instance of FulfillmentTaskDocument.
47 48 49 50 51 |
# File 'lib/new_store_api/models/fulfillment_task_document.rb', line 47 def initialize(status = nil, type = nil, permalink = SKIP) @permalink = permalink unless permalink == SKIP @status = status @type = type end |
Instance Attribute Details
#permalink ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/new_store_api/models/fulfillment_task_document.rb', line 14 def permalink @permalink end |
#status ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/new_store_api/models/fulfillment_task_document.rb', line 18 def status @status end |
#type ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/new_store_api/models/fulfillment_task_document.rb', line 22 def type @type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/new_store_api/models/fulfillment_task_document.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. status = hash.key?('status') ? hash['status'] : nil type = hash.key?('type') ? hash['type'] : nil permalink = hash.key?('permalink') ? hash['permalink'] : SKIP # Create object from extracted values. FulfillmentTaskDocument.new(status, type, permalink) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/new_store_api/models/fulfillment_task_document.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['permalink'] = 'permalink' @_hash['status'] = 'status' @_hash['type'] = 'type' @_hash end |
.nullables ⇒ Object
An array for nullable fields
41 42 43 44 45 |
# File 'lib/new_store_api/models/fulfillment_task_document.rb', line 41 def self.nullables %w[ permalink ] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 |
# File 'lib/new_store_api/models/fulfillment_task_document.rb', line 34 def self.optionals %w[ permalink ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
75 76 77 78 79 |
# File 'lib/new_store_api/models/fulfillment_task_document.rb', line 75 def inspect class_name = self.class.name.split('::').last "<#{class_name} permalink: #{@permalink.inspect}, status: #{@status.inspect}, type:"\ " #{@type.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
69 70 71 72 |
# File 'lib/new_store_api/models/fulfillment_task_document.rb', line 69 def to_s class_name = self.class.name.split('::').last "<#{class_name} permalink: #{@permalink}, status: #{@status}, type: #{@type}>" end |