Class: NewStoreApi::GetConfigResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/new_store_api/models/get_config_response.rb

Overview

Identity configuration.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(issuer = nil, providers = nil) ⇒ GetConfigResponse

Returns a new instance of GetConfigResponse.



39
40
41
42
# File 'lib/new_store_api/models/get_config_response.rb', line 39

def initialize(issuer = nil, providers = nil)
  @issuer = issuer
  @providers = providers
end

Instance Attribute Details

#issuerString

The URI of the issuer, for example: 'https://id.s.newstore.net/auth/realms/dodici'.

Returns:

  • (String)


15
16
17
# File 'lib/new_store_api/models/get_config_response.rb', line 15

def issuer
  @issuer
end

#providersArray[Provider]

A list of all brokered identity providers.

Returns:



19
20
21
# File 'lib/new_store_api/models/get_config_response.rb', line 19

def providers
  @providers
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/new_store_api/models/get_config_response.rb', line 45

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  issuer = hash.key?('issuer') ? hash['issuer'] : nil
  # Parameter is an array, so we need to iterate through it
  providers = nil
  unless hash['providers'].nil?
    providers = []
    hash['providers'].each do |structure|
      providers << (Provider.from_hash(structure) if structure)
    end
  end

  providers = nil unless hash.key?('providers')

  # Create object from extracted values.
  GetConfigResponse.new(issuer,
                        providers)
end

.namesObject

A mapping from model property names to API property names.



22
23
24
25
26
27
# File 'lib/new_store_api/models/get_config_response.rb', line 22

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['issuer'] = 'issuer'
  @_hash['providers'] = 'providers'
  @_hash
end

.nullablesObject

An array for nullable fields



35
36
37
# File 'lib/new_store_api/models/get_config_response.rb', line 35

def self.nullables
  []
end

.optionalsObject

An array for optional fields



30
31
32
# File 'lib/new_store_api/models/get_config_response.rb', line 30

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



73
74
75
76
# File 'lib/new_store_api/models/get_config_response.rb', line 73

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} issuer: #{@issuer.inspect}, providers: #{@providers.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



67
68
69
70
# File 'lib/new_store_api/models/get_config_response.rb', line 67

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} issuer: #{@issuer}, providers: #{@providers}>"
end