Class: NewStoreApi::GetResponse
- Defined in:
- lib/new_store_api/models/get_response.rb
Overview
GetResponse Model.
Instance Attribute Summary collapse
-
#code ⇒ String
An identifier of the reason code, pattern is '^[^+=%]+$'.
-
#localizations ⇒ Array[Localization]
An identifier of the reason code, pattern is '^[^+=%]+$'.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(code = nil, localizations = nil) ⇒ GetResponse
constructor
A new instance of GetResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(code = nil, localizations = nil) ⇒ GetResponse
Returns a new instance of GetResponse.
38 39 40 41 |
# File 'lib/new_store_api/models/get_response.rb', line 38 def initialize(code = nil, localizations = nil) @code = code @localizations = localizations end |
Instance Attribute Details
#code ⇒ String
An identifier of the reason code, pattern is '^[^+=%]+$'
14 15 16 |
# File 'lib/new_store_api/models/get_response.rb', line 14 def code @code end |
#localizations ⇒ Array[Localization]
An identifier of the reason code, pattern is '^[^+=%]+$'
18 19 20 |
# File 'lib/new_store_api/models/get_response.rb', line 18 def localizations @localizations end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/new_store_api/models/get_response.rb', line 44 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. code = hash.key?('code') ? hash['code'] : nil # Parameter is an array, so we need to iterate through it localizations = nil unless hash['localizations'].nil? localizations = [] hash['localizations'].each do |structure| localizations << (Localization.from_hash(structure) if structure) end end localizations = nil unless hash.key?('localizations') # Create object from extracted values. GetResponse.new(code, localizations) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/new_store_api/models/get_response.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['code'] = 'code' @_hash['localizations'] = 'localizations' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/new_store_api/models/get_response.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/new_store_api/models/get_response.rb', line 29 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
72 73 74 75 |
# File 'lib/new_store_api/models/get_response.rb', line 72 def inspect class_name = self.class.name.split('::').last "<#{class_name} code: #{@code.inspect}, localizations: #{@localizations.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
66 67 68 69 |
# File 'lib/new_store_api/models/get_response.rb', line 66 def to_s class_name = self.class.name.split('::').last "<#{class_name} code: #{@code}, localizations: #{@localizations}>" end |