Class: NewStoreApi::GetScopesResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/new_store_api/models/get_scopes_response.rb

Overview

A list of available scopes

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(items = SKIP, scopes = SKIP) ⇒ GetScopesResponse

Returns a new instance of GetScopesResponse.



41
42
43
44
# File 'lib/new_store_api/models/get_scopes_response.rb', line 41

def initialize(items = SKIP, scopes = SKIP)
  @items = items unless items == SKIP
  @scopes = scopes unless scopes == SKIP
end

Instance Attribute Details

#itemsArray[Item11]

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/new_store_api/models/get_scopes_response.rb', line 14

def items
  @items
end

#scopesArray[String]

TODO: Write general description for this method

Returns:

  • (Array[String])


18
19
20
# File 'lib/new_store_api/models/get_scopes_response.rb', line 18

def scopes
  @scopes
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/new_store_api/models/get_scopes_response.rb', line 47

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  items = nil
  unless hash['items'].nil?
    items = []
    hash['items'].each do |structure|
      items << (Item11.from_hash(structure) if structure)
    end
  end

  items = SKIP unless hash.key?('items')
  scopes = hash.key?('scopes') ? hash['scopes'] : SKIP

  # Create object from extracted values.
  GetScopesResponse.new(items,
                        scopes)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/new_store_api/models/get_scopes_response.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['items'] = 'items'
  @_hash['scopes'] = 'scopes'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/new_store_api/models/get_scopes_response.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/new_store_api/models/get_scopes_response.rb', line 29

def self.optionals
  %w[
    items
    scopes
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



75
76
77
78
# File 'lib/new_store_api/models/get_scopes_response.rb', line 75

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} items: #{@items.inspect}, scopes: #{@scopes.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



69
70
71
72
# File 'lib/new_store_api/models/get_scopes_response.rb', line 69

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} items: #{@items}, scopes: #{@scopes}>"
end