Class: NewStoreApi::GetUsersResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/new_store_api/models/get_users_response.rb

Overview

Gets all users

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(elements = SKIP, pagination_info = SKIP) ⇒ GetUsersResponse

Returns a new instance of GetUsersResponse.



41
42
43
44
# File 'lib/new_store_api/models/get_users_response.rb', line 41

def initialize(elements = SKIP, pagination_info = SKIP)
  @elements = elements unless elements == SKIP
  @pagination_info = pagination_info unless pagination_info == SKIP
end

Instance Attribute Details

#elementsArray[User]

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/new_store_api/models/get_users_response.rb', line 14

def elements
  @elements
end

#pagination_infoPaginatedResponse

Contains default fields for paginatable APIs.

Returns:



18
19
20
# File 'lib/new_store_api/models/get_users_response.rb', line 18

def pagination_info
  @pagination_info
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/new_store_api/models/get_users_response.rb', line 47

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  elements = nil
  unless hash['elements'].nil?
    elements = []
    hash['elements'].each do |structure|
      elements << (User.from_hash(structure) if structure)
    end
  end

  elements = SKIP unless hash.key?('elements')
  pagination_info = PaginatedResponse.from_hash(hash['pagination_info']) if
    hash['pagination_info']

  # Create object from extracted values.
  GetUsersResponse.new(elements,
                       pagination_info)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/new_store_api/models/get_users_response.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['elements'] = 'elements'
  @_hash['pagination_info'] = 'pagination_info'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/new_store_api/models/get_users_response.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/new_store_api/models/get_users_response.rb', line 29

def self.optionals
  %w[
    elements
    pagination_info
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



76
77
78
79
80
# File 'lib/new_store_api/models/get_users_response.rb', line 76

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} elements: #{@elements.inspect}, pagination_info:"\
  " #{@pagination_info.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



70
71
72
73
# File 'lib/new_store_api/models/get_users_response.rb', line 70

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} elements: #{@elements}, pagination_info: #{@pagination_info}>"
end