Class: NewStoreApi::InjectedOrderExtendedAttribute

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/new_store_api/models/injected_order_extended_attribute.rb

Overview

Extra information about the order, which is propagated through NewStore applications.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(name = nil, value = nil) ⇒ InjectedOrderExtendedAttribute

Returns a new instance of InjectedOrderExtendedAttribute.



39
40
41
42
# File 'lib/new_store_api/models/injected_order_extended_attribute.rb', line 39

def initialize(name = nil, value = nil)
  @name = name
  @value = value
end

Instance Attribute Details

#nameString

TODO: Write general description for this method

Returns:

  • (String)


15
16
17
# File 'lib/new_store_api/models/injected_order_extended_attribute.rb', line 15

def name
  @name
end

#valueString

TODO: Write general description for this method

Returns:

  • (String)


19
20
21
# File 'lib/new_store_api/models/injected_order_extended_attribute.rb', line 19

def value
  @value
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



45
46
47
48
49
50
51
52
53
54
55
# File 'lib/new_store_api/models/injected_order_extended_attribute.rb', line 45

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  name = hash.key?('name') ? hash['name'] : nil
  value = hash.key?('value') ? hash['value'] : nil

  # Create object from extracted values.
  InjectedOrderExtendedAttribute.new(name,
                                     value)
end

.namesObject

A mapping from model property names to API property names.



22
23
24
25
26
27
# File 'lib/new_store_api/models/injected_order_extended_attribute.rb', line 22

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['name'] = 'name'
  @_hash['value'] = 'value'
  @_hash
end

.nullablesObject

An array for nullable fields



35
36
37
# File 'lib/new_store_api/models/injected_order_extended_attribute.rb', line 35

def self.nullables
  []
end

.optionalsObject

An array for optional fields



30
31
32
# File 'lib/new_store_api/models/injected_order_extended_attribute.rb', line 30

def self.optionals
  []
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/new_store_api/models/injected_order_extended_attribute.rb', line 59

def self.validate(value)
  if value.instance_of? self
    return (
      APIHelper.valid_type?(value.name,
                            ->(val) { val.instance_of? String }) and
        APIHelper.valid_type?(value.value,
                              ->(val) { val.instance_of? String })
    )
  end

  return false unless value.instance_of? Hash

  (
    APIHelper.valid_type?(value['name'],
                          ->(val) { val.instance_of? String }) and
      APIHelper.valid_type?(value['value'],
                            ->(val) { val.instance_of? String })
  )
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



86
87
88
89
# File 'lib/new_store_api/models/injected_order_extended_attribute.rb', line 86

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} name: #{@name.inspect}, value: #{@value.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



80
81
82
83
# File 'lib/new_store_api/models/injected_order_extended_attribute.rb', line 80

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} name: #{@name}, value: #{@value}>"
end