Class: NewStoreApi::InjectedOrderRoutingStrategy

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/new_store_api/models/injected_order_routing_strategy.rb

Overview

InjectedOrderRoutingStrategy Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initializeInjectedOrderRoutingStrategy

Returns a new instance of InjectedOrderRoutingStrategy.



34
35
36
# File 'lib/new_store_api/models/injected_order_routing_strategy.rb', line 34

def initialize
  @strategy = 'default'
end

Instance Attribute Details

#strategyString (readonly)

The default routing strategy that NewStore uses to determine the best fulfillment location, based on the fulfillment config.

Returns:

  • (String)


15
16
17
# File 'lib/new_store_api/models/injected_order_routing_strategy.rb', line 15

def strategy
  @strategy
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



39
40
41
42
43
44
45
46
47
# File 'lib/new_store_api/models/injected_order_routing_strategy.rb', line 39

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.


  # Create object from extracted values.
  InjectedOrderRoutingStrategy.new
end

.namesObject

A mapping from model property names to API property names.



18
19
20
21
22
# File 'lib/new_store_api/models/injected_order_routing_strategy.rb', line 18

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['strategy'] = 'strategy'
  @_hash
end

.nullablesObject

An array for nullable fields



30
31
32
# File 'lib/new_store_api/models/injected_order_routing_strategy.rb', line 30

def self.nullables
  []
end

.optionalsObject

An array for optional fields



25
26
27
# File 'lib/new_store_api/models/injected_order_routing_strategy.rb', line 25

def self.optionals
  []
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



51
52
53
54
55
56
57
58
59
60
61
# File 'lib/new_store_api/models/injected_order_routing_strategy.rb', line 51

def self.validate(value)
  if value.instance_of? self
    return APIHelper.valid_type?(value.strategy,
                                 ->(val) { val.instance_of? String })
  end

  return false unless value.instance_of? Hash

  APIHelper.valid_type?(value['strategy'],
                        ->(val) { val.instance_of? String })
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



70
71
72
73
# File 'lib/new_store_api/models/injected_order_routing_strategy.rb', line 70

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} strategy: #{@strategy.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



64
65
66
67
# File 'lib/new_store_api/models/injected_order_routing_strategy.rb', line 64

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} strategy: #{@strategy}>"
end