Class: NewStoreApi::Item21

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/new_store_api/models/item21.rb

Overview

A combination of item id (Sales Order Item UUID) and action to be taken to this item (reroute/cancel or swap).

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(action = nil, item_id = nil) ⇒ Item21

Returns a new instance of Item21.



39
40
41
42
# File 'lib/new_store_api/models/item21.rb', line 39

def initialize(action = nil, item_id = nil)
  @action = action
  @item_id = item_id
end

Instance Attribute Details

#actionActionEnum

Action to be performed with the item(reroute, cancel).

Returns:



15
16
17
# File 'lib/new_store_api/models/item21.rb', line 15

def action
  @action
end

#item_idString

Identifier (Sales Order Item UUID) of a single item in logistic order.

Returns:

  • (String)


19
20
21
# File 'lib/new_store_api/models/item21.rb', line 19

def item_id
  @item_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



45
46
47
48
49
50
51
52
53
54
55
# File 'lib/new_store_api/models/item21.rb', line 45

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  action = hash.key?('action') ? hash['action'] : nil
  item_id = hash.key?('item_id') ? hash['item_id'] : nil

  # Create object from extracted values.
  Item21.new(action,
             item_id)
end

.namesObject

A mapping from model property names to API property names.



22
23
24
25
26
27
# File 'lib/new_store_api/models/item21.rb', line 22

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['action'] = 'action'
  @_hash['item_id'] = 'item_id'
  @_hash
end

.nullablesObject

An array for nullable fields



35
36
37
# File 'lib/new_store_api/models/item21.rb', line 35

def self.nullables
  []
end

.optionalsObject

An array for optional fields



30
31
32
# File 'lib/new_store_api/models/item21.rb', line 30

def self.optionals
  []
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:

  • The (Item21 | Hash)

    value against the validation is performed.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/new_store_api/models/item21.rb', line 59

def self.validate(value)
  if value.instance_of? self
    return (
      APIHelper.valid_type?(value.action,
                            ->(val) { ActionEnum.validate(val) }) and
        APIHelper.valid_type?(value.item_id,
                              ->(val) { val.instance_of? String })
    )
  end

  return false unless value.instance_of? Hash

  (
    APIHelper.valid_type?(value['action'],
                          ->(val) { ActionEnum.validate(val) }) and
      APIHelper.valid_type?(value['item_id'],
                            ->(val) { val.instance_of? String })
  )
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



86
87
88
89
# File 'lib/new_store_api/models/item21.rb', line 86

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} action: #{@action.inspect}, item_id: #{@item_id.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



80
81
82
83
# File 'lib/new_store_api/models/item21.rb', line 80

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} action: #{@action}, item_id: #{@item_id}>"
end