Class: NewStoreApi::Item3
- Defined in:
- lib/new_store_api/models/item3.rb
Overview
Item3 Model.
Instance Attribute Summary collapse
-
#id ⇒ String
The identifier of the item.
-
#type ⇒ String
readonly
The identifier of the item.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(id = nil) ⇒ Item3
constructor
A new instance of Item3.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(id = nil) ⇒ Item3
Returns a new instance of Item3.
38 39 40 41 |
# File 'lib/new_store_api/models/item3.rb', line 38 def initialize(id = nil) @id = id @type = 'product' end |
Instance Attribute Details
#id ⇒ String
The identifier of the item.
14 15 16 |
# File 'lib/new_store_api/models/item3.rb', line 14 def id @id end |
#type ⇒ String (readonly)
The identifier of the item.
18 19 20 |
# File 'lib/new_store_api/models/item3.rb', line 18 def type @type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
44 45 46 47 48 49 50 51 52 |
# File 'lib/new_store_api/models/item3.rb', line 44 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. id = hash.key?('id') ? hash['id'] : nil # Create object from extracted values. Item3.new(id) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/new_store_api/models/item3.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['id'] = 'id' @_hash['type'] = 'type' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/new_store_api/models/item3.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/new_store_api/models/item3.rb', line 29 def self.optionals [] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/new_store_api/models/item3.rb', line 56 def self.validate(value) if value.instance_of? self return ( APIHelper.valid_type?(value.id, ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value.type, ->(val) { val.instance_of? String }) ) end return false unless value.instance_of? Hash ( APIHelper.valid_type?(value['id'], ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value['type'], ->(val) { val.instance_of? String }) ) end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
83 84 85 86 |
# File 'lib/new_store_api/models/item3.rb', line 83 def inspect class_name = self.class.name.split('::').last "<#{class_name} id: #{@id.inspect}, type: #{@type.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
77 78 79 80 |
# File 'lib/new_store_api/models/item3.rb', line 77 def to_s class_name = self.class.name.split('::').last "<#{class_name} id: #{@id}, type: #{@type}>" end |