Class: NewStoreApi::Link
- Defined in:
- lib/new_store_api/models/link.rb
Overview
Link Model.
Instance Attribute Summary collapse
-
#href ⇒ String
Resource URI.
-
#method ⇒ String
Request method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(href = nil, method = SKIP) ⇒ Link
constructor
A new instance of Link.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(href = nil, method = SKIP) ⇒ Link
Returns a new instance of Link.
40 41 42 43 |
# File 'lib/new_store_api/models/link.rb', line 40 def initialize(href = nil, method = SKIP) @href = href @method = method unless method == SKIP end |
Instance Attribute Details
#href ⇒ String
Resource URI
14 15 16 |
# File 'lib/new_store_api/models/link.rb', line 14 def href @href end |
#method ⇒ String
Request method
18 19 20 |
# File 'lib/new_store_api/models/link.rb', line 18 def method @method end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/new_store_api/models/link.rb', line 46 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. href = hash.key?('href') ? hash['href'] : nil method = hash.key?('method') ? hash['method'] : SKIP # Create object from extracted values. Link.new(href, method) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/new_store_api/models/link.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['href'] = 'href' @_hash['method'] = 'method' @_hash end |
.nullables ⇒ Object
An array for nullable fields
36 37 38 |
# File 'lib/new_store_api/models/link.rb', line 36 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 |
# File 'lib/new_store_api/models/link.rb', line 29 def self.optionals %w[ method ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
65 66 67 68 |
# File 'lib/new_store_api/models/link.rb', line 65 def inspect class_name = self.class.name.split('::').last "<#{class_name} href: #{@href.inspect}, method: #{@method.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
59 60 61 62 |
# File 'lib/new_store_api/models/link.rb', line 59 def to_s class_name = self.class.name.split('::').last "<#{class_name} href: #{@href}, method: #{@method}>" end |