Class: NewStoreApi::ListAddressesResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- NewStoreApi::ListAddressesResponse
- Defined in:
- lib/new_store_api/models/list_addresses_response.rb
Overview
List addresses response
Instance Attribute Summary collapse
-
#addresses ⇒ Array[AddressResponse]
TODO: Write general description for this method.
-
#pagination_info ⇒ PaginationInfo
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(addresses = nil, pagination_info = nil) ⇒ ListAddressesResponse
constructor
A new instance of ListAddressesResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(addresses = nil, pagination_info = nil) ⇒ ListAddressesResponse
Returns a new instance of ListAddressesResponse.
38 39 40 41 |
# File 'lib/new_store_api/models/list_addresses_response.rb', line 38 def initialize(addresses = nil, pagination_info = nil) @addresses = addresses @pagination_info = pagination_info end |
Instance Attribute Details
#addresses ⇒ Array[AddressResponse]
TODO: Write general description for this method
14 15 16 |
# File 'lib/new_store_api/models/list_addresses_response.rb', line 14 def addresses @addresses end |
#pagination_info ⇒ PaginationInfo
TODO: Write general description for this method
18 19 20 |
# File 'lib/new_store_api/models/list_addresses_response.rb', line 18 def pagination_info @pagination_info end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/new_store_api/models/list_addresses_response.rb', line 44 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it addresses = nil unless hash['addresses'].nil? addresses = [] hash['addresses'].each do |structure| addresses << (AddressResponse.from_hash(structure) if structure) end end addresses = nil unless hash.key?('addresses') pagination_info = PaginationInfo.from_hash(hash['pagination_info']) if hash['pagination_info'] # Create object from extracted values. ListAddressesResponse.new(addresses, pagination_info) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/new_store_api/models/list_addresses_response.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['addresses'] = 'addresses' @_hash['pagination_info'] = 'pagination_info' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/new_store_api/models/list_addresses_response.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/new_store_api/models/list_addresses_response.rb', line 29 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
73 74 75 76 77 |
# File 'lib/new_store_api/models/list_addresses_response.rb', line 73 def inspect class_name = self.class.name.split('::').last "<#{class_name} addresses: #{@addresses.inspect}, pagination_info:"\ " #{@pagination_info.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
67 68 69 70 |
# File 'lib/new_store_api/models/list_addresses_response.rb', line 67 def to_s class_name = self.class.name.split('::').last "<#{class_name} addresses: #{@addresses}, pagination_info: #{@pagination_info}>" end |