Class: NewStoreApi::ListReservationsResponseV1
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- NewStoreApi::ListReservationsResponseV1
- Defined in:
- lib/new_store_api/models/list_reservations_response_v1.rb
Overview
ListReservationsResponseV1 Model.
Instance Attribute Summary collapse
-
#items ⇒ Array[ReservationSummaryResponseV1]
List of reservations.
-
#pagination_info ⇒ ReservationsPaginationInfo
List of reservations.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(items = nil, pagination_info = nil) ⇒ ListReservationsResponseV1
constructor
A new instance of ListReservationsResponseV1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(items = nil, pagination_info = nil) ⇒ ListReservationsResponseV1
Returns a new instance of ListReservationsResponseV1.
38 39 40 41 |
# File 'lib/new_store_api/models/list_reservations_response_v1.rb', line 38 def initialize(items = nil, pagination_info = nil) @items = items @pagination_info = pagination_info end |
Instance Attribute Details
#items ⇒ Array[ReservationSummaryResponseV1]
List of reservations.
14 15 16 |
# File 'lib/new_store_api/models/list_reservations_response_v1.rb', line 14 def items @items end |
#pagination_info ⇒ ReservationsPaginationInfo
List of reservations.
18 19 20 |
# File 'lib/new_store_api/models/list_reservations_response_v1.rb', line 18 def pagination_info @pagination_info end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/new_store_api/models/list_reservations_response_v1.rb', line 44 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it items = nil unless hash['items'].nil? items = [] hash['items'].each do |structure| items << (ReservationSummaryResponseV1.from_hash(structure) if structure) end end items = nil unless hash.key?('items') pagination_info = ReservationsPaginationInfo.from_hash(hash['pagination_info']) if hash['pagination_info'] # Create object from extracted values. ListReservationsResponseV1.new(items, pagination_info) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/new_store_api/models/list_reservations_response_v1.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['items'] = 'items' @_hash['pagination_info'] = 'pagination_info' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/new_store_api/models/list_reservations_response_v1.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/new_store_api/models/list_reservations_response_v1.rb', line 29 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
73 74 75 76 |
# File 'lib/new_store_api/models/list_reservations_response_v1.rb', line 73 def inspect class_name = self.class.name.split('::').last "<#{class_name} items: #{@items.inspect}, pagination_info: #{@pagination_info.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
67 68 69 70 |
# File 'lib/new_store_api/models/list_reservations_response_v1.rb', line 67 def to_s class_name = self.class.name.split('::').last "<#{class_name} items: #{@items}, pagination_info: #{@pagination_info}>" end |