Class: NewStoreApi::ListResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/new_store_api/models/list_response.rb

Overview

ListResponse Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(codes = nil) ⇒ ListResponse

Returns a new instance of ListResponse.



33
34
35
# File 'lib/new_store_api/models/list_response.rb', line 33

def initialize(codes = nil)
  @codes = codes
end

Instance Attribute Details

#codesArray[LocalizedReasonCode]

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/new_store_api/models/list_response.rb', line 14

def codes
  @codes
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
# File 'lib/new_store_api/models/list_response.rb', line 38

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  codes = nil
  unless hash['codes'].nil?
    codes = []
    hash['codes'].each do |structure|
      codes << (LocalizedReasonCode.from_hash(structure) if structure)
    end
  end

  codes = nil unless hash.key?('codes')

  # Create object from extracted values.
  ListResponse.new(codes)
end

.namesObject

A mapping from model property names to API property names.



17
18
19
20
21
# File 'lib/new_store_api/models/list_response.rb', line 17

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['codes'] = 'codes'
  @_hash
end

.nullablesObject

An array for nullable fields



29
30
31
# File 'lib/new_store_api/models/list_response.rb', line 29

def self.nullables
  []
end

.optionalsObject

An array for optional fields



24
25
26
# File 'lib/new_store_api/models/list_response.rb', line 24

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



64
65
66
67
# File 'lib/new_store_api/models/list_response.rb', line 64

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} codes: #{@codes.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



58
59
60
61
# File 'lib/new_store_api/models/list_response.rb', line 58

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} codes: #{@codes}>"
end