Class: NewStoreApi::Localization

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/new_store_api/models/localization.rb

Overview

Localization Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(locale = nil, name = nil) ⇒ Localization

Returns a new instance of Localization.



38
39
40
41
# File 'lib/new_store_api/models/localization.rb', line 38

def initialize(locale = nil, name = nil)
  @locale = locale
  @name = name
end

Instance Attribute Details

#localeString

The locale of the reason code, pattern is '(^[a-z]2-[A-Za-z]2$)'

Returns:

  • (String)


14
15
16
# File 'lib/new_store_api/models/localization.rb', line 14

def locale
  @locale
end

#nameString

The name of the reason code.

Returns:

  • (String)


18
19
20
# File 'lib/new_store_api/models/localization.rb', line 18

def name
  @name
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



44
45
46
47
48
49
50
51
52
53
54
# File 'lib/new_store_api/models/localization.rb', line 44

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  locale = hash.key?('locale') ? hash['locale'] : nil
  name = hash.key?('name') ? hash['name'] : nil

  # Create object from extracted values.
  Localization.new(locale,
                   name)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/new_store_api/models/localization.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['locale'] = 'locale'
  @_hash['name'] = 'name'
  @_hash
end

.nullablesObject

An array for nullable fields



34
35
36
# File 'lib/new_store_api/models/localization.rb', line 34

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
# File 'lib/new_store_api/models/localization.rb', line 29

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



63
64
65
66
# File 'lib/new_store_api/models/localization.rb', line 63

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} locale: #{@locale.inspect}, name: #{@name.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



57
58
59
60
# File 'lib/new_store_api/models/localization.rb', line 57

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} locale: #{@locale}, name: #{@name}>"
end