Class: NewStoreApi::LocationMapping
- Defined in:
- lib/new_store_api/models/location_mapping.rb
Overview
LocationMapping Model.
Instance Attribute Summary collapse
-
#connected_account_id ⇒ String
TODO: Write general description for this method.
-
#environment ⇒ String
TODO: Write general description for this method.
-
#location_id ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(connected_account_id = nil, environment = nil, location_id = nil) ⇒ LocationMapping
constructor
A new instance of LocationMapping.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(connected_account_id = nil, environment = nil, location_id = nil) ⇒ LocationMapping
Returns a new instance of LocationMapping.
43 44 45 46 47 48 |
# File 'lib/new_store_api/models/location_mapping.rb', line 43 def initialize(connected_account_id = nil, environment = nil, location_id = nil) @connected_account_id = connected_account_id @environment = environment @location_id = location_id end |
Instance Attribute Details
#connected_account_id ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/new_store_api/models/location_mapping.rb', line 14 def connected_account_id @connected_account_id end |
#environment ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/new_store_api/models/location_mapping.rb', line 18 def environment @environment end |
#location_id ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/new_store_api/models/location_mapping.rb', line 22 def location_id @location_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/new_store_api/models/location_mapping.rb', line 51 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. connected_account_id = hash.key?('connected_account_id') ? hash['connected_account_id'] : nil environment = hash.key?('environment') ? hash['environment'] : nil location_id = hash.key?('location_id') ? hash['location_id'] : nil # Create object from extracted values. LocationMapping.new(connected_account_id, environment, location_id) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/new_store_api/models/location_mapping.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['connected_account_id'] = 'connected_account_id' @_hash['environment'] = 'environment' @_hash['location_id'] = 'location_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/new_store_api/models/location_mapping.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/new_store_api/models/location_mapping.rb', line 34 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
74 75 76 77 78 |
# File 'lib/new_store_api/models/location_mapping.rb', line 74 def inspect class_name = self.class.name.split('::').last "<#{class_name} connected_account_id: #{@connected_account_id.inspect}, environment:"\ " #{@environment.inspect}, location_id: #{@location_id.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
67 68 69 70 71 |
# File 'lib/new_store_api/models/location_mapping.rb', line 67 def to_s class_name = self.class.name.split('::').last "<#{class_name} connected_account_id: #{@connected_account_id}, environment:"\ " #{@environment}, location_id: #{@location_id}>" end |