Class: NewStoreApi::MoveOrCopy

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/new_store_api/models/move_or_copy.rb

Overview

MoveOrCopy Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(from = nil, op = nil, path = nil) ⇒ MoveOrCopy

Returns a new instance of MoveOrCopy.



43
44
45
46
47
# File 'lib/new_store_api/models/move_or_copy.rb', line 43

def initialize(from = nil, op = nil, path = nil)
  @from = from
  @op = op
  @path = path
end

Instance Attribute Details

#fromString

A JSON Pointer path pointing to the location to move/copy from.

Returns:

  • (String)


14
15
16
# File 'lib/new_store_api/models/move_or_copy.rb', line 14

def from
  @from
end

#opOp1Enum

The operation to perform.

Returns:



18
19
20
# File 'lib/new_store_api/models/move_or_copy.rb', line 18

def op
  @op
end

#pathString

A JSON Pointer path.

Returns:

  • (String)


22
23
24
# File 'lib/new_store_api/models/move_or_copy.rb', line 22

def path
  @path
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/new_store_api/models/move_or_copy.rb', line 50

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  from = hash.key?('from') ? hash['from'] : nil
  op = hash.key?('op') ? hash['op'] : nil
  path = hash.key?('path') ? hash['path'] : nil

  # Create object from extracted values.
  MoveOrCopy.new(from,
                 op,
                 path)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/new_store_api/models/move_or_copy.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['from'] = 'from'
  @_hash['op'] = 'op'
  @_hash['path'] = 'path'
  @_hash
end

.nullablesObject

An array for nullable fields



39
40
41
# File 'lib/new_store_api/models/move_or_copy.rb', line 39

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
# File 'lib/new_store_api/models/move_or_copy.rb', line 34

def self.optionals
  []
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:

  • The (MoveOrCopy | Hash)

    value against the validation is performed.



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/new_store_api/models/move_or_copy.rb', line 66

def self.validate(value)
  if value.instance_of? self
    return (
      APIHelper.valid_type?(value.from,
                            ->(val) { val.instance_of? String }) and
        APIHelper.valid_type?(value.op,
                              ->(val) { Op1Enum.validate(val) }) and
        APIHelper.valid_type?(value.path,
                              ->(val) { val.instance_of? String })
    )
  end

  return false unless value.instance_of? Hash

  (
    APIHelper.valid_type?(value['from'],
                          ->(val) { val.instance_of? String }) and
      APIHelper.valid_type?(value['op'],
                            ->(val) { Op1Enum.validate(val) }) and
      APIHelper.valid_type?(value['path'],
                            ->(val) { val.instance_of? String })
  )
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



97
98
99
100
# File 'lib/new_store_api/models/move_or_copy.rb', line 97

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} from: #{@from.inspect}, op: #{@op.inspect}, path: #{@path.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



91
92
93
94
# File 'lib/new_store_api/models/move_or_copy.rb', line 91

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} from: #{@from}, op: #{@op}, path: #{@path}>"
end