Class: NewStoreApi::NotRoutedItemResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- NewStoreApi::NotRoutedItemResponse
- Defined in:
- lib/new_store_api/models/not_routed_item_response.rb
Overview
Line item that could not be routed.
Instance Attribute Summary collapse
-
#item_id ⇒ String
Line item identifier from the request.
-
#reason ⇒ String
Reason the line item could not be routed.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(item_id = nil, reason = nil) ⇒ NotRoutedItemResponse
constructor
A new instance of NotRoutedItemResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(item_id = nil, reason = nil) ⇒ NotRoutedItemResponse
Returns a new instance of NotRoutedItemResponse.
38 39 40 41 |
# File 'lib/new_store_api/models/not_routed_item_response.rb', line 38 def initialize(item_id = nil, reason = nil) @item_id = item_id @reason = reason end |
Instance Attribute Details
#item_id ⇒ String
Line item identifier from the request.
14 15 16 |
# File 'lib/new_store_api/models/not_routed_item_response.rb', line 14 def item_id @item_id end |
#reason ⇒ String
Reason the line item could not be routed.
18 19 20 |
# File 'lib/new_store_api/models/not_routed_item_response.rb', line 18 def reason @reason end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/new_store_api/models/not_routed_item_response.rb', line 44 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. item_id = hash.key?('item_id') ? hash['item_id'] : nil reason = hash.key?('reason') ? hash['reason'] : nil # Create object from extracted values. NotRoutedItemResponse.new(item_id, reason) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/new_store_api/models/not_routed_item_response.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['item_id'] = 'item_id' @_hash['reason'] = 'reason' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/new_store_api/models/not_routed_item_response.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/new_store_api/models/not_routed_item_response.rb', line 29 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
63 64 65 66 |
# File 'lib/new_store_api/models/not_routed_item_response.rb', line 63 def inspect class_name = self.class.name.split('::').last "<#{class_name} item_id: #{@item_id.inspect}, reason: #{@reason.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
57 58 59 60 |
# File 'lib/new_store_api/models/not_routed_item_response.rb', line 57 def to_s class_name = self.class.name.split('::').last "<#{class_name} item_id: #{@item_id}, reason: #{@reason}>" end |