Class: NewStoreApi::OfflineCountriesConfigUpdateV1Dto
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- NewStoreApi::OfflineCountriesConfigUpdateV1Dto
- Defined in:
- lib/new_store_api/models/offline_countries_config_update_v1_dto.rb
Overview
OfflineCountriesConfigUpdateV1Dto Model.
Instance Attribute Summary collapse
-
#at ⇒ OfflineCountryConfigV1Dto
Per country offline mode configuration for Austria.
-
#de ⇒ OfflineCountryConfigV1Dto
Per country offline mode configuration for Germany.
-
#es ⇒ OfflineCountryConfigV1Dto
Per country offline mode configuration for Spain.
-
#fr ⇒ OfflineCountryConfigV1Dto
Per country offline mode configuration for France.
-
#ie ⇒ OfflineCountryConfigV1Dto
Per country offline mode configuration for Ireland.
-
#it ⇒ OfflineCountryConfigV1Dto
Per country offline mode configuration for Italy.
-
#mc ⇒ OfflineCountryConfigV1Dto
Per country offline mode configuration for Monaco.
-
#min ⇒ OfflineCountryConfigV1Dto
Per country offline mode configuration for India.
-
#pl ⇒ OfflineCountryConfigV1Dto
Per country offline mode configuration for Poland.
-
#pr ⇒ OfflineCountryConfigV1Dto
Per country offline mode configuration for Puerto Rico.
-
#th ⇒ OfflineCountryConfigV1Dto
Per country offline mode configuration for Thailand.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(at = SKIP, de = SKIP, es = SKIP, fr = SKIP, ie = SKIP, min = SKIP, it = SKIP, mc = SKIP, pl = SKIP, pr = SKIP, th = SKIP) ⇒ OfflineCountriesConfigUpdateV1Dto
constructor
A new instance of OfflineCountriesConfigUpdateV1Dto.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(at = SKIP, de = SKIP, es = SKIP, fr = SKIP, ie = SKIP, min = SKIP, it = SKIP, mc = SKIP, pl = SKIP, pr = SKIP, th = SKIP) ⇒ OfflineCountriesConfigUpdateV1Dto
Returns a new instance of OfflineCountriesConfigUpdateV1Dto.
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/new_store_api/models/offline_countries_config_update_v1_dto.rb', line 95 def initialize(at = SKIP, de = SKIP, es = SKIP, fr = SKIP, ie = SKIP, min = SKIP, it = SKIP, mc = SKIP, pl = SKIP, pr = SKIP, th = SKIP) @at = at unless at == SKIP @de = de unless de == SKIP @es = es unless es == SKIP @fr = fr unless fr == SKIP @ie = ie unless ie == SKIP @min = min unless min == SKIP @it = it unless it == SKIP @mc = mc unless mc == SKIP @pl = pl unless pl == SKIP @pr = pr unless pr == SKIP @th = th unless th == SKIP end |
Instance Attribute Details
#at ⇒ OfflineCountryConfigV1Dto
Per country offline mode configuration for Austria.
14 15 16 |
# File 'lib/new_store_api/models/offline_countries_config_update_v1_dto.rb', line 14 def at @at end |
#de ⇒ OfflineCountryConfigV1Dto
Per country offline mode configuration for Germany.
18 19 20 |
# File 'lib/new_store_api/models/offline_countries_config_update_v1_dto.rb', line 18 def de @de end |
#es ⇒ OfflineCountryConfigV1Dto
Per country offline mode configuration for Spain.
22 23 24 |
# File 'lib/new_store_api/models/offline_countries_config_update_v1_dto.rb', line 22 def es @es end |
#fr ⇒ OfflineCountryConfigV1Dto
Per country offline mode configuration for France.
26 27 28 |
# File 'lib/new_store_api/models/offline_countries_config_update_v1_dto.rb', line 26 def fr @fr end |
#ie ⇒ OfflineCountryConfigV1Dto
Per country offline mode configuration for Ireland.
30 31 32 |
# File 'lib/new_store_api/models/offline_countries_config_update_v1_dto.rb', line 30 def ie @ie end |
#it ⇒ OfflineCountryConfigV1Dto
Per country offline mode configuration for Italy.
38 39 40 |
# File 'lib/new_store_api/models/offline_countries_config_update_v1_dto.rb', line 38 def it @it end |
#mc ⇒ OfflineCountryConfigV1Dto
Per country offline mode configuration for Monaco.
42 43 44 |
# File 'lib/new_store_api/models/offline_countries_config_update_v1_dto.rb', line 42 def mc @mc end |
#min ⇒ OfflineCountryConfigV1Dto
Per country offline mode configuration for India
34 35 36 |
# File 'lib/new_store_api/models/offline_countries_config_update_v1_dto.rb', line 34 def min @min end |
#pl ⇒ OfflineCountryConfigV1Dto
Per country offline mode configuration for Poland.
46 47 48 |
# File 'lib/new_store_api/models/offline_countries_config_update_v1_dto.rb', line 46 def pl @pl end |
#pr ⇒ OfflineCountryConfigV1Dto
Per country offline mode configuration for Puerto Rico.
50 51 52 |
# File 'lib/new_store_api/models/offline_countries_config_update_v1_dto.rb', line 50 def pr @pr end |
#th ⇒ OfflineCountryConfigV1Dto
Per country offline mode configuration for Thailand.
54 55 56 |
# File 'lib/new_store_api/models/offline_countries_config_update_v1_dto.rb', line 54 def th @th end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/new_store_api/models/offline_countries_config_update_v1_dto.rb', line 112 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. at = OfflineCountryConfigV1Dto.from_hash(hash['AT']) if hash['AT'] de = OfflineCountryConfigV1Dto.from_hash(hash['DE']) if hash['DE'] es = OfflineCountryConfigV1Dto.from_hash(hash['ES']) if hash['ES'] fr = OfflineCountryConfigV1Dto.from_hash(hash['FR']) if hash['FR'] ie = OfflineCountryConfigV1Dto.from_hash(hash['IE']) if hash['IE'] min = OfflineCountryConfigV1Dto.from_hash(hash['IN']) if hash['IN'] it = OfflineCountryConfigV1Dto.from_hash(hash['IT']) if hash['IT'] mc = OfflineCountryConfigV1Dto.from_hash(hash['MC']) if hash['MC'] pl = OfflineCountryConfigV1Dto.from_hash(hash['PL']) if hash['PL'] pr = OfflineCountryConfigV1Dto.from_hash(hash['PR']) if hash['PR'] th = OfflineCountryConfigV1Dto.from_hash(hash['TH']) if hash['TH'] # Create object from extracted values. OfflineCountriesConfigUpdateV1Dto.new(at, de, es, fr, ie, min, it, mc, pl, pr, th) end |
.names ⇒ Object
A mapping from model property names to API property names.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/new_store_api/models/offline_countries_config_update_v1_dto.rb', line 57 def self.names @_hash = {} if @_hash.nil? @_hash['at'] = 'AT' @_hash['de'] = 'DE' @_hash['es'] = 'ES' @_hash['fr'] = 'FR' @_hash['ie'] = 'IE' @_hash['min'] = 'IN' @_hash['it'] = 'IT' @_hash['mc'] = 'MC' @_hash['pl'] = 'PL' @_hash['pr'] = 'PR' @_hash['th'] = 'TH' @_hash end |
.nullables ⇒ Object
An array for nullable fields
91 92 93 |
# File 'lib/new_store_api/models/offline_countries_config_update_v1_dto.rb', line 91 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/new_store_api/models/offline_countries_config_update_v1_dto.rb', line 74 def self.optionals %w[ at de es fr ie min it mc pl pr th ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
150 151 152 153 154 155 |
# File 'lib/new_store_api/models/offline_countries_config_update_v1_dto.rb', line 150 def inspect class_name = self.class.name.split('::').last "<#{class_name} at: #{@at.inspect}, de: #{@de.inspect}, es: #{@es.inspect}, fr:"\ " #{@fr.inspect}, ie: #{@ie.inspect}, min: #{@min.inspect}, it: #{@it.inspect}, mc:"\ " #{@mc.inspect}, pl: #{@pl.inspect}, pr: #{@pr.inspect}, th: #{@th.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
143 144 145 146 147 |
# File 'lib/new_store_api/models/offline_countries_config_update_v1_dto.rb', line 143 def to_s class_name = self.class.name.split('::').last "<#{class_name} at: #{@at}, de: #{@de}, es: #{@es}, fr: #{@fr}, ie: #{@ie}, min: #{@min},"\ " it: #{@it}, mc: #{@mc}, pl: #{@pl}, pr: #{@pr}, th: #{@th}>" end |