Class: NewStoreApi::OfflineCountriesResponseV1Dto
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- NewStoreApi::OfflineCountriesResponseV1Dto
- Defined in:
- lib/new_store_api/models/offline_countries_response_v1_dto.rb
Overview
OfflineCountriesResponseV1Dto Model.
Instance Attribute Summary collapse
-
#offline_countries ⇒ OfflineCountriesConfigV1Dto
Per country offline mode configuration.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(offline_countries = nil) ⇒ OfflineCountriesResponseV1Dto
constructor
A new instance of OfflineCountriesResponseV1Dto.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(offline_countries = nil) ⇒ OfflineCountriesResponseV1Dto
Returns a new instance of OfflineCountriesResponseV1Dto.
33 34 35 |
# File 'lib/new_store_api/models/offline_countries_response_v1_dto.rb', line 33 def initialize(offline_countries = nil) @offline_countries = offline_countries end |
Instance Attribute Details
#offline_countries ⇒ OfflineCountriesConfigV1Dto
Per country offline mode configuration.
14 15 16 |
# File 'lib/new_store_api/models/offline_countries_response_v1_dto.rb', line 14 def offline_countries @offline_countries end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
38 39 40 41 42 43 44 45 46 47 |
# File 'lib/new_store_api/models/offline_countries_response_v1_dto.rb', line 38 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. offline_countries = OfflineCountriesConfigV1Dto.from_hash(hash['offline_countries']) if hash['offline_countries'] # Create object from extracted values. OfflineCountriesResponseV1Dto.new(offline_countries) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/new_store_api/models/offline_countries_response_v1_dto.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['offline_countries'] = 'offline_countries' @_hash end |
.nullables ⇒ Object
An array for nullable fields
29 30 31 |
# File 'lib/new_store_api/models/offline_countries_response_v1_dto.rb', line 29 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 |
# File 'lib/new_store_api/models/offline_countries_response_v1_dto.rb', line 24 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
56 57 58 59 |
# File 'lib/new_store_api/models/offline_countries_response_v1_dto.rb', line 56 def inspect class_name = self.class.name.split('::').last "<#{class_name} offline_countries: #{@offline_countries.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
50 51 52 53 |
# File 'lib/new_store_api/models/offline_countries_response_v1_dto.rb', line 50 def to_s class_name = self.class.name.split('::').last "<#{class_name} offline_countries: #{@offline_countries}>" end |