Class: NewStoreApi::OrderFulfillmentRequestsResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/new_store_api/models/order_fulfillment_requests_response.rb

Overview

Fulfillment requests for an order

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(fulfillment_requests = nil) ⇒ OrderFulfillmentRequestsResponse

Returns a new instance of OrderFulfillmentRequestsResponse.



34
35
36
# File 'lib/new_store_api/models/order_fulfillment_requests_response.rb', line 34

def initialize(fulfillment_requests = nil)
  @fulfillment_requests = fulfillment_requests
end

Instance Attribute Details

#fulfillment_requestsArray[FulfillmentRequest1]

All fulfillment requests that belongs to the order. Can be empty if order not routed yet, or if order doesn't exist.

Returns:



15
16
17
# File 'lib/new_store_api/models/order_fulfillment_requests_response.rb', line 15

def fulfillment_requests
  @fulfillment_requests
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
# File 'lib/new_store_api/models/order_fulfillment_requests_response.rb', line 39

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  fulfillment_requests = nil
  unless hash['fulfillment_requests'].nil?
    fulfillment_requests = []
    hash['fulfillment_requests'].each do |structure|
      fulfillment_requests << (FulfillmentRequest1.from_hash(structure) if structure)
    end
  end

  fulfillment_requests = nil unless hash.key?('fulfillment_requests')

  # Create object from extracted values.
  OrderFulfillmentRequestsResponse.new(fulfillment_requests)
end

.namesObject

A mapping from model property names to API property names.



18
19
20
21
22
# File 'lib/new_store_api/models/order_fulfillment_requests_response.rb', line 18

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['fulfillment_requests'] = 'fulfillment_requests'
  @_hash
end

.nullablesObject

An array for nullable fields



30
31
32
# File 'lib/new_store_api/models/order_fulfillment_requests_response.rb', line 30

def self.nullables
  []
end

.optionalsObject

An array for optional fields



25
26
27
# File 'lib/new_store_api/models/order_fulfillment_requests_response.rb', line 25

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



65
66
67
68
# File 'lib/new_store_api/models/order_fulfillment_requests_response.rb', line 65

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} fulfillment_requests: #{@fulfillment_requests.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



59
60
61
62
# File 'lib/new_store_api/models/order_fulfillment_requests_response.rb', line 59

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} fulfillment_requests: #{@fulfillment_requests}>"
end