Class: NewStoreApi::Original
- Defined in:
- lib/new_store_api/models/original.rb
Overview
The original routing strategy on order creation
Instance Attribute Summary collapse
-
#fulfillment_node_id ⇒ String
TODO: Write general description for this method.
-
#strategy ⇒ RoutingInsightsStrategyTypeEnum
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(strategy = nil, fulfillment_node_id = SKIP) ⇒ Original
constructor
A new instance of Original.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(strategy = nil, fulfillment_node_id = SKIP) ⇒ Original
Returns a new instance of Original.
40 41 42 43 |
# File 'lib/new_store_api/models/original.rb', line 40 def initialize(strategy = nil, fulfillment_node_id = SKIP) @fulfillment_node_id = fulfillment_node_id unless fulfillment_node_id == SKIP @strategy = strategy end |
Instance Attribute Details
#fulfillment_node_id ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/new_store_api/models/original.rb', line 14 def fulfillment_node_id @fulfillment_node_id end |
#strategy ⇒ RoutingInsightsStrategyTypeEnum
TODO: Write general description for this method
18 19 20 |
# File 'lib/new_store_api/models/original.rb', line 18 def strategy @strategy end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
46 47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/new_store_api/models/original.rb', line 46 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. strategy = hash.key?('strategy') ? hash['strategy'] : nil fulfillment_node_id = hash.key?('fulfillment_node_id') ? hash['fulfillment_node_id'] : SKIP # Create object from extracted values. Original.new(strategy, fulfillment_node_id) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/new_store_api/models/original.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['fulfillment_node_id'] = 'fulfillment_node_id' @_hash['strategy'] = 'strategy' @_hash end |
.nullables ⇒ Object
An array for nullable fields
36 37 38 |
# File 'lib/new_store_api/models/original.rb', line 36 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 |
# File 'lib/new_store_api/models/original.rb', line 29 def self.optionals %w[ fulfillment_node_id ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
66 67 68 69 70 |
# File 'lib/new_store_api/models/original.rb', line 66 def inspect class_name = self.class.name.split('::').last "<#{class_name} fulfillment_node_id: #{@fulfillment_node_id.inspect}, strategy:"\ " #{@strategy.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
60 61 62 63 |
# File 'lib/new_store_api/models/original.rb', line 60 def to_s class_name = self.class.name.split('::').last "<#{class_name} fulfillment_node_id: #{@fulfillment_node_id}, strategy: #{@strategy}>" end |