Class: NewStoreApi::PackageDimensions
- Defined in:
- lib/new_store_api/models/package_dimensions.rb
Overview
The physical dimensions of a package type.
Instance Attribute Summary collapse
-
#height ⇒ Float
Height of the package.
-
#length ⇒ Float
Length of the package.
-
#unit ⇒ DimensionUnitEnum
Unit of measurement for the dimensions.
-
#width ⇒ Float
Width of the package.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(height = nil, length = nil, unit = nil, width = nil) ⇒ PackageDimensions
constructor
A new instance of PackageDimensions.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(height = nil, length = nil, unit = nil, width = nil) ⇒ PackageDimensions
Returns a new instance of PackageDimensions.
48 49 50 51 52 53 |
# File 'lib/new_store_api/models/package_dimensions.rb', line 48 def initialize(height = nil, length = nil, unit = nil, width = nil) @height = height @length = length @unit = unit @width = width end |
Instance Attribute Details
#height ⇒ Float
Height of the package.
14 15 16 |
# File 'lib/new_store_api/models/package_dimensions.rb', line 14 def height @height end |
#length ⇒ Float
Length of the package.
18 19 20 |
# File 'lib/new_store_api/models/package_dimensions.rb', line 18 def length @length end |
#unit ⇒ DimensionUnitEnum
Unit of measurement for the dimensions.
22 23 24 |
# File 'lib/new_store_api/models/package_dimensions.rb', line 22 def unit @unit end |
#width ⇒ Float
Width of the package.
26 27 28 |
# File 'lib/new_store_api/models/package_dimensions.rb', line 26 def width @width end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/new_store_api/models/package_dimensions.rb', line 56 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. height = hash.key?('height') ? hash['height'] : nil length = hash.key?('length') ? hash['length'] : nil unit = hash.key?('unit') ? hash['unit'] : nil width = hash.key?('width') ? hash['width'] : nil # Create object from extracted values. PackageDimensions.new(height, length, unit, width) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/new_store_api/models/package_dimensions.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['height'] = 'height' @_hash['length'] = 'length' @_hash['unit'] = 'unit' @_hash['width'] = 'width' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/new_store_api/models/package_dimensions.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 |
# File 'lib/new_store_api/models/package_dimensions.rb', line 39 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
79 80 81 82 83 |
# File 'lib/new_store_api/models/package_dimensions.rb', line 79 def inspect class_name = self.class.name.split('::').last "<#{class_name} height: #{@height.inspect}, length: #{@length.inspect}, unit:"\ " #{@unit.inspect}, width: #{@width.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
73 74 75 76 |
# File 'lib/new_store_api/models/package_dimensions.rb', line 73 def to_s class_name = self.class.name.split('::').last "<#{class_name} height: #{@height}, length: #{@length}, unit: #{@unit}, width: #{@width}>" end |