Class: NewStoreApi::PackageOption
- Defined in:
- lib/new_store_api/models/package_option.rb
Overview
PackageOption Model.
Instance Attribute Summary collapse
-
#dimensions ⇒ PackageOptionDimensions
TODO: Write general description for this method.
-
#weight ⇒ PackageOptionWeight
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(weight = nil, dimensions = SKIP) ⇒ PackageOption
constructor
A new instance of PackageOption.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(weight = nil, dimensions = SKIP) ⇒ PackageOption
Returns a new instance of PackageOption.
42 43 44 45 |
# File 'lib/new_store_api/models/package_option.rb', line 42 def initialize(weight = nil, dimensions = SKIP) @dimensions = dimensions unless dimensions == SKIP @weight = weight end |
Instance Attribute Details
#dimensions ⇒ PackageOptionDimensions
TODO: Write general description for this method
14 15 16 |
# File 'lib/new_store_api/models/package_option.rb', line 14 def dimensions @dimensions end |
#weight ⇒ PackageOptionWeight
TODO: Write general description for this method
18 19 20 |
# File 'lib/new_store_api/models/package_option.rb', line 18 def weight @weight end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/new_store_api/models/package_option.rb', line 48 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. weight = PackageOptionWeight.from_hash(hash['weight']) if hash['weight'] dimensions = PackageOptionDimensions.from_hash(hash['dimensions']) if hash['dimensions'] # Create object from extracted values. PackageOption.new(weight, dimensions) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/new_store_api/models/package_option.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['dimensions'] = 'dimensions' @_hash['weight'] = 'weight' @_hash end |
.nullables ⇒ Object
An array for nullable fields
36 37 38 39 40 |
# File 'lib/new_store_api/models/package_option.rb', line 36 def self.nullables %w[ dimensions ] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 |
# File 'lib/new_store_api/models/package_option.rb', line 29 def self.optionals %w[ dimensions ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
67 68 69 70 |
# File 'lib/new_store_api/models/package_option.rb', line 67 def inspect class_name = self.class.name.split('::').last "<#{class_name} dimensions: #{@dimensions.inspect}, weight: #{@weight.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
61 62 63 64 |
# File 'lib/new_store_api/models/package_option.rb', line 61 def to_s class_name = self.class.name.split('::').last "<#{class_name} dimensions: #{@dimensions}, weight: #{@weight}>" end |