Class: NewStoreApi::PackageOptionWeight
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- NewStoreApi::PackageOptionWeight
- Defined in:
- lib/new_store_api/models/package_option_weight.rb
Overview
PackageOptionWeight Model.
Instance Attribute Summary collapse
-
#amount ⇒ Float
TODO: Write general description for this method.
-
#unit ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(amount = nil, unit = nil) ⇒ PackageOptionWeight
constructor
A new instance of PackageOptionWeight.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(amount = nil, unit = nil) ⇒ PackageOptionWeight
Returns a new instance of PackageOptionWeight.
38 39 40 41 |
# File 'lib/new_store_api/models/package_option_weight.rb', line 38 def initialize(amount = nil, unit = nil) @amount = amount @unit = unit end |
Instance Attribute Details
#amount ⇒ Float
TODO: Write general description for this method
14 15 16 |
# File 'lib/new_store_api/models/package_option_weight.rb', line 14 def amount @amount end |
#unit ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/new_store_api/models/package_option_weight.rb', line 18 def unit @unit end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/new_store_api/models/package_option_weight.rb', line 44 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. amount = hash.key?('amount') ? hash['amount'] : nil unit = hash.key?('unit') ? hash['unit'] : nil # Create object from extracted values. PackageOptionWeight.new(amount, unit) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/new_store_api/models/package_option_weight.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['amount'] = 'amount' @_hash['unit'] = 'unit' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/new_store_api/models/package_option_weight.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/new_store_api/models/package_option_weight.rb', line 29 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
63 64 65 66 |
# File 'lib/new_store_api/models/package_option_weight.rb', line 63 def inspect class_name = self.class.name.split('::').last "<#{class_name} amount: #{@amount.inspect}, unit: #{@unit.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
57 58 59 60 |
# File 'lib/new_store_api/models/package_option_weight.rb', line 57 def to_s class_name = self.class.name.split('::').last "<#{class_name} amount: #{@amount}, unit: #{@unit}>" end |