Class: NewStoreApi::PaginatedResponse
- Defined in:
- lib/new_store_api/models/paginated_response.rb
Overview
Contains default fields for paginatable APIs.
Instance Attribute Summary collapse
-
#count ⇒ Integer
Contains the count of returned elements.
-
#offset ⇒ Integer
Contains the current offset.
-
#total ⇒ Integer
Contains the total count of elements.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(count = nil, offset = nil, total = nil) ⇒ PaginatedResponse
constructor
A new instance of PaginatedResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(count = nil, offset = nil, total = nil) ⇒ PaginatedResponse
Returns a new instance of PaginatedResponse.
43 44 45 46 47 |
# File 'lib/new_store_api/models/paginated_response.rb', line 43 def initialize(count = nil, offset = nil, total = nil) @count = count @offset = offset @total = total end |
Instance Attribute Details
#count ⇒ Integer
Contains the count of returned elements.
14 15 16 |
# File 'lib/new_store_api/models/paginated_response.rb', line 14 def count @count end |
#offset ⇒ Integer
Contains the current offset.
18 19 20 |
# File 'lib/new_store_api/models/paginated_response.rb', line 18 def offset @offset end |
#total ⇒ Integer
Contains the total count of elements.
22 23 24 |
# File 'lib/new_store_api/models/paginated_response.rb', line 22 def total @total end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
50 51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/new_store_api/models/paginated_response.rb', line 50 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. count = hash.key?('count') ? hash['count'] : nil offset = hash.key?('offset') ? hash['offset'] : nil total = hash.key?('total') ? hash['total'] : nil # Create object from extracted values. PaginatedResponse.new(count, offset, total) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/new_store_api/models/paginated_response.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['count'] = 'count' @_hash['offset'] = 'offset' @_hash['total'] = 'total' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/new_store_api/models/paginated_response.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/new_store_api/models/paginated_response.rb', line 34 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
71 72 73 74 75 |
# File 'lib/new_store_api/models/paginated_response.rb', line 71 def inspect class_name = self.class.name.split('::').last "<#{class_name} count: #{@count.inspect}, offset: #{@offset.inspect}, total:"\ " #{@total.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
65 66 67 68 |
# File 'lib/new_store_api/models/paginated_response.rb', line 65 def to_s class_name = self.class.name.split('::').last "<#{class_name} count: #{@count}, offset: #{@offset}, total: #{@total}>" end |