Class: NewStoreApi::Payment1
- Defined in:
- lib/new_store_api/models/payment1.rb
Overview
Payment1 Model.
Instance Attribute Summary collapse
-
#amount ⇒ Float
TODO: Write general description for this method.
-
#currency ⇒ String
TODO: Write general description for this method.
-
#processor ⇒ String
TODO: Write general description for this method.
-
#psp_reference ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(amount = nil, currency = nil, processor = nil, psp_reference = nil) ⇒ Payment1
constructor
A new instance of Payment1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(amount = nil, currency = nil, processor = nil, psp_reference = nil) ⇒ Payment1
Returns a new instance of Payment1.
48 49 50 51 52 53 54 |
# File 'lib/new_store_api/models/payment1.rb', line 48 def initialize(amount = nil, currency = nil, processor = nil, psp_reference = nil) @amount = amount @currency = currency @processor = processor @psp_reference = psp_reference end |
Instance Attribute Details
#amount ⇒ Float
TODO: Write general description for this method
14 15 16 |
# File 'lib/new_store_api/models/payment1.rb', line 14 def amount @amount end |
#currency ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/new_store_api/models/payment1.rb', line 18 def currency @currency end |
#processor ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/new_store_api/models/payment1.rb', line 22 def processor @processor end |
#psp_reference ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/new_store_api/models/payment1.rb', line 26 def psp_reference @psp_reference end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/new_store_api/models/payment1.rb', line 57 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. amount = hash.key?('amount') ? hash['amount'] : nil currency = hash.key?('currency') ? hash['currency'] : nil processor = hash.key?('processor') ? hash['processor'] : nil psp_reference = hash.key?('psp_reference') ? hash['psp_reference'] : nil # Create object from extracted values. Payment1.new(amount, currency, processor, psp_reference) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/new_store_api/models/payment1.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['amount'] = 'amount' @_hash['currency'] = 'currency' @_hash['processor'] = 'processor' @_hash['psp_reference'] = 'psp_reference' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/new_store_api/models/payment1.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 |
# File 'lib/new_store_api/models/payment1.rb', line 39 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
81 82 83 84 85 |
# File 'lib/new_store_api/models/payment1.rb', line 81 def inspect class_name = self.class.name.split('::').last "<#{class_name} amount: #{@amount.inspect}, currency: #{@currency.inspect}, processor:"\ " #{@processor.inspect}, psp_reference: #{@psp_reference.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
74 75 76 77 78 |
# File 'lib/new_store_api/models/payment1.rb', line 74 def to_s class_name = self.class.name.split('::').last "<#{class_name} amount: #{@amount}, currency: #{@currency}, processor: #{@processor},"\ " psp_reference: #{@psp_reference}>" end |