Class: NewStoreApi::PaymentLinkGetResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- NewStoreApi::PaymentLinkGetResponse
- Defined in:
- lib/new_store_api/models/payment_link_get_response.rb
Overview
PaymentLinkGetResponse Model.
Instance Attribute Summary collapse
-
#payment ⇒ Payment1
TODO: Write general description for this method.
-
#payment_link_url ⇒ String
TODO: Write general description for this method.
-
#payment_reference ⇒ String
TODO: Write general description for this method.
-
#status ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(payment = nil, payment_link_url = nil, payment_reference = nil, status = nil) ⇒ PaymentLinkGetResponse
constructor
A new instance of PaymentLinkGetResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(payment = nil, payment_link_url = nil, payment_reference = nil, status = nil) ⇒ PaymentLinkGetResponse
Returns a new instance of PaymentLinkGetResponse.
48 49 50 51 52 53 54 |
# File 'lib/new_store_api/models/payment_link_get_response.rb', line 48 def initialize(payment = nil, payment_link_url = nil, payment_reference = nil, status = nil) @payment = payment @payment_link_url = payment_link_url @payment_reference = payment_reference @status = status end |
Instance Attribute Details
#payment ⇒ Payment1
TODO: Write general description for this method
14 15 16 |
# File 'lib/new_store_api/models/payment_link_get_response.rb', line 14 def payment @payment end |
#payment_link_url ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/new_store_api/models/payment_link_get_response.rb', line 18 def payment_link_url @payment_link_url end |
#payment_reference ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/new_store_api/models/payment_link_get_response.rb', line 22 def payment_reference @payment_reference end |
#status ⇒ String
TODO: Write general description for this method
26 27 28 |
# File 'lib/new_store_api/models/payment_link_get_response.rb', line 26 def status @status end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/new_store_api/models/payment_link_get_response.rb', line 57 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. payment = Payment1.from_hash(hash['payment']) if hash['payment'] payment_link_url = hash.key?('payment_link_url') ? hash['payment_link_url'] : nil payment_reference = hash.key?('payment_reference') ? hash['payment_reference'] : nil status = hash.key?('status') ? hash['status'] : nil # Create object from extracted values. PaymentLinkGetResponse.new(payment, payment_link_url, payment_reference, status) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/new_store_api/models/payment_link_get_response.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['payment'] = 'payment' @_hash['payment_link_url'] = 'payment_link_url' @_hash['payment_reference'] = 'payment_reference' @_hash['status'] = 'status' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/new_store_api/models/payment_link_get_response.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 |
# File 'lib/new_store_api/models/payment_link_get_response.rb', line 39 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
83 84 85 86 87 88 |
# File 'lib/new_store_api/models/payment_link_get_response.rb', line 83 def inspect class_name = self.class.name.split('::').last "<#{class_name} payment: #{@payment.inspect}, payment_link_url:"\ " #{@payment_link_url.inspect}, payment_reference: #{@payment_reference.inspect}, status:"\ " #{@status.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
76 77 78 79 80 |
# File 'lib/new_store_api/models/payment_link_get_response.rb', line 76 def to_s class_name = self.class.name.split('::').last "<#{class_name} payment: #{@payment}, payment_link_url: #{@payment_link_url},"\ " payment_reference: #{@payment_reference}, status: #{@status}>" end |