Class: NewStoreApi::PaymentLinkResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- NewStoreApi::PaymentLinkResponse
- Defined in:
- lib/new_store_api/models/payment_link_response.rb
Overview
PaymentLinkResponse Model.
Instance Attribute Summary collapse
-
#payment_link_url ⇒ String
TODO: Write general description for this method.
-
#payment_reference ⇒ String
TODO: Write general description for this method.
-
#status ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(payment_link_url = nil, payment_reference = nil, status = nil) ⇒ PaymentLinkResponse
constructor
A new instance of PaymentLinkResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(payment_link_url = nil, payment_reference = nil, status = nil) ⇒ PaymentLinkResponse
Returns a new instance of PaymentLinkResponse.
43 44 45 46 47 48 |
# File 'lib/new_store_api/models/payment_link_response.rb', line 43 def initialize(payment_link_url = nil, payment_reference = nil, status = nil) @payment_link_url = payment_link_url @payment_reference = payment_reference @status = status end |
Instance Attribute Details
#payment_link_url ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/new_store_api/models/payment_link_response.rb', line 14 def payment_link_url @payment_link_url end |
#payment_reference ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/new_store_api/models/payment_link_response.rb', line 18 def payment_reference @payment_reference end |
#status ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/new_store_api/models/payment_link_response.rb', line 22 def status @status end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/new_store_api/models/payment_link_response.rb', line 51 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. payment_link_url = hash.key?('payment_link_url') ? hash['payment_link_url'] : nil payment_reference = hash.key?('payment_reference') ? hash['payment_reference'] : nil status = hash.key?('status') ? hash['status'] : nil # Create object from extracted values. PaymentLinkResponse.new(payment_link_url, payment_reference, status) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/new_store_api/models/payment_link_response.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['payment_link_url'] = 'payment_link_url' @_hash['payment_reference'] = 'payment_reference' @_hash['status'] = 'status' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/new_store_api/models/payment_link_response.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/new_store_api/models/payment_link_response.rb', line 34 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
75 76 77 78 79 |
# File 'lib/new_store_api/models/payment_link_response.rb', line 75 def inspect class_name = self.class.name.split('::').last "<#{class_name} payment_link_url: #{@payment_link_url.inspect}, payment_reference:"\ " #{@payment_reference.inspect}, status: #{@status.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
68 69 70 71 72 |
# File 'lib/new_store_api/models/payment_link_response.rb', line 68 def to_s class_name = self.class.name.split('::').last "<#{class_name} payment_link_url: #{@payment_link_url}, payment_reference:"\ " #{@payment_reference}, status: #{@status}>" end |