Class: NewStoreApi::PermalinkResponse
- Defined in:
- lib/new_store_api/models/permalink_response.rb
Overview
PermalinkResponse Model.
Instance Attribute Summary collapse
-
#permanent_link ⇒ String
The URL of the document.
-
#vault_data_id ⇒ String
ID of the document in the PII vault.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(permanent_link = nil, vault_data_id = SKIP) ⇒ PermalinkResponse
constructor
A new instance of PermalinkResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(permanent_link = nil, vault_data_id = SKIP) ⇒ PermalinkResponse
Returns a new instance of PermalinkResponse.
40 41 42 43 |
# File 'lib/new_store_api/models/permalink_response.rb', line 40 def initialize(permanent_link = nil, vault_data_id = SKIP) @permanent_link = permanent_link @vault_data_id = vault_data_id unless vault_data_id == SKIP end |
Instance Attribute Details
#permanent_link ⇒ String
The URL of the document.
14 15 16 |
# File 'lib/new_store_api/models/permalink_response.rb', line 14 def permanent_link @permanent_link end |
#vault_data_id ⇒ String
ID of the document in the PII vault
18 19 20 |
# File 'lib/new_store_api/models/permalink_response.rb', line 18 def vault_data_id @vault_data_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
46 47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/new_store_api/models/permalink_response.rb', line 46 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. permanent_link = hash.key?('permanent_link') ? hash['permanent_link'] : nil vault_data_id = hash.key?('vault_data_id') ? hash['vault_data_id'] : SKIP # Create object from extracted values. PermalinkResponse.new(permanent_link, vault_data_id) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/new_store_api/models/permalink_response.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['permanent_link'] = 'permanent_link' @_hash['vault_data_id'] = 'vault_data_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
36 37 38 |
# File 'lib/new_store_api/models/permalink_response.rb', line 36 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 |
# File 'lib/new_store_api/models/permalink_response.rb', line 29 def self.optionals %w[ vault_data_id ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
66 67 68 69 70 |
# File 'lib/new_store_api/models/permalink_response.rb', line 66 def inspect class_name = self.class.name.split('::').last "<#{class_name} permanent_link: #{@permanent_link.inspect}, vault_data_id:"\ " #{@vault_data_id.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
60 61 62 63 |
# File 'lib/new_store_api/models/permalink_response.rb', line 60 def to_s class_name = self.class.name.split('::').last "<#{class_name} permanent_link: #{@permanent_link}, vault_data_id: #{@vault_data_id}>" end |