Class: NewStoreApi::PostChargeRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/new_store_api/models/post_charge_request.rb

Overview

PostChargeRequest Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(amount = nil, order_number = SKIP) ⇒ PostChargeRequest

Returns a new instance of PostChargeRequest.



41
42
43
44
# File 'lib/new_store_api/models/post_charge_request.rb', line 41

def initialize(amount = nil, order_number = SKIP)
  @amount = amount
  @order_number = order_number unless order_number == SKIP
end

Instance Attribute Details

#amountAmount

The amount consisting of value and currency

Returns:



14
15
16
# File 'lib/new_store_api/models/post_charge_request.rb', line 14

def amount
  @amount
end

#order_numberString

Tenant order identifier to be added to payment provider requests and public events

Returns:

  • (String)


19
20
21
# File 'lib/new_store_api/models/post_charge_request.rb', line 19

def order_number
  @order_number
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



47
48
49
50
51
52
53
54
55
56
57
# File 'lib/new_store_api/models/post_charge_request.rb', line 47

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  amount = Amount.from_hash(hash['amount']) if hash['amount']
  order_number = hash.key?('order_number') ? hash['order_number'] : SKIP

  # Create object from extracted values.
  PostChargeRequest.new(amount,
                        order_number)
end

.namesObject

A mapping from model property names to API property names.



22
23
24
25
26
27
# File 'lib/new_store_api/models/post_charge_request.rb', line 22

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['amount'] = 'amount'
  @_hash['order_number'] = 'order_number'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/new_store_api/models/post_charge_request.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



30
31
32
33
34
# File 'lib/new_store_api/models/post_charge_request.rb', line 30

def self.optionals
  %w[
    order_number
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



66
67
68
69
# File 'lib/new_store_api/models/post_charge_request.rb', line 66

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} amount: #{@amount.inspect}, order_number: #{@order_number.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



60
61
62
63
# File 'lib/new_store_api/models/post_charge_request.rb', line 60

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} amount: #{@amount}, order_number: #{@order_number}>"
end