Class: NewStoreApi::PresignedUrlRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/new_store_api/models/presigned_url_request.rb

Overview

PresignedUrlRequest Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(file_name = nil) ⇒ PresignedUrlRequest

Returns a new instance of PresignedUrlRequest.



33
34
35
# File 'lib/new_store_api/models/presigned_url_request.rb', line 33

def initialize(file_name = nil)
  @file_name = file_name
end

Instance Attribute Details

#file_nameString

The name of the file to be uploaded, including extension.

Returns:

  • (String)


14
15
16
# File 'lib/new_store_api/models/presigned_url_request.rb', line 14

def file_name
  @file_name
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



38
39
40
41
42
43
44
45
46
# File 'lib/new_store_api/models/presigned_url_request.rb', line 38

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  file_name = hash.key?('file_name') ? hash['file_name'] : nil

  # Create object from extracted values.
  PresignedUrlRequest.new(file_name)
end

.namesObject

A mapping from model property names to API property names.



17
18
19
20
21
# File 'lib/new_store_api/models/presigned_url_request.rb', line 17

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['file_name'] = 'file_name'
  @_hash
end

.nullablesObject

An array for nullable fields



29
30
31
# File 'lib/new_store_api/models/presigned_url_request.rb', line 29

def self.nullables
  []
end

.optionalsObject

An array for optional fields



24
25
26
# File 'lib/new_store_api/models/presigned_url_request.rb', line 24

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



55
56
57
58
# File 'lib/new_store_api/models/presigned_url_request.rb', line 55

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} file_name: #{@file_name.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



49
50
51
52
# File 'lib/new_store_api/models/presigned_url_request.rb', line 49

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} file_name: #{@file_name}>"
end