Class: NewStoreApi::PresignedUrlResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- NewStoreApi::PresignedUrlResponse
- Defined in:
- lib/new_store_api/models/presigned_url_response.rb
Overview
PresignedUrlResponse Model.
Instance Attribute Summary collapse
-
#url ⇒ String
The presigned URL.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(url = nil) ⇒ PresignedUrlResponse
constructor
A new instance of PresignedUrlResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(url = nil) ⇒ PresignedUrlResponse
Returns a new instance of PresignedUrlResponse.
33 34 35 |
# File 'lib/new_store_api/models/presigned_url_response.rb', line 33 def initialize(url = nil) @url = url end |
Instance Attribute Details
#url ⇒ String
The presigned URL.
14 15 16 |
# File 'lib/new_store_api/models/presigned_url_response.rb', line 14 def url @url end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
38 39 40 41 42 43 44 45 46 |
# File 'lib/new_store_api/models/presigned_url_response.rb', line 38 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. url = hash.key?('url') ? hash['url'] : nil # Create object from extracted values. PresignedUrlResponse.new(url) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/new_store_api/models/presigned_url_response.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['url'] = 'url' @_hash end |
.nullables ⇒ Object
An array for nullable fields
29 30 31 |
# File 'lib/new_store_api/models/presigned_url_response.rb', line 29 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 |
# File 'lib/new_store_api/models/presigned_url_response.rb', line 24 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
55 56 57 58 |
# File 'lib/new_store_api/models/presigned_url_response.rb', line 55 def inspect class_name = self.class.name.split('::').last "<#{class_name} url: #{@url.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
49 50 51 52 |
# File 'lib/new_store_api/models/presigned_url_response.rb', line 49 def to_s class_name = self.class.name.split('::').last "<#{class_name} url: #{@url}>" end |