Class: NewStoreApi::ProcessorMetadata

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/new_store_api/models/processor_metadata.rb

Overview

ProcessorMetadata Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(embedded_processor = nil) ⇒ ProcessorMetadata

Returns a new instance of ProcessorMetadata.



33
34
35
# File 'lib/new_store_api/models/processor_metadata.rb', line 33

def initialize(embedded_processor = nil)
  @embedded_processor = embedded_processor
end

Instance Attribute Details

#embedded_processorString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/new_store_api/models/processor_metadata.rb', line 14

def embedded_processor
  @embedded_processor
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



38
39
40
41
42
43
44
45
46
47
# File 'lib/new_store_api/models/processor_metadata.rb', line 38

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  embedded_processor =
    hash.key?('embedded_processor') ? hash['embedded_processor'] : nil

  # Create object from extracted values.
  ProcessorMetadata.new(embedded_processor)
end

.namesObject

A mapping from model property names to API property names.



17
18
19
20
21
# File 'lib/new_store_api/models/processor_metadata.rb', line 17

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['embedded_processor'] = 'embedded_processor'
  @_hash
end

.nullablesObject

An array for nullable fields



29
30
31
# File 'lib/new_store_api/models/processor_metadata.rb', line 29

def self.nullables
  []
end

.optionalsObject

An array for optional fields



24
25
26
# File 'lib/new_store_api/models/processor_metadata.rb', line 24

def self.optionals
  []
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



51
52
53
54
55
56
57
58
59
60
61
# File 'lib/new_store_api/models/processor_metadata.rb', line 51

def self.validate(value)
  if value.instance_of? self
    return APIHelper.valid_type?(value.embedded_processor,
                                 ->(val) { val.instance_of? String })
  end

  return false unless value.instance_of? Hash

  APIHelper.valid_type?(value['embedded_processor'],
                        ->(val) { val.instance_of? String })
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



70
71
72
73
# File 'lib/new_store_api/models/processor_metadata.rb', line 70

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} embedded_processor: #{@embedded_processor.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



64
65
66
67
# File 'lib/new_store_api/models/processor_metadata.rb', line 64

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} embedded_processor: #{@embedded_processor}>"
end