Class: NewStoreApi::Provider
- Defined in:
- lib/new_store_api/models/provider.rb
Overview
Provider Model.
Instance Attribute Summary collapse
-
#malias ⇒ String
The alias as specified in Keycloak.
-
#provider ⇒ Provider1Enum
The provider, one of: 'auth0', 'microsoft-azure-ad'.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(malias = SKIP, provider = SKIP) ⇒ Provider
constructor
A new instance of Provider.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(malias = SKIP, provider = SKIP) ⇒ Provider
Returns a new instance of Provider.
41 42 43 44 |
# File 'lib/new_store_api/models/provider.rb', line 41 def initialize(malias = SKIP, provider = SKIP) @malias = malias unless malias == SKIP @provider = provider unless provider == SKIP end |
Instance Attribute Details
#malias ⇒ String
The alias as specified in Keycloak.
14 15 16 |
# File 'lib/new_store_api/models/provider.rb', line 14 def malias @malias end |
#provider ⇒ Provider1Enum
The provider, one of: 'auth0', 'microsoft-azure-ad'.
18 19 20 |
# File 'lib/new_store_api/models/provider.rb', line 18 def provider @provider end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/new_store_api/models/provider.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. malias = hash.key?('alias') ? hash['alias'] : SKIP provider = hash.key?('provider') ? hash['provider'] : SKIP # Create object from extracted values. Provider.new(malias, provider) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/new_store_api/models/provider.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['malias'] = 'alias' @_hash['provider'] = 'provider' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/new_store_api/models/provider.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/new_store_api/models/provider.rb', line 29 def self.optionals %w[ malias provider ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
66 67 68 69 |
# File 'lib/new_store_api/models/provider.rb', line 66 def inspect class_name = self.class.name.split('::').last "<#{class_name} malias: #{@malias.inspect}, provider: #{@provider.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
60 61 62 63 |
# File 'lib/new_store_api/models/provider.rb', line 60 def to_s class_name = self.class.name.split('::').last "<#{class_name} malias: #{@malias}, provider: #{@provider}>" end |