Class: NewStoreApi::PutRoutingRulesetResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- NewStoreApi::PutRoutingRulesetResponse
- Defined in:
- lib/new_store_api/models/put_routing_ruleset_response.rb
Overview
PutRoutingRulesetResponse Model.
Instance Attribute Summary collapse
-
#fulfillment_config_uri ⇒ String
Fulfillment Configuration Revision URI.
-
#routing_ruleset ⇒ RoutingRuleset1
Fulfillment Configuration Revision URI.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(fulfillment_config_uri = SKIP, routing_ruleset = SKIP) ⇒ PutRoutingRulesetResponse
constructor
A new instance of PutRoutingRulesetResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(fulfillment_config_uri = SKIP, routing_ruleset = SKIP) ⇒ PutRoutingRulesetResponse
Returns a new instance of PutRoutingRulesetResponse.
41 42 43 44 |
# File 'lib/new_store_api/models/put_routing_ruleset_response.rb', line 41 def initialize(fulfillment_config_uri = SKIP, routing_ruleset = SKIP) @fulfillment_config_uri = fulfillment_config_uri unless fulfillment_config_uri == SKIP @routing_ruleset = routing_ruleset unless routing_ruleset == SKIP end |
Instance Attribute Details
#fulfillment_config_uri ⇒ String
Fulfillment Configuration Revision URI
14 15 16 |
# File 'lib/new_store_api/models/put_routing_ruleset_response.rb', line 14 def fulfillment_config_uri @fulfillment_config_uri end |
#routing_ruleset ⇒ RoutingRuleset1
Fulfillment Configuration Revision URI
18 19 20 |
# File 'lib/new_store_api/models/put_routing_ruleset_response.rb', line 18 def routing_ruleset @routing_ruleset end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/new_store_api/models/put_routing_ruleset_response.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. fulfillment_config_uri = hash.key?('fulfillment_config_uri') ? hash['fulfillment_config_uri'] : SKIP routing_ruleset = RoutingRuleset1.from_hash(hash['routing_ruleset']) if hash['routing_ruleset'] # Create object from extracted values. PutRoutingRulesetResponse.new(fulfillment_config_uri, routing_ruleset) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/new_store_api/models/put_routing_ruleset_response.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['fulfillment_config_uri'] = 'fulfillment_config_uri' @_hash['routing_ruleset'] = 'routing_ruleset' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/new_store_api/models/put_routing_ruleset_response.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/new_store_api/models/put_routing_ruleset_response.rb', line 29 def self.optionals %w[ fulfillment_config_uri routing_ruleset ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
69 70 71 72 73 |
# File 'lib/new_store_api/models/put_routing_ruleset_response.rb', line 69 def inspect class_name = self.class.name.split('::').last "<#{class_name} fulfillment_config_uri: #{@fulfillment_config_uri.inspect},"\ " routing_ruleset: #{@routing_ruleset.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
62 63 64 65 66 |
# File 'lib/new_store_api/models/put_routing_ruleset_response.rb', line 62 def to_s class_name = self.class.name.split('::').last "<#{class_name} fulfillment_config_uri: #{@fulfillment_config_uri}, routing_ruleset:"\ " #{@routing_ruleset}>" end |