Class: NewStoreApi::ReservationItemSummaryResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/new_store_api/models/reservation_item_summary_response.rb

Overview

ReservationItemSummaryResponse Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(id = nil, product_id = nil) ⇒ ReservationItemSummaryResponse

Returns a new instance of ReservationItemSummaryResponse.



38
39
40
41
# File 'lib/new_store_api/models/reservation_item_summary_response.rb', line 38

def initialize(id = nil, product_id = nil)
  @id = id
  @product_id = product_id
end

Instance Attribute Details

#idUUID | String

Unique identifier for the reservation item

Returns:

  • (UUID | String)


14
15
16
# File 'lib/new_store_api/models/reservation_item_summary_response.rb', line 14

def id
  @id
end

#product_idString

ID of the product the reservation item corresponds to

Returns:

  • (String)


18
19
20
# File 'lib/new_store_api/models/reservation_item_summary_response.rb', line 18

def product_id
  @product_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



44
45
46
47
48
49
50
51
52
53
54
# File 'lib/new_store_api/models/reservation_item_summary_response.rb', line 44

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  id = hash.key?('id') ? hash['id'] : nil
  product_id = hash.key?('product_id') ? hash['product_id'] : nil

  # Create object from extracted values.
  ReservationItemSummaryResponse.new(id,
                                     product_id)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/new_store_api/models/reservation_item_summary_response.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['id'] = 'id'
  @_hash['product_id'] = 'product_id'
  @_hash
end

.nullablesObject

An array for nullable fields



34
35
36
# File 'lib/new_store_api/models/reservation_item_summary_response.rb', line 34

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
# File 'lib/new_store_api/models/reservation_item_summary_response.rb', line 29

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



63
64
65
66
# File 'lib/new_store_api/models/reservation_item_summary_response.rb', line 63

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id.inspect}, product_id: #{@product_id.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



57
58
59
60
# File 'lib/new_store_api/models/reservation_item_summary_response.rb', line 57

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id}, product_id: #{@product_id}>"
end