Class: NewStoreApi::ReservationItemUpdate

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/new_store_api/models/reservation_item_update.rb

Overview

ReservationItemUpdate Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(id = nil, status = nil, cart_id = SKIP) ⇒ ReservationItemUpdate

Returns a new instance of ReservationItemUpdate.



47
48
49
50
51
# File 'lib/new_store_api/models/reservation_item_update.rb', line 47

def initialize(id = nil, status = nil, cart_id = SKIP)
  @cart_id = cart_id unless cart_id == SKIP
  @id = id
  @status = status
end

Instance Attribute Details

#cart_idString

ID of the cart in which the item was purchased during conversion

Returns:

  • (String)


14
15
16
# File 'lib/new_store_api/models/reservation_item_update.rb', line 14

def cart_id
  @cart_id
end

#idUUID | String

Unique identifier of the reservation item to update

Returns:

  • (UUID | String)


18
19
20
# File 'lib/new_store_api/models/reservation_item_update.rb', line 18

def id
  @id
end

#statusUpdatedItemStatusEnum

Unique identifier of the reservation item to update



22
23
24
# File 'lib/new_store_api/models/reservation_item_update.rb', line 22

def status
  @status
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/new_store_api/models/reservation_item_update.rb', line 54

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  id = hash.key?('id') ? hash['id'] : nil
  status = hash.key?('status') ? hash['status'] : nil
  cart_id = hash.key?('cart_id') ? hash['cart_id'] : SKIP

  # Create object from extracted values.
  ReservationItemUpdate.new(id,
                            status,
                            cart_id)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/new_store_api/models/reservation_item_update.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['cart_id'] = 'cart_id'
  @_hash['id'] = 'id'
  @_hash['status'] = 'status'
  @_hash
end

.nullablesObject

An array for nullable fields



41
42
43
44
45
# File 'lib/new_store_api/models/reservation_item_update.rb', line 41

def self.nullables
  %w[
    cart_id
  ]
end

.optionalsObject

An array for optional fields



34
35
36
37
38
# File 'lib/new_store_api/models/reservation_item_update.rb', line 34

def self.optionals
  %w[
    cart_id
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



75
76
77
78
79
# File 'lib/new_store_api/models/reservation_item_update.rb', line 75

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} cart_id: #{@cart_id.inspect}, id: #{@id.inspect}, status:"\
  " #{@status.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



69
70
71
72
# File 'lib/new_store_api/models/reservation_item_update.rb', line 69

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} cart_id: #{@cart_id}, id: #{@id}, status: #{@status}>"
end