Class: NewStoreApi::ReservationSummaryResponseV1

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/new_store_api/models/reservation_summary_response_v1.rb

Overview

ReservationSummaryResponseV1 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(associate_id = nil, created_at = nil, customer_profile_id = nil, expires_at = nil, external_id = nil, id = nil, items = nil, location_id = nil, reserved_item_count = nil, status = nil) ⇒ ReservationSummaryResponseV1

Returns a new instance of ReservationSummaryResponseV1.



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/new_store_api/models/reservation_summary_response_v1.rb', line 81

def initialize(associate_id = nil, created_at = nil,
               customer_profile_id = nil, expires_at = nil,
               external_id = nil, id = nil, items = nil, location_id = nil,
               reserved_item_count = nil, status = nil)
  @associate_id = associate_id
  @created_at = created_at
  @customer_profile_id = customer_profile_id
  @expires_at = expires_at
  @external_id = external_id
  @id = id
  @items = items
  @location_id = location_id
  @reserved_item_count = reserved_item_count
  @status = status
end

Instance Attribute Details

#associate_idString

ID of the associate that created the reservation

Returns:

  • (String)


15
16
17
# File 'lib/new_store_api/models/reservation_summary_response_v1.rb', line 15

def associate_id
  @associate_id
end

#created_atDateTime

Date and time the reservation was created

Returns:

  • (DateTime)


19
20
21
# File 'lib/new_store_api/models/reservation_summary_response_v1.rb', line 19

def created_at
  @created_at
end

#customer_profile_idString

Profile ID of the customer the reservation is for

Returns:

  • (String)


23
24
25
# File 'lib/new_store_api/models/reservation_summary_response_v1.rb', line 23

def customer_profile_id
  @customer_profile_id
end

#expires_atDateTime

Date and time the reservation expires

Returns:

  • (DateTime)


27
28
29
# File 'lib/new_store_api/models/reservation_summary_response_v1.rb', line 27

def expires_at
  @expires_at
end

#external_idString

Short, human-readable identifier for the reservation

Returns:

  • (String)


31
32
33
# File 'lib/new_store_api/models/reservation_summary_response_v1.rb', line 31

def external_id
  @external_id
end

#idUUID | String

Unique identifier for the reservation

Returns:

  • (UUID | String)


35
36
37
# File 'lib/new_store_api/models/reservation_summary_response_v1.rb', line 35

def id
  @id
end

#itemsArray[ReservationItemSummaryResponse]

Items associated with the reservation

Returns:



39
40
41
# File 'lib/new_store_api/models/reservation_summary_response_v1.rb', line 39

def items
  @items
end

#location_idString

ID of the fulfillment location the reservation is for

Returns:

  • (String)


43
44
45
# File 'lib/new_store_api/models/reservation_summary_response_v1.rb', line 43

def location_id
  @location_id
end

#reserved_item_countInteger

Number of items in the RESERVED state

Returns:

  • (Integer)


47
48
49
# File 'lib/new_store_api/models/reservation_summary_response_v1.rb', line 47

def reserved_item_count
  @reserved_item_count
end

#statusReservationStatusEnum

The status of a reservation.



51
52
53
# File 'lib/new_store_api/models/reservation_summary_response_v1.rb', line 51

def status
  @status
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/new_store_api/models/reservation_summary_response_v1.rb', line 98

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  associate_id = hash.key?('associate_id') ? hash['associate_id'] : nil
  created_at = if hash.key?('created_at')
                 (DateTimeHelper.from_rfc3339(hash['created_at']) if hash['created_at'])
               end
  customer_profile_id =
    hash.key?('customer_profile_id') ? hash['customer_profile_id'] : nil
  expires_at = if hash.key?('expires_at')
                 (DateTimeHelper.from_rfc3339(hash['expires_at']) if hash['expires_at'])
               end
  external_id = hash.key?('external_id') ? hash['external_id'] : nil
  id = hash.key?('id') ? hash['id'] : nil
  # Parameter is an array, so we need to iterate through it
  items = nil
  unless hash['items'].nil?
    items = []
    hash['items'].each do |structure|
      items << (ReservationItemSummaryResponse.from_hash(structure) if structure)
    end
  end

  items = nil unless hash.key?('items')
  location_id = hash.key?('location_id') ? hash['location_id'] : nil
  reserved_item_count =
    hash.key?('reserved_item_count') ? hash['reserved_item_count'] : nil
  status = hash.key?('status') ? hash['status'] : nil

  # Create object from extracted values.
  ReservationSummaryResponseV1.new(associate_id,
                                   created_at,
                                   customer_profile_id,
                                   expires_at,
                                   external_id,
                                   id,
                                   items,
                                   location_id,
                                   reserved_item_count,
                                   status)
end

.namesObject

A mapping from model property names to API property names.



54
55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/new_store_api/models/reservation_summary_response_v1.rb', line 54

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['associate_id'] = 'associate_id'
  @_hash['created_at'] = 'created_at'
  @_hash['customer_profile_id'] = 'customer_profile_id'
  @_hash['expires_at'] = 'expires_at'
  @_hash['external_id'] = 'external_id'
  @_hash['id'] = 'id'
  @_hash['items'] = 'items'
  @_hash['location_id'] = 'location_id'
  @_hash['reserved_item_count'] = 'reserved_item_count'
  @_hash['status'] = 'status'
  @_hash
end

.nullablesObject

An array for nullable fields



75
76
77
78
79
# File 'lib/new_store_api/models/reservation_summary_response_v1.rb', line 75

def self.nullables
  %w[
    associate_id
  ]
end

.optionalsObject

An array for optional fields



70
71
72
# File 'lib/new_store_api/models/reservation_summary_response_v1.rb', line 70

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



159
160
161
162
163
164
165
166
# File 'lib/new_store_api/models/reservation_summary_response_v1.rb', line 159

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} associate_id: #{@associate_id.inspect}, created_at: #{@created_at.inspect},"\
  " customer_profile_id: #{@customer_profile_id.inspect}, expires_at: #{@expires_at.inspect},"\
  " external_id: #{@external_id.inspect}, id: #{@id.inspect}, items: #{@items.inspect},"\
  " location_id: #{@location_id.inspect}, reserved_item_count:"\
  " #{@reserved_item_count.inspect}, status: #{@status.inspect}>"
end

#to_custom_created_atObject



141
142
143
# File 'lib/new_store_api/models/reservation_summary_response_v1.rb', line 141

def to_custom_created_at
  DateTimeHelper.to_rfc3339(created_at)
end

#to_custom_expires_atObject



145
146
147
# File 'lib/new_store_api/models/reservation_summary_response_v1.rb', line 145

def to_custom_expires_at
  DateTimeHelper.to_rfc3339(expires_at)
end

#to_sObject

Provides a human-readable string representation of the object.



150
151
152
153
154
155
156
# File 'lib/new_store_api/models/reservation_summary_response_v1.rb', line 150

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} associate_id: #{@associate_id}, created_at: #{@created_at},"\
  " customer_profile_id: #{@customer_profile_id}, expires_at: #{@expires_at}, external_id:"\
  " #{@external_id}, id: #{@id}, items: #{@items}, location_id: #{@location_id},"\
  " reserved_item_count: #{@reserved_item_count}, status: #{@status}>"
end