Class: NewStoreApi::ResponseCreateManifest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- NewStoreApi::ResponseCreateManifest
- Defined in:
- lib/new_store_api/models/response_create_manifest.rb
Overview
ResponseCreateManifest Model.
Instance Attribute Summary collapse
-
#carrier_code ⇒ String
TODO: Write general description for this method.
-
#document_url ⇒ String
TODO: Write general description for this method.
-
#id ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(carrier_code = nil, document_url = nil, id = nil) ⇒ ResponseCreateManifest
constructor
A new instance of ResponseCreateManifest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(carrier_code = nil, document_url = nil, id = nil) ⇒ ResponseCreateManifest
Returns a new instance of ResponseCreateManifest.
43 44 45 46 47 |
# File 'lib/new_store_api/models/response_create_manifest.rb', line 43 def initialize(carrier_code = nil, document_url = nil, id = nil) @carrier_code = carrier_code @document_url = document_url @id = id end |
Instance Attribute Details
#carrier_code ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/new_store_api/models/response_create_manifest.rb', line 14 def carrier_code @carrier_code end |
#document_url ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/new_store_api/models/response_create_manifest.rb', line 18 def document_url @document_url end |
#id ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/new_store_api/models/response_create_manifest.rb', line 22 def id @id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
50 51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/new_store_api/models/response_create_manifest.rb', line 50 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. carrier_code = hash.key?('carrier_code') ? hash['carrier_code'] : nil document_url = hash.key?('document_url') ? hash['document_url'] : nil id = hash.key?('id') ? hash['id'] : nil # Create object from extracted values. ResponseCreateManifest.new(carrier_code, document_url, id) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/new_store_api/models/response_create_manifest.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['carrier_code'] = 'carrier_code' @_hash['document_url'] = 'document_url' @_hash['id'] = 'id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/new_store_api/models/response_create_manifest.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/new_store_api/models/response_create_manifest.rb', line 34 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
72 73 74 75 76 |
# File 'lib/new_store_api/models/response_create_manifest.rb', line 72 def inspect class_name = self.class.name.split('::').last "<#{class_name} carrier_code: #{@carrier_code.inspect}, document_url:"\ " #{@document_url.inspect}, id: #{@id.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
65 66 67 68 69 |
# File 'lib/new_store_api/models/response_create_manifest.rb', line 65 def to_s class_name = self.class.name.split('::').last "<#{class_name} carrier_code: #{@carrier_code}, document_url: #{@document_url}, id:"\ " #{@id}>" end |