Class: NewStoreApi::ResponseShowBookings

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/new_store_api/models/response_show_bookings.rb

Overview

ResponseShowBookings Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(booking_id = nil, bookings = nil) ⇒ ResponseShowBookings

Returns a new instance of ResponseShowBookings.



38
39
40
41
# File 'lib/new_store_api/models/response_show_bookings.rb', line 38

def initialize(booking_id = nil, bookings = nil)
  @booking_id = booking_id
  @bookings = bookings
end

Instance Attribute Details

#booking_idUUID | String

TODO: Write general description for this method

Returns:

  • (UUID | String)


14
15
16
# File 'lib/new_store_api/models/response_show_bookings.rb', line 14

def booking_id
  @booking_id
end

#bookingsArray[ResponseBookedPackageTransaction]

TODO: Write general description for this method



18
19
20
# File 'lib/new_store_api/models/response_show_bookings.rb', line 18

def bookings
  @bookings
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/new_store_api/models/response_show_bookings.rb', line 44

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  booking_id = hash.key?('booking_id') ? hash['booking_id'] : nil
  # Parameter is an array, so we need to iterate through it
  bookings = nil
  unless hash['bookings'].nil?
    bookings = []
    hash['bookings'].each do |structure|
      bookings << (ResponseBookedPackageTransaction.from_hash(structure) if structure)
    end
  end

  bookings = nil unless hash.key?('bookings')

  # Create object from extracted values.
  ResponseShowBookings.new(booking_id,
                           bookings)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/new_store_api/models/response_show_bookings.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['booking_id'] = 'booking_id'
  @_hash['bookings'] = 'bookings'
  @_hash
end

.nullablesObject

An array for nullable fields



34
35
36
# File 'lib/new_store_api/models/response_show_bookings.rb', line 34

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
# File 'lib/new_store_api/models/response_show_bookings.rb', line 29

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



72
73
74
75
# File 'lib/new_store_api/models/response_show_bookings.rb', line 72

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} booking_id: #{@booking_id.inspect}, bookings: #{@bookings.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



66
67
68
69
# File 'lib/new_store_api/models/response_show_bookings.rb', line 66

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} booking_id: #{@booking_id}, bookings: #{@bookings}>"
end