Class: NewStoreApi::RoutesV1

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/new_store_api/models/routes_v1.rb

Overview

RoutesV1 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(destination_region = SKIP, fulfilled_by = SKIP) ⇒ RoutesV1

Returns a new instance of RoutesV1.



42
43
44
45
# File 'lib/new_store_api/models/routes_v1.rb', line 42

def initialize(destination_region = SKIP, fulfilled_by = SKIP)
  @destination_region = destination_region unless destination_region == SKIP
  @fulfilled_by = fulfilled_by unless fulfilled_by == SKIP
end

Instance Attribute Details

#destination_regionDestinationRegion

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/new_store_api/models/routes_v1.rb', line 14

def destination_region
  @destination_region
end

#fulfilled_byHash[String, Object]

This configuration mentions the service levels identifications and which location group will serve this region

Returns:

  • (Hash[String, Object])


19
20
21
# File 'lib/new_store_api/models/routes_v1.rb', line 19

def fulfilled_by
  @fulfilled_by
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



48
49
50
51
52
53
54
55
56
57
58
59
# File 'lib/new_store_api/models/routes_v1.rb', line 48

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  destination_region = DestinationRegion.from_hash(hash['destination_region']) if
    hash['destination_region']
  fulfilled_by = hash.key?('fulfilled_by') ? hash['fulfilled_by'] : SKIP

  # Create object from extracted values.
  RoutesV1.new(destination_region,
               fulfilled_by)
end

.namesObject

A mapping from model property names to API property names.



22
23
24
25
26
27
# File 'lib/new_store_api/models/routes_v1.rb', line 22

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['destination_region'] = 'destination_region'
  @_hash['fulfilled_by'] = 'fulfilled_by'
  @_hash
end

.nullablesObject

An array for nullable fields



38
39
40
# File 'lib/new_store_api/models/routes_v1.rb', line 38

def self.nullables
  []
end

.optionalsObject

An array for optional fields



30
31
32
33
34
35
# File 'lib/new_store_api/models/routes_v1.rb', line 30

def self.optionals
  %w[
    destination_region
    fulfilled_by
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



69
70
71
72
73
# File 'lib/new_store_api/models/routes_v1.rb', line 69

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} destination_region: #{@destination_region.inspect}, fulfilled_by:"\
  " #{@fulfilled_by.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



62
63
64
65
66
# File 'lib/new_store_api/models/routes_v1.rb', line 62

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} destination_region: #{@destination_region}, fulfilled_by:"\
  " #{@fulfilled_by}>"
end