Class: NewStoreApi::RoutingDecisionTracePicked
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- NewStoreApi::RoutingDecisionTracePicked
- Defined in:
- lib/new_store_api/models/routing_decision_trace_picked.rb
Overview
Selected routing logic candidate in the decision trace.
Instance Attribute Summary collapse
-
#candidate_id ⇒ String
Identifier of the selected routing candidate.
-
#label ⇒ String
Human-readable label for the selected candidate.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(candidate_id = nil, label = nil) ⇒ RoutingDecisionTracePicked
constructor
A new instance of RoutingDecisionTracePicked.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(candidate_id = nil, label = nil) ⇒ RoutingDecisionTracePicked
Returns a new instance of RoutingDecisionTracePicked.
38 39 40 41 |
# File 'lib/new_store_api/models/routing_decision_trace_picked.rb', line 38 def initialize(candidate_id = nil, label = nil) @candidate_id = candidate_id @label = label end |
Instance Attribute Details
#candidate_id ⇒ String
Identifier of the selected routing candidate.
14 15 16 |
# File 'lib/new_store_api/models/routing_decision_trace_picked.rb', line 14 def candidate_id @candidate_id end |
#label ⇒ String
Human-readable label for the selected candidate.
18 19 20 |
# File 'lib/new_store_api/models/routing_decision_trace_picked.rb', line 18 def label @label end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/new_store_api/models/routing_decision_trace_picked.rb', line 44 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. candidate_id = hash.key?('candidate_id') ? hash['candidate_id'] : nil label = hash.key?('label') ? hash['label'] : nil # Create object from extracted values. RoutingDecisionTracePicked.new(candidate_id, label) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/new_store_api/models/routing_decision_trace_picked.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['candidate_id'] = 'candidate_id' @_hash['label'] = 'label' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/new_store_api/models/routing_decision_trace_picked.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/new_store_api/models/routing_decision_trace_picked.rb', line 29 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
63 64 65 66 |
# File 'lib/new_store_api/models/routing_decision_trace_picked.rb', line 63 def inspect class_name = self.class.name.split('::').last "<#{class_name} candidate_id: #{@candidate_id.inspect}, label: #{@label.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
57 58 59 60 |
# File 'lib/new_store_api/models/routing_decision_trace_picked.rb', line 57 def to_s class_name = self.class.name.split('::').last "<#{class_name} candidate_id: #{@candidate_id}, label: #{@label}>" end |