Class: NewStoreApi::RoutingInsightsServiceLevels

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/new_store_api/models/routing_insights_service_levels.rb

Overview

RoutingInsightsServiceLevels Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(current = SKIP, original = SKIP) ⇒ RoutingInsightsServiceLevels

Returns a new instance of RoutingInsightsServiceLevels.



43
44
45
46
# File 'lib/new_store_api/models/routing_insights_service_levels.rb', line 43

def initialize(current = SKIP, original = SKIP)
  @current = current unless current == SKIP
  @original = original unless original == SKIP
end

Instance Attribute Details

#currentString

Service level with which the order was fulfilled

Returns:

  • (String)


14
15
16
# File 'lib/new_store_api/models/routing_insights_service_levels.rb', line 14

def current
  @current
end

#originalString

Service level with which the order was created

Returns:

  • (String)


18
19
20
# File 'lib/new_store_api/models/routing_insights_service_levels.rb', line 18

def original
  @original
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



49
50
51
52
53
54
55
56
57
58
59
# File 'lib/new_store_api/models/routing_insights_service_levels.rb', line 49

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  current = hash.key?('current') ? hash['current'] : SKIP
  original = hash.key?('original') ? hash['original'] : SKIP

  # Create object from extracted values.
  RoutingInsightsServiceLevels.new(current,
                                   original)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/new_store_api/models/routing_insights_service_levels.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['current'] = 'current'
  @_hash['original'] = 'original'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
40
41
# File 'lib/new_store_api/models/routing_insights_service_levels.rb', line 37

def self.nullables
  %w[
    current
  ]
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/new_store_api/models/routing_insights_service_levels.rb', line 29

def self.optionals
  %w[
    current
    original
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



63
64
65
66
67
68
69
# File 'lib/new_store_api/models/routing_insights_service_levels.rb', line 63

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



78
79
80
81
# File 'lib/new_store_api/models/routing_insights_service_levels.rb', line 78

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} current: #{@current.inspect}, original: #{@original.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



72
73
74
75
# File 'lib/new_store_api/models/routing_insights_service_levels.rb', line 72

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} current: #{@current}, original: #{@original}>"
end