Class: NewStoreApi::SalesOrderCancellationRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- NewStoreApi::SalesOrderCancellationRequest
- Defined in:
- lib/new_store_api/models/sales_order_cancellation_request.rb
Overview
Request schema for order cancellation.
Instance Attribute Summary collapse
-
#note ⇒ String
An optional note.
-
#reason ⇒ String
The reason why the order was cancelled.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(reason = nil, note = SKIP) ⇒ SalesOrderCancellationRequest
constructor
A new instance of SalesOrderCancellationRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(reason = nil, note = SKIP) ⇒ SalesOrderCancellationRequest
Returns a new instance of SalesOrderCancellationRequest.
40 41 42 43 |
# File 'lib/new_store_api/models/sales_order_cancellation_request.rb', line 40 def initialize(reason = nil, note = SKIP) @note = note unless note == SKIP @reason = reason end |
Instance Attribute Details
#note ⇒ String
An optional note.
14 15 16 |
# File 'lib/new_store_api/models/sales_order_cancellation_request.rb', line 14 def note @note end |
#reason ⇒ String
The reason why the order was cancelled.
18 19 20 |
# File 'lib/new_store_api/models/sales_order_cancellation_request.rb', line 18 def reason @reason end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/new_store_api/models/sales_order_cancellation_request.rb', line 46 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. reason = hash.key?('reason') ? hash['reason'] : nil note = hash.key?('note') ? hash['note'] : SKIP # Create object from extracted values. SalesOrderCancellationRequest.new(reason, note) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/new_store_api/models/sales_order_cancellation_request.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['note'] = 'note' @_hash['reason'] = 'reason' @_hash end |
.nullables ⇒ Object
An array for nullable fields
36 37 38 |
# File 'lib/new_store_api/models/sales_order_cancellation_request.rb', line 36 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 |
# File 'lib/new_store_api/models/sales_order_cancellation_request.rb', line 29 def self.optionals %w[ note ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
65 66 67 68 |
# File 'lib/new_store_api/models/sales_order_cancellation_request.rb', line 65 def inspect class_name = self.class.name.split('::').last "<#{class_name} note: #{@note.inspect}, reason: #{@reason.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
59 60 61 62 |
# File 'lib/new_store_api/models/sales_order_cancellation_request.rb', line 59 def to_s class_name = self.class.name.split('::').last "<#{class_name} note: #{@note}, reason: #{@reason}>" end |