Class: NewStoreApi::SalesOrderCancellationResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- NewStoreApi::SalesOrderCancellationResponse
- Defined in:
- lib/new_store_api/models/sales_order_cancellation_response.rb
Overview
Request schema for order cancellation status.
Instance Attribute Summary collapse
-
#cancelable ⇒ TrueClass | FalseClass
Describes if the order is cancelable in the current state.
-
#canceled ⇒ TrueClass | FalseClass
Describes if the order has been canceled.
-
#is_safe ⇒ TrueClass | FalseClass
Describes if it is safe to cancel the order in the current state.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(cancelable = nil, canceled = nil, is_safe = nil) ⇒ SalesOrderCancellationResponse
constructor
A new instance of SalesOrderCancellationResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(cancelable = nil, canceled = nil, is_safe = nil) ⇒ SalesOrderCancellationResponse
Returns a new instance of SalesOrderCancellationResponse.
43 44 45 46 47 |
# File 'lib/new_store_api/models/sales_order_cancellation_response.rb', line 43 def initialize(cancelable = nil, canceled = nil, is_safe = nil) @cancelable = cancelable @canceled = canceled @is_safe = is_safe end |
Instance Attribute Details
#cancelable ⇒ TrueClass | FalseClass
Describes if the order is cancelable in the current state.
14 15 16 |
# File 'lib/new_store_api/models/sales_order_cancellation_response.rb', line 14 def cancelable @cancelable end |
#canceled ⇒ TrueClass | FalseClass
Describes if the order has been canceled.
18 19 20 |
# File 'lib/new_store_api/models/sales_order_cancellation_response.rb', line 18 def canceled @canceled end |
#is_safe ⇒ TrueClass | FalseClass
Describes if it is safe to cancel the order in the current state.
22 23 24 |
# File 'lib/new_store_api/models/sales_order_cancellation_response.rb', line 22 def is_safe @is_safe end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
50 51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/new_store_api/models/sales_order_cancellation_response.rb', line 50 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. cancelable = hash.key?('cancelable') ? hash['cancelable'] : nil canceled = hash.key?('canceled') ? hash['canceled'] : nil is_safe = hash.key?('is_safe') ? hash['is_safe'] : nil # Create object from extracted values. SalesOrderCancellationResponse.new(cancelable, canceled, is_safe) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/new_store_api/models/sales_order_cancellation_response.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['cancelable'] = 'cancelable' @_hash['canceled'] = 'canceled' @_hash['is_safe'] = 'is_safe' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/new_store_api/models/sales_order_cancellation_response.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/new_store_api/models/sales_order_cancellation_response.rb', line 34 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
71 72 73 74 75 |
# File 'lib/new_store_api/models/sales_order_cancellation_response.rb', line 71 def inspect class_name = self.class.name.split('::').last "<#{class_name} cancelable: #{@cancelable.inspect}, canceled: #{@canceled.inspect},"\ " is_safe: #{@is_safe.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
65 66 67 68 |
# File 'lib/new_store_api/models/sales_order_cancellation_response.rb', line 65 def to_s class_name = self.class.name.split('::').last "<#{class_name} cancelable: #{@cancelable}, canceled: #{@canceled}, is_safe: #{@is_safe}>" end |