Class: NewStoreApi::SalesOrderExternalIdentifier
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- NewStoreApi::SalesOrderExternalIdentifier
- Defined in:
- lib/new_store_api/models/sales_order_external_identifier.rb
Overview
External identifier for the order item
Instance Attribute Summary collapse
-
#epc ⇒ String
EPC (Electronic Product Code) for order item.
-
#serial_number ⇒ String
Serial number of order item.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(epc = SKIP, serial_number = SKIP) ⇒ SalesOrderExternalIdentifier
constructor
A new instance of SalesOrderExternalIdentifier.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(epc = SKIP, serial_number = SKIP) ⇒ SalesOrderExternalIdentifier
Returns a new instance of SalesOrderExternalIdentifier.
41 42 43 44 |
# File 'lib/new_store_api/models/sales_order_external_identifier.rb', line 41 def initialize(epc = SKIP, serial_number = SKIP) @epc = epc unless epc == SKIP @serial_number = serial_number unless serial_number == SKIP end |
Instance Attribute Details
#epc ⇒ String
EPC (Electronic Product Code) for order item
14 15 16 |
# File 'lib/new_store_api/models/sales_order_external_identifier.rb', line 14 def epc @epc end |
#serial_number ⇒ String
Serial number of order item
18 19 20 |
# File 'lib/new_store_api/models/sales_order_external_identifier.rb', line 18 def serial_number @serial_number end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/new_store_api/models/sales_order_external_identifier.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. epc = hash.key?('epc') ? hash['epc'] : SKIP serial_number = hash.key?('serial_number') ? hash['serial_number'] : SKIP # Create object from extracted values. SalesOrderExternalIdentifier.new(epc, serial_number) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/new_store_api/models/sales_order_external_identifier.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['epc'] = 'epc' @_hash['serial_number'] = 'serial_number' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/new_store_api/models/sales_order_external_identifier.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/new_store_api/models/sales_order_external_identifier.rb', line 29 def self.optionals %w[ epc serial_number ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
66 67 68 69 |
# File 'lib/new_store_api/models/sales_order_external_identifier.rb', line 66 def inspect class_name = self.class.name.split('::').last "<#{class_name} epc: #{@epc.inspect}, serial_number: #{@serial_number.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
60 61 62 63 |
# File 'lib/new_store_api/models/sales_order_external_identifier.rb', line 60 def to_s class_name = self.class.name.split('::').last "<#{class_name} epc: #{@epc}, serial_number: #{@serial_number}>" end |