Class: NewStoreApi::SalesOrderFulfillment

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/new_store_api/models/sales_order_fulfillment.rb

Overview

SalesOrderFulfillment Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(item_ids = nil, origin = SKIP) ⇒ SalesOrderFulfillment

Returns a new instance of SalesOrderFulfillment.



41
42
43
44
# File 'lib/new_store_api/models/sales_order_fulfillment.rb', line 41

def initialize(item_ids = nil, origin = SKIP)
  @item_ids = item_ids
  @origin = origin unless origin == SKIP
end

Instance Attribute Details

#item_idsArray[String]

The order item UUIDs belonging to this fulfillment group.

Returns:

  • (Array[String])


14
15
16
# File 'lib/new_store_api/models/sales_order_fulfillment.rb', line 14

def item_ids
  @item_ids
end

#originOrigin

The ship-from origin for this fulfillment group. Omitted when neither zip code nor country code is known.

Returns:



19
20
21
# File 'lib/new_store_api/models/sales_order_fulfillment.rb', line 19

def origin
  @origin
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



47
48
49
50
51
52
53
54
55
56
57
# File 'lib/new_store_api/models/sales_order_fulfillment.rb', line 47

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  item_ids = hash.key?('item_ids') ? hash['item_ids'] : nil
  origin = Origin.from_hash(hash['origin']) if hash['origin']

  # Create object from extracted values.
  SalesOrderFulfillment.new(item_ids,
                            origin)
end

.namesObject

A mapping from model property names to API property names.



22
23
24
25
26
27
# File 'lib/new_store_api/models/sales_order_fulfillment.rb', line 22

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['item_ids'] = 'item_ids'
  @_hash['origin'] = 'origin'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/new_store_api/models/sales_order_fulfillment.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



30
31
32
33
34
# File 'lib/new_store_api/models/sales_order_fulfillment.rb', line 30

def self.optionals
  %w[
    origin
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



66
67
68
69
# File 'lib/new_store_api/models/sales_order_fulfillment.rb', line 66

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} item_ids: #{@item_ids.inspect}, origin: #{@origin.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



60
61
62
63
# File 'lib/new_store_api/models/sales_order_fulfillment.rb', line 60

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} item_ids: #{@item_ids}, origin: #{@origin}>"
end