Class: NewStoreApi::SalesOrderListResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/new_store_api/models/sales_order_list_response.rb

Overview

Order history for a customer retrieved from external OMS

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(orders = nil) ⇒ SalesOrderListResponse

Returns a new instance of SalesOrderListResponse.



33
34
35
# File 'lib/new_store_api/models/sales_order_list_response.rb', line 33

def initialize(orders = nil)
  @orders = orders
end

Instance Attribute Details

#ordersArray[SalesOrder]

Customer's order history

Returns:



14
15
16
# File 'lib/new_store_api/models/sales_order_list_response.rb', line 14

def orders
  @orders
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
# File 'lib/new_store_api/models/sales_order_list_response.rb', line 38

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  orders = nil
  unless hash['orders'].nil?
    orders = []
    hash['orders'].each do |structure|
      orders << (SalesOrder.from_hash(structure) if structure)
    end
  end

  orders = nil unless hash.key?('orders')

  # Create object from extracted values.
  SalesOrderListResponse.new(orders)
end

.namesObject

A mapping from model property names to API property names.



17
18
19
20
21
# File 'lib/new_store_api/models/sales_order_list_response.rb', line 17

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['orders'] = 'orders'
  @_hash
end

.nullablesObject

An array for nullable fields



29
30
31
# File 'lib/new_store_api/models/sales_order_list_response.rb', line 29

def self.nullables
  []
end

.optionalsObject

An array for optional fields



24
25
26
# File 'lib/new_store_api/models/sales_order_list_response.rb', line 24

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



64
65
66
67
# File 'lib/new_store_api/models/sales_order_list_response.rb', line 64

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} orders: #{@orders.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



58
59
60
61
# File 'lib/new_store_api/models/sales_order_list_response.rb', line 58

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} orders: #{@orders}>"
end