Class: NewStoreApi::SalesOrderListResponseV2

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/new_store_api/models/sales_order_list_response_v2.rb

Overview

Order history for a customer retrieved from NewStore OMS

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(orders = nil, pagination_info = nil) ⇒ SalesOrderListResponseV2

Returns a new instance of SalesOrderListResponseV2.



39
40
41
42
# File 'lib/new_store_api/models/sales_order_list_response_v2.rb', line 39

def initialize(orders = nil, pagination_info = nil)
  @orders = orders
  @pagination_info = pagination_info
end

Instance Attribute Details

#ordersArray[SalesOrderV2]

Contains the list of orders for the customer with the given customer_id.

Returns:



15
16
17
# File 'lib/new_store_api/models/sales_order_list_response_v2.rb', line 15

def orders
  @orders
end

#pagination_infoPaginatedResponse

Pagination information for the order history response.

Returns:



19
20
21
# File 'lib/new_store_api/models/sales_order_list_response_v2.rb', line 19

def pagination_info
  @pagination_info
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
# File 'lib/new_store_api/models/sales_order_list_response_v2.rb', line 45

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  orders = nil
  unless hash['orders'].nil?
    orders = []
    hash['orders'].each do |structure|
      orders << (SalesOrderV2.from_hash(structure) if structure)
    end
  end

  orders = nil unless hash.key?('orders')
  pagination_info = PaginatedResponse.from_hash(hash['pagination_info']) if
    hash['pagination_info']

  # Create object from extracted values.
  SalesOrderListResponseV2.new(orders,
                               pagination_info)
end

.namesObject

A mapping from model property names to API property names.



22
23
24
25
26
27
# File 'lib/new_store_api/models/sales_order_list_response_v2.rb', line 22

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['orders'] = 'orders'
  @_hash['pagination_info'] = 'pagination_info'
  @_hash
end

.nullablesObject

An array for nullable fields



35
36
37
# File 'lib/new_store_api/models/sales_order_list_response_v2.rb', line 35

def self.nullables
  []
end

.optionalsObject

An array for optional fields



30
31
32
# File 'lib/new_store_api/models/sales_order_list_response_v2.rb', line 30

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



74
75
76
77
# File 'lib/new_store_api/models/sales_order_list_response_v2.rb', line 74

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} orders: #{@orders.inspect}, pagination_info: #{@pagination_info.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



68
69
70
71
# File 'lib/new_store_api/models/sales_order_list_response_v2.rb', line 68

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} orders: #{@orders}, pagination_info: #{@pagination_info}>"
end