Class: NewStoreApi::SalesOrderPricesResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/new_store_api/models/sales_order_prices_response.rb

Overview

The response for retrieving price information.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(currency = nil, items = nil) ⇒ SalesOrderPricesResponse

Returns a new instance of SalesOrderPricesResponse.



38
39
40
41
# File 'lib/new_store_api/models/sales_order_prices_response.rb', line 38

def initialize(currency = nil, items = nil)
  @currency = currency
  @items = items
end

Instance Attribute Details

#currencyString

The currency that was used to buy the order, ISO 4217.

Returns:

  • (String)


14
15
16
# File 'lib/new_store_api/models/sales_order_prices_response.rb', line 14

def currency
  @currency
end

#itemsArray[Object]

The currency that was used to buy the order, ISO 4217.

Returns:

  • (Array[Object])


18
19
20
# File 'lib/new_store_api/models/sales_order_prices_response.rb', line 18

def items
  @items
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



44
45
46
47
48
49
50
51
52
53
54
55
56
# File 'lib/new_store_api/models/sales_order_prices_response.rb', line 44

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  currency = hash.key?('currency') ? hash['currency'] : nil
  items = hash.key?('items') ? APIHelper.deserialize_union_type(
    UnionTypeLookUp.get(:SalesOrderPricesResponseItems), hash['items']
  ) : nil

  # Create object from extracted values.
  SalesOrderPricesResponse.new(currency,
                               items)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/new_store_api/models/sales_order_prices_response.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['currency'] = 'currency'
  @_hash['items'] = 'items'
  @_hash
end

.nullablesObject

An array for nullable fields



34
35
36
# File 'lib/new_store_api/models/sales_order_prices_response.rb', line 34

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
# File 'lib/new_store_api/models/sales_order_prices_response.rb', line 29

def self.optionals
  []
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/new_store_api/models/sales_order_prices_response.rb', line 60

def self.validate(value)
  if value.instance_of? self
    return (
      APIHelper.valid_type?(value.currency,
                            ->(val) { val.instance_of? String }) and
        UnionTypeLookUp.get(:SalesOrderPricesResponseItems)
                       .validate(value.items)
    )
  end

  return false unless value.instance_of? Hash

  (
    APIHelper.valid_type?(value['currency'],
                          ->(val) { val.instance_of? String }) and
      UnionTypeLookUp.get(:SalesOrderPricesResponseItems)
                     .validate(value['items'])
  )
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



87
88
89
90
# File 'lib/new_store_api/models/sales_order_prices_response.rb', line 87

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} currency: #{@currency.inspect}, items: #{@items.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



81
82
83
84
# File 'lib/new_store_api/models/sales_order_prices_response.rb', line 81

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} currency: #{@currency}, items: #{@items}>"
end