Class: NewStoreApi::SignatureBeV1Dto

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/new_store_api/models/signature_be_v1_dto.rb

Overview

SignatureBeV1Dto Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(digital_signature = nil, digital_signature_qr_code = nil, environment = nil, receipt_number = nil, series_name = nil) ⇒ SignatureBeV1Dto

Returns a new instance of SignatureBeV1Dto.



53
54
55
56
57
58
59
60
# File 'lib/new_store_api/models/signature_be_v1_dto.rb', line 53

def initialize(digital_signature = nil, digital_signature_qr_code = nil,
               environment = nil, receipt_number = nil, series_name = nil)
  @digital_signature = digital_signature
  @digital_signature_qr_code = digital_signature_qr_code
  @environment = environment
  @receipt_number = receipt_number
  @series_name = series_name
end

Instance Attribute Details

#digital_signatureString

Digital signature (ES256 JWT) of the chained transaction data

Returns:

  • (String)


14
15
16
# File 'lib/new_store_api/models/signature_be_v1_dto.rb', line 14

def digital_signature
  @digital_signature
end

#digital_signature_qr_codeString

QR code of the digital signature, as a base64-encoded PNG image

Returns:

  • (String)


18
19
20
# File 'lib/new_store_api/models/signature_be_v1_dto.rb', line 18

def digital_signature_qr_code
  @digital_signature_qr_code
end

#environmentFiscalEnvironmentEnum

QR code of the digital signature, as a base64-encoded PNG image



22
23
24
# File 'lib/new_store_api/models/signature_be_v1_dto.rb', line 22

def environment
  @environment
end

#receipt_numberString

Receipt Number

Returns:

  • (String)


26
27
28
# File 'lib/new_store_api/models/signature_be_v1_dto.rb', line 26

def receipt_number
  @receipt_number
end

#series_nameString

The name of the sequencing series used to generate the receipt number.

Returns:

  • (String)


30
31
32
# File 'lib/new_store_api/models/signature_be_v1_dto.rb', line 30

def series_name
  @series_name
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/new_store_api/models/signature_be_v1_dto.rb', line 63

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  digital_signature =
    hash.key?('digital_signature') ? hash['digital_signature'] : nil
  digital_signature_qr_code =
    hash.key?('digital_signature_qr_code') ? hash['digital_signature_qr_code'] : nil
  environment = hash.key?('environment') ? hash['environment'] : nil
  receipt_number =
    hash.key?('receipt_number') ? hash['receipt_number'] : nil
  series_name = hash.key?('series_name') ? hash['series_name'] : nil

  # Create object from extracted values.
  SignatureBeV1Dto.new(digital_signature,
                       digital_signature_qr_code,
                       environment,
                       receipt_number,
                       series_name)
end

.namesObject

A mapping from model property names to API property names.



33
34
35
36
37
38
39
40
41
# File 'lib/new_store_api/models/signature_be_v1_dto.rb', line 33

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['digital_signature'] = 'digital_signature'
  @_hash['digital_signature_qr_code'] = 'digital_signature_qr_code'
  @_hash['environment'] = 'environment'
  @_hash['receipt_number'] = 'receipt_number'
  @_hash['series_name'] = 'series_name'
  @_hash
end

.nullablesObject

An array for nullable fields



49
50
51
# File 'lib/new_store_api/models/signature_be_v1_dto.rb', line 49

def self.nullables
  []
end

.optionalsObject

An array for optional fields



44
45
46
# File 'lib/new_store_api/models/signature_be_v1_dto.rb', line 44

def self.optionals
  []
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/new_store_api/models/signature_be_v1_dto.rb', line 86

def self.validate(value)
  if value.instance_of? self
    return (
      APIHelper.valid_type?(value.digital_signature,
                            ->(val) { val.instance_of? String }) and
        APIHelper.valid_type?(value.digital_signature_qr_code,
                              ->(val) { val.instance_of? String }) and
        APIHelper.valid_type?(value.environment,
                              ->(val) { FiscalEnvironmentEnum.validate(val) }) and
        APIHelper.valid_type?(value.receipt_number,
                              ->(val) { val.instance_of? String }) and
        APIHelper.valid_type?(value.series_name,
                              ->(val) { val.instance_of? String })
    )
  end

  return false unless value.instance_of? Hash

  (
    APIHelper.valid_type?(value['digital_signature'],
                          ->(val) { val.instance_of? String }) and
      APIHelper.valid_type?(value['digital_signature_qr_code'],
                            ->(val) { val.instance_of? String }) and
      APIHelper.valid_type?(value['environment'],
                            ->(val) { FiscalEnvironmentEnum.validate(val) }) and
      APIHelper.valid_type?(value['receipt_number'],
                            ->(val) { val.instance_of? String }) and
      APIHelper.valid_type?(value['series_name'],
                            ->(val) { val.instance_of? String })
  )
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



127
128
129
130
131
132
133
# File 'lib/new_store_api/models/signature_be_v1_dto.rb', line 127

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} digital_signature: #{@digital_signature.inspect},"\
  " digital_signature_qr_code: #{@digital_signature_qr_code.inspect}, environment:"\
  " #{@environment.inspect}, receipt_number: #{@receipt_number.inspect}, series_name:"\
  " #{@series_name.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



119
120
121
122
123
124
# File 'lib/new_store_api/models/signature_be_v1_dto.rb', line 119

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} digital_signature: #{@digital_signature}, digital_signature_qr_code:"\
  " #{@digital_signature_qr_code}, environment: #{@environment}, receipt_number:"\
  " #{@receipt_number}, series_name: #{@series_name}>"
end