Class: NewStoreApi::SignatureEsV1Dto
- Defined in:
- lib/new_store_api/models/signature_es_v1_dto.rb
Overview
SignatureEsV1Dto Model.
Instance Attribute Summary collapse
-
#environment ⇒ EnvironmentEnum
Fiscal Environment.
-
#receipt_number ⇒ String
Receipt Number.
-
#series_name ⇒ String
The name of the sequencing series used to generate the receipt number.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(environment = nil, receipt_number = nil, series_name = nil) ⇒ SignatureEsV1Dto
constructor
A new instance of SignatureEsV1Dto.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(environment = nil, receipt_number = nil, series_name = nil) ⇒ SignatureEsV1Dto
Returns a new instance of SignatureEsV1Dto.
43 44 45 46 47 |
# File 'lib/new_store_api/models/signature_es_v1_dto.rb', line 43 def initialize(environment = nil, receipt_number = nil, series_name = nil) @environment = environment @receipt_number = receipt_number @series_name = series_name end |
Instance Attribute Details
#environment ⇒ EnvironmentEnum
Fiscal Environment
14 15 16 |
# File 'lib/new_store_api/models/signature_es_v1_dto.rb', line 14 def environment @environment end |
#receipt_number ⇒ String
Receipt Number
18 19 20 |
# File 'lib/new_store_api/models/signature_es_v1_dto.rb', line 18 def receipt_number @receipt_number end |
#series_name ⇒ String
The name of the sequencing series used to generate the receipt number.
22 23 24 |
# File 'lib/new_store_api/models/signature_es_v1_dto.rb', line 22 def series_name @series_name end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/new_store_api/models/signature_es_v1_dto.rb', line 50 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. environment = hash.key?('environment') ? hash['environment'] : nil receipt_number = hash.key?('receipt_number') ? hash['receipt_number'] : nil series_name = hash.key?('series_name') ? hash['series_name'] : nil # Create object from extracted values. SignatureEsV1Dto.new(environment, receipt_number, series_name) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/new_store_api/models/signature_es_v1_dto.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['environment'] = 'environment' @_hash['receipt_number'] = 'receipt_number' @_hash['series_name'] = 'series_name' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/new_store_api/models/signature_es_v1_dto.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/new_store_api/models/signature_es_v1_dto.rb', line 34 def self.optionals [] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/new_store_api/models/signature_es_v1_dto.rb', line 67 def self.validate(value) if value.instance_of? self return ( APIHelper.valid_type?(value.environment, ->(val) { EnvironmentEnum.validate(val) }) and APIHelper.valid_type?(value.receipt_number, ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value.series_name, ->(val) { val.instance_of? String }) ) end return false unless value.instance_of? Hash ( APIHelper.valid_type?(value['environment'], ->(val) { EnvironmentEnum.validate(val) }) and APIHelper.valid_type?(value['receipt_number'], ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value['series_name'], ->(val) { val.instance_of? String }) ) end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
99 100 101 102 103 |
# File 'lib/new_store_api/models/signature_es_v1_dto.rb', line 99 def inspect class_name = self.class.name.split('::').last "<#{class_name} environment: #{@environment.inspect}, receipt_number:"\ " #{@receipt_number.inspect}, series_name: #{@series_name.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
92 93 94 95 96 |
# File 'lib/new_store_api/models/signature_es_v1_dto.rb', line 92 def to_s class_name = self.class.name.split('::').last "<#{class_name} environment: #{@environment}, receipt_number: #{@receipt_number},"\ " series_name: #{@series_name}>" end |