Class: NewStoreApi::SimulationRoutedItem
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- NewStoreApi::SimulationRoutedItem
- Defined in:
- lib/new_store_api/models/simulation_routed_item.rb
Overview
Routed line item with the selected location.
Instance Attribute Summary collapse
-
#fulfillment_node_id ⇒ String
Location selected for the line item.
-
#line_item_id ⇒ String
Line item identifier from the request.
-
#product_id ⇒ String
Product identifier from the request.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(fulfillment_node_id = nil, line_item_id = nil, product_id = nil) ⇒ SimulationRoutedItem
constructor
A new instance of SimulationRoutedItem.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(fulfillment_node_id = nil, line_item_id = nil, product_id = nil) ⇒ SimulationRoutedItem
Returns a new instance of SimulationRoutedItem.
43 44 45 46 47 48 |
# File 'lib/new_store_api/models/simulation_routed_item.rb', line 43 def initialize(fulfillment_node_id = nil, line_item_id = nil, product_id = nil) @fulfillment_node_id = fulfillment_node_id @line_item_id = line_item_id @product_id = product_id end |
Instance Attribute Details
#fulfillment_node_id ⇒ String
Location selected for the line item.
14 15 16 |
# File 'lib/new_store_api/models/simulation_routed_item.rb', line 14 def fulfillment_node_id @fulfillment_node_id end |
#line_item_id ⇒ String
Line item identifier from the request.
18 19 20 |
# File 'lib/new_store_api/models/simulation_routed_item.rb', line 18 def line_item_id @line_item_id end |
#product_id ⇒ String
Product identifier from the request.
22 23 24 |
# File 'lib/new_store_api/models/simulation_routed_item.rb', line 22 def product_id @product_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/new_store_api/models/simulation_routed_item.rb', line 51 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. fulfillment_node_id = hash.key?('fulfillment_node_id') ? hash['fulfillment_node_id'] : nil line_item_id = hash.key?('line_item_id') ? hash['line_item_id'] : nil product_id = hash.key?('product_id') ? hash['product_id'] : nil # Create object from extracted values. SimulationRoutedItem.new(fulfillment_node_id, line_item_id, product_id) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/new_store_api/models/simulation_routed_item.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['fulfillment_node_id'] = 'fulfillment_node_id' @_hash['line_item_id'] = 'line_item_id' @_hash['product_id'] = 'product_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/new_store_api/models/simulation_routed_item.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/new_store_api/models/simulation_routed_item.rb', line 34 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
74 75 76 77 78 |
# File 'lib/new_store_api/models/simulation_routed_item.rb', line 74 def inspect class_name = self.class.name.split('::').last "<#{class_name} fulfillment_node_id: #{@fulfillment_node_id.inspect}, line_item_id:"\ " #{@line_item_id.inspect}, product_id: #{@product_id.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
67 68 69 70 71 |
# File 'lib/new_store_api/models/simulation_routed_item.rb', line 67 def to_s class_name = self.class.name.split('::').last "<#{class_name} fulfillment_node_id: #{@fulfillment_node_id}, line_item_id:"\ " #{@line_item_id}, product_id: #{@product_id}>" end |