Class: NewStoreApi::StockProductAvailabilityResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/new_store_api/models/stock_product_availability_response.rb

Overview

Paginated response of valid request for fetching availabilities by products.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(has_more = nil, items = nil) ⇒ StockProductAvailabilityResponse

Returns a new instance of StockProductAvailabilityResponse.



38
39
40
41
# File 'lib/new_store_api/models/stock_product_availability_response.rb', line 38

def initialize(has_more = nil, items = nil)
  @has_more = has_more
  @items = items
end

Instance Attribute Details

#has_moreTrueClass | FalseClass

Boolean value which indicates if the result has more pages to be fetched

Returns:

  • (TrueClass | FalseClass)


14
15
16
# File 'lib/new_store_api/models/stock_product_availability_response.rb', line 14

def has_more
  @has_more
end

#itemsArray[Item5]

Boolean value which indicates if the result has more pages to be fetched

Returns:



18
19
20
# File 'lib/new_store_api/models/stock_product_availability_response.rb', line 18

def items
  @items
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/new_store_api/models/stock_product_availability_response.rb', line 44

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  has_more = hash.key?('has_more') ? hash['has_more'] : nil
  # Parameter is an array, so we need to iterate through it
  items = nil
  unless hash['items'].nil?
    items = []
    hash['items'].each do |structure|
      items << (Item5.from_hash(structure) if structure)
    end
  end

  items = nil unless hash.key?('items')

  # Create object from extracted values.
  StockProductAvailabilityResponse.new(has_more,
                                       items)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/new_store_api/models/stock_product_availability_response.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['has_more'] = 'has_more'
  @_hash['items'] = 'items'
  @_hash
end

.nullablesObject

An array for nullable fields



34
35
36
# File 'lib/new_store_api/models/stock_product_availability_response.rb', line 34

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
# File 'lib/new_store_api/models/stock_product_availability_response.rb', line 29

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



72
73
74
75
# File 'lib/new_store_api/models/stock_product_availability_response.rb', line 72

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} has_more: #{@has_more.inspect}, items: #{@items.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



66
67
68
69
# File 'lib/new_store_api/models/stock_product_availability_response.rb', line 66

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} has_more: #{@has_more}, items: #{@items}>"
end