Class: NewStoreApi::Subscription

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/new_store_api/models/subscription.rb

Overview

Subscription Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(topic_name = SKIP, topic_value = SKIP) ⇒ Subscription

Returns a new instance of Subscription.



42
43
44
45
# File 'lib/new_store_api/models/subscription.rb', line 42

def initialize(topic_name = SKIP, topic_value = SKIP)
  @topic_name = topic_name unless topic_name == SKIP
  @topic_value = topic_value unless topic_value == SKIP
end

Instance Attribute Details

#topic_nameString

Identifier topic name for this subscription

Returns:

  • (String)


14
15
16
# File 'lib/new_store_api/models/subscription.rb', line 14

def topic_name
  @topic_name
end

#topic_valueString

Identifier topic value for this subscription which can be 'True' or 'False'

Returns:

  • (String)


19
20
21
# File 'lib/new_store_api/models/subscription.rb', line 19

def topic_value
  @topic_value
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



48
49
50
51
52
53
54
55
56
57
58
# File 'lib/new_store_api/models/subscription.rb', line 48

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  topic_name = hash.key?('topic_name') ? hash['topic_name'] : SKIP
  topic_value = hash.key?('topic_value') ? hash['topic_value'] : SKIP

  # Create object from extracted values.
  Subscription.new(topic_name,
                   topic_value)
end

.namesObject

A mapping from model property names to API property names.



22
23
24
25
26
27
# File 'lib/new_store_api/models/subscription.rb', line 22

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['topic_name'] = 'topic_name'
  @_hash['topic_value'] = 'topic_value'
  @_hash
end

.nullablesObject

An array for nullable fields



38
39
40
# File 'lib/new_store_api/models/subscription.rb', line 38

def self.nullables
  []
end

.optionalsObject

An array for optional fields



30
31
32
33
34
35
# File 'lib/new_store_api/models/subscription.rb', line 30

def self.optionals
  %w[
    topic_name
    topic_value
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



67
68
69
70
# File 'lib/new_store_api/models/subscription.rb', line 67

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} topic_name: #{@topic_name.inspect}, topic_value: #{@topic_value.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



61
62
63
64
# File 'lib/new_store_api/models/subscription.rb', line 61

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} topic_name: #{@topic_name}, topic_value: #{@topic_value}>"
end