Class: NewStoreApi::SupportedIdentityProvider
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- NewStoreApi::SupportedIdentityProvider
- Defined in:
- lib/new_store_api/models/supported_identity_provider.rb
Overview
Supported identity providers and protocols
Instance Attribute Summary collapse
-
#protocol ⇒ IdentityProviderProtocolEnum
Supported Protocols for Identity Providers.
-
#vendor ⇒ IdentityProviderVendorEnum
Supported Vendors for Identity Providers.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(protocol = SKIP, vendor = SKIP) ⇒ SupportedIdentityProvider
constructor
A new instance of SupportedIdentityProvider.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(protocol = SKIP, vendor = SKIP) ⇒ SupportedIdentityProvider
Returns a new instance of SupportedIdentityProvider.
41 42 43 44 |
# File 'lib/new_store_api/models/supported_identity_provider.rb', line 41 def initialize(protocol = SKIP, vendor = SKIP) @protocol = protocol unless protocol == SKIP @vendor = vendor unless vendor == SKIP end |
Instance Attribute Details
#protocol ⇒ IdentityProviderProtocolEnum
Supported Protocols for Identity Providers
14 15 16 |
# File 'lib/new_store_api/models/supported_identity_provider.rb', line 14 def protocol @protocol end |
#vendor ⇒ IdentityProviderVendorEnum
Supported Vendors for Identity Providers
18 19 20 |
# File 'lib/new_store_api/models/supported_identity_provider.rb', line 18 def vendor @vendor end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/new_store_api/models/supported_identity_provider.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. protocol = hash.key?('protocol') ? hash['protocol'] : SKIP vendor = hash.key?('vendor') ? hash['vendor'] : SKIP # Create object from extracted values. SupportedIdentityProvider.new(protocol, vendor) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/new_store_api/models/supported_identity_provider.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['protocol'] = 'protocol' @_hash['vendor'] = 'vendor' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/new_store_api/models/supported_identity_provider.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/new_store_api/models/supported_identity_provider.rb', line 29 def self.optionals %w[ protocol vendor ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
66 67 68 69 |
# File 'lib/new_store_api/models/supported_identity_provider.rb', line 66 def inspect class_name = self.class.name.split('::').last "<#{class_name} protocol: #{@protocol.inspect}, vendor: #{@vendor.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
60 61 62 63 |
# File 'lib/new_store_api/models/supported_identity_provider.rb', line 60 def to_s class_name = self.class.name.split('::').last "<#{class_name} protocol: #{@protocol}, vendor: #{@vendor}>" end |