Class: NewStoreApi::TaxInformation
- Defined in:
- lib/new_store_api/models/tax_information.rb
Overview
Metadata about the tax of the order.
Instance Attribute Summary collapse
-
#is_exempt ⇒ TrueClass | FalseClass
If the tax was exempted for this order.
-
#method ⇒ SalesOrderTaxMethodEnum
Method of calculation of the taxes, can be vat_included or vat_excluded.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(is_exempt = nil, method = nil) ⇒ TaxInformation
constructor
A new instance of TaxInformation.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(is_exempt = nil, method = nil) ⇒ TaxInformation
Returns a new instance of TaxInformation.
39 40 41 42 |
# File 'lib/new_store_api/models/tax_information.rb', line 39 def initialize(is_exempt = nil, method = nil) @is_exempt = is_exempt @method = method end |
Instance Attribute Details
#is_exempt ⇒ TrueClass | FalseClass
If the tax was exempted for this order. In case of external orders, the flag will always return false.
15 16 17 |
# File 'lib/new_store_api/models/tax_information.rb', line 15 def is_exempt @is_exempt end |
#method ⇒ SalesOrderTaxMethodEnum
Method of calculation of the taxes, can be vat_included or vat_excluded.
19 20 21 |
# File 'lib/new_store_api/models/tax_information.rb', line 19 def method @method end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/new_store_api/models/tax_information.rb', line 45 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. is_exempt = hash.key?('is_exempt') ? hash['is_exempt'] : nil method = hash.key?('method') ? hash['method'] : nil # Create object from extracted values. TaxInformation.new(is_exempt, method) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/new_store_api/models/tax_information.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['is_exempt'] = 'is_exempt' @_hash['method'] = 'method' @_hash end |
.nullables ⇒ Object
An array for nullable fields
35 36 37 |
# File 'lib/new_store_api/models/tax_information.rb', line 35 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 |
# File 'lib/new_store_api/models/tax_information.rb', line 30 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
64 65 66 67 |
# File 'lib/new_store_api/models/tax_information.rb', line 64 def inspect class_name = self.class.name.split('::').last "<#{class_name} is_exempt: #{@is_exempt.inspect}, method: #{@method.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
58 59 60 61 |
# File 'lib/new_store_api/models/tax_information.rb', line 58 def to_s class_name = self.class.name.split('::').last "<#{class_name} is_exempt: #{@is_exempt}, method: #{@method}>" end |