Class: NewStoreApi::TokensResponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/new_store_api/models/tokens_response.rb

Overview

Tokens response.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(data = nil, errors = nil) ⇒ TokensResponse

Returns a new instance of TokensResponse.



39
40
41
42
# File 'lib/new_store_api/models/tokens_response.rb', line 39

def initialize(data = nil, errors = nil)
  @data = data
  @errors = errors
end

Instance Attribute Details

#dataObject

Keys with tokens or detokenized plaintext data, according to the operation.

Returns:

  • (Object)


15
16
17
# File 'lib/new_store_api/models/tokens_response.rb', line 15

def data
  @data
end

#errorsObject

Keys with error codes.

Returns:

  • (Object)


19
20
21
# File 'lib/new_store_api/models/tokens_response.rb', line 19

def errors
  @errors
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



45
46
47
48
49
50
51
52
53
54
55
# File 'lib/new_store_api/models/tokens_response.rb', line 45

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  data = hash.key?('data') ? hash['data'] : nil
  errors = hash.key?('errors') ? hash['errors'] : nil

  # Create object from extracted values.
  TokensResponse.new(data,
                     errors)
end

.namesObject

A mapping from model property names to API property names.



22
23
24
25
26
27
# File 'lib/new_store_api/models/tokens_response.rb', line 22

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['data'] = 'data'
  @_hash['errors'] = 'errors'
  @_hash
end

.nullablesObject

An array for nullable fields



35
36
37
# File 'lib/new_store_api/models/tokens_response.rb', line 35

def self.nullables
  []
end

.optionalsObject

An array for optional fields



30
31
32
# File 'lib/new_store_api/models/tokens_response.rb', line 30

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



64
65
66
67
# File 'lib/new_store_api/models/tokens_response.rb', line 64

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} data: #{@data.inspect}, errors: #{@errors.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



58
59
60
61
# File 'lib/new_store_api/models/tokens_response.rb', line 58

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} data: #{@data}, errors: #{@errors}>"
end