Class: NewStoreApi::UpdateOidcIdentityProviderConfig

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/new_store_api/models/update_oidc_identity_provider_config.rb

Overview

UpdateOidcIdentityProviderConfig Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(client_secret = nil) ⇒ UpdateOidcIdentityProviderConfig

Returns a new instance of UpdateOidcIdentityProviderConfig.



33
34
35
# File 'lib/new_store_api/models/update_oidc_identity_provider_config.rb', line 33

def initialize(client_secret = nil)
  @client_secret = client_secret
end

Instance Attribute Details

#client_secretString

Client secret of an OIDC client

Returns:

  • (String)


14
15
16
# File 'lib/new_store_api/models/update_oidc_identity_provider_config.rb', line 14

def client_secret
  @client_secret
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



38
39
40
41
42
43
44
45
46
# File 'lib/new_store_api/models/update_oidc_identity_provider_config.rb', line 38

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  client_secret = hash.key?('client_secret') ? hash['client_secret'] : nil

  # Create object from extracted values.
  UpdateOidcIdentityProviderConfig.new(client_secret)
end

.namesObject

A mapping from model property names to API property names.



17
18
19
20
21
# File 'lib/new_store_api/models/update_oidc_identity_provider_config.rb', line 17

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['client_secret'] = 'client_secret'
  @_hash
end

.nullablesObject

An array for nullable fields



29
30
31
# File 'lib/new_store_api/models/update_oidc_identity_provider_config.rb', line 29

def self.nullables
  []
end

.optionalsObject

An array for optional fields



24
25
26
# File 'lib/new_store_api/models/update_oidc_identity_provider_config.rb', line 24

def self.optionals
  []
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



50
51
52
53
54
55
56
57
58
59
60
# File 'lib/new_store_api/models/update_oidc_identity_provider_config.rb', line 50

def self.validate(value)
  if value.instance_of? self
    return APIHelper.valid_type?(value.client_secret,
                                 ->(val) { val.instance_of? String })
  end

  return false unless value.instance_of? Hash

  APIHelper.valid_type?(value['client_secret'],
                        ->(val) { val.instance_of? String })
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



69
70
71
72
# File 'lib/new_store_api/models/update_oidc_identity_provider_config.rb', line 69

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} client_secret: #{@client_secret.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



63
64
65
66
# File 'lib/new_store_api/models/update_oidc_identity_provider_config.rb', line 63

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} client_secret: #{@client_secret}>"
end