Class: NewStoreApi::Warning

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/new_store_api/models/warning.rb

Overview

A warning stating what went wrong during the operation.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(code = nil, kind = nil, message = nil, ref = nil) ⇒ Warning

Returns a new instance of Warning.



48
49
50
51
52
53
# File 'lib/new_store_api/models/warning.rb', line 48

def initialize(code = nil, kind = nil, message = nil, ref = nil)
  @code = code
  @kind = kind
  @message = message
  @ref = ref
end

Instance Attribute Details

#codeString

A code related to the warning class.

Returns:

  • (String)


14
15
16
# File 'lib/new_store_api/models/warning.rb', line 14

def code
  @code
end

#kindString

The kind of the resource that caused the warning.

Returns:

  • (String)


18
19
20
# File 'lib/new_store_api/models/warning.rb', line 18

def kind
  @kind
end

#messageString

A message describing what went wrong.

Returns:

  • (String)


22
23
24
# File 'lib/new_store_api/models/warning.rb', line 22

def message
  @message
end

#refString

A reference to the object that caused the warning. Usually the ID of item.

Returns:

  • (String)


26
27
28
# File 'lib/new_store_api/models/warning.rb', line 26

def ref
  @ref
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/new_store_api/models/warning.rb', line 56

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  code = hash.key?('code') ? hash['code'] : nil
  kind = hash.key?('kind') ? hash['kind'] : nil
  message = hash.key?('message') ? hash['message'] : nil
  ref = hash.key?('ref') ? hash['ref'] : nil

  # Create object from extracted values.
  Warning.new(code,
              kind,
              message,
              ref)
end

.namesObject

A mapping from model property names to API property names.



29
30
31
32
33
34
35
36
# File 'lib/new_store_api/models/warning.rb', line 29

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['code'] = 'code'
  @_hash['kind'] = 'kind'
  @_hash['message'] = 'message'
  @_hash['ref'] = 'ref'
  @_hash
end

.nullablesObject

An array for nullable fields



44
45
46
# File 'lib/new_store_api/models/warning.rb', line 44

def self.nullables
  []
end

.optionalsObject

An array for optional fields



39
40
41
# File 'lib/new_store_api/models/warning.rb', line 39

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



79
80
81
82
83
# File 'lib/new_store_api/models/warning.rb', line 79

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} code: #{@code.inspect}, kind: #{@kind.inspect}, message:"\
  " #{@message.inspect}, ref: #{@ref.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



73
74
75
76
# File 'lib/new_store_api/models/warning.rb', line 73

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} code: #{@code}, kind: #{@kind}, message: #{@message}, ref: #{@ref}>"
end