Class: NewStoreApi::ZoneResponse
- Defined in:
- lib/new_store_api/models/zone_response.rb
Overview
ZoneResponse Model.
Instance Attribute Summary collapse
-
#count ⇒ Integer
Counted quantity.
-
#zone_code ⇒ String
Zone code.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(count = nil, zone_code = nil) ⇒ ZoneResponse
constructor
A new instance of ZoneResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(count = nil, zone_code = nil) ⇒ ZoneResponse
Returns a new instance of ZoneResponse.
38 39 40 41 |
# File 'lib/new_store_api/models/zone_response.rb', line 38 def initialize(count = nil, zone_code = nil) @count = count @zone_code = zone_code end |
Instance Attribute Details
#count ⇒ Integer
Counted quantity.
14 15 16 |
# File 'lib/new_store_api/models/zone_response.rb', line 14 def count @count end |
#zone_code ⇒ String
Zone code.
18 19 20 |
# File 'lib/new_store_api/models/zone_response.rb', line 18 def zone_code @zone_code end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/new_store_api/models/zone_response.rb', line 44 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. count = hash.key?('count') ? hash['count'] : nil zone_code = hash.key?('zone_code') ? hash['zone_code'] : nil # Create object from extracted values. ZoneResponse.new(count, zone_code) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/new_store_api/models/zone_response.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['count'] = 'count' @_hash['zone_code'] = 'zone_code' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/new_store_api/models/zone_response.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/new_store_api/models/zone_response.rb', line 29 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
63 64 65 66 |
# File 'lib/new_store_api/models/zone_response.rb', line 63 def inspect class_name = self.class.name.split('::').last "<#{class_name} count: #{@count.inspect}, zone_code: #{@zone_code.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
57 58 59 60 |
# File 'lib/new_store_api/models/zone_response.rb', line 57 def to_s class_name = self.class.name.split('::').last "<#{class_name} count: #{@count}, zone_code: #{@zone_code}>" end |