Class: NewStoreApi::AddReplaceOrTest
- Defined in:
- lib/new_store_api/models/add_replace_or_test.rb
Overview
AddReplaceOrTest Model.
Instance Attribute Summary collapse
-
#op ⇒ OpEnum
The operation to perform.
-
#path ⇒ String
A JSON Pointer path.
-
#value ⇒ Object
The value to add, replace or test.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(op = nil, path = nil, value = nil) ⇒ AddReplaceOrTest
constructor
A new instance of AddReplaceOrTest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(op = nil, path = nil, value = nil) ⇒ AddReplaceOrTest
Returns a new instance of AddReplaceOrTest.
43 44 45 46 47 |
# File 'lib/new_store_api/models/add_replace_or_test.rb', line 43 def initialize(op = nil, path = nil, value = nil) @op = op @path = path @value = value end |
Instance Attribute Details
#op ⇒ OpEnum
The operation to perform.
14 15 16 |
# File 'lib/new_store_api/models/add_replace_or_test.rb', line 14 def op @op end |
#path ⇒ String
A JSON Pointer path.
18 19 20 |
# File 'lib/new_store_api/models/add_replace_or_test.rb', line 18 def path @path end |
#value ⇒ Object
The value to add, replace or test.
22 23 24 |
# File 'lib/new_store_api/models/add_replace_or_test.rb', line 22 def value @value end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
50 51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/new_store_api/models/add_replace_or_test.rb', line 50 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. op = hash.key?('op') ? hash['op'] : nil path = hash.key?('path') ? hash['path'] : nil value = hash.key?('value') ? hash['value'] : nil # Create object from extracted values. AddReplaceOrTest.new(op, path, value) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/new_store_api/models/add_replace_or_test.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['op'] = 'op' @_hash['path'] = 'path' @_hash['value'] = 'value' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/new_store_api/models/add_replace_or_test.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/new_store_api/models/add_replace_or_test.rb', line 34 def self.optionals [] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/new_store_api/models/add_replace_or_test.rb', line 66 def self.validate(value) if value.instance_of? self return ( APIHelper.valid_type?(value.op, ->(val) { OpEnum.validate(val) }) and APIHelper.valid_type?(value.path, ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value.value, ->(val) { val.instance_of? Object }) ) end return false unless value.instance_of? Hash ( APIHelper.valid_type?(value['op'], ->(val) { OpEnum.validate(val) }) and APIHelper.valid_type?(value['path'], ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value['value'], ->(val) { val.instance_of? Object }) ) end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
97 98 99 100 |
# File 'lib/new_store_api/models/add_replace_or_test.rb', line 97 def inspect class_name = self.class.name.split('::').last "<#{class_name} op: #{@op.inspect}, path: #{@path.inspect}, value: #{@value.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
91 92 93 94 |
# File 'lib/new_store_api/models/add_replace_or_test.rb', line 91 def to_s class_name = self.class.name.split('::').last "<#{class_name} op: #{@op}, path: #{@path}, value: #{@value}>" end |