Class: NewStoreApi::AuditsResponse
- Defined in:
- lib/new_store_api/models/audits_response.rb
Overview
AuditsResponse Model.
Instance Attribute Summary collapse
-
#audits ⇒ Array[AuditReadOnly]
TODO: Write general description for this method.
-
#page_count ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(audits = nil, page_count = nil) ⇒ AuditsResponse
constructor
A new instance of AuditsResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(audits = nil, page_count = nil) ⇒ AuditsResponse
Returns a new instance of AuditsResponse.
38 39 40 41 |
# File 'lib/new_store_api/models/audits_response.rb', line 38 def initialize(audits = nil, page_count = nil) @audits = audits @page_count = page_count end |
Instance Attribute Details
#audits ⇒ Array[AuditReadOnly]
TODO: Write general description for this method
14 15 16 |
# File 'lib/new_store_api/models/audits_response.rb', line 14 def audits @audits end |
#page_count ⇒ Integer
TODO: Write general description for this method
18 19 20 |
# File 'lib/new_store_api/models/audits_response.rb', line 18 def page_count @page_count end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/new_store_api/models/audits_response.rb', line 44 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it audits = nil unless hash['audits'].nil? audits = [] hash['audits'].each do |structure| audits << (AuditReadOnly.from_hash(structure) if structure) end end audits = nil unless hash.key?('audits') page_count = hash.key?('page_count') ? hash['page_count'] : nil # Create object from extracted values. AuditsResponse.new(audits, page_count) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/new_store_api/models/audits_response.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['audits'] = 'audits' @_hash['page_count'] = 'page_count' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/new_store_api/models/audits_response.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/new_store_api/models/audits_response.rb', line 29 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
72 73 74 75 |
# File 'lib/new_store_api/models/audits_response.rb', line 72 def inspect class_name = self.class.name.split('::').last "<#{class_name} audits: #{@audits.inspect}, page_count: #{@page_count.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
66 67 68 69 |
# File 'lib/new_store_api/models/audits_response.rb', line 66 def to_s class_name = self.class.name.split('::').last "<#{class_name} audits: #{@audits}, page_count: #{@page_count}>" end |