Class: NewStoreApi::BillingAddress
- Defined in:
- lib/new_store_api/models/billing_address.rb
Overview
The consumer's billing address for the returned order. As billing address is optional for an order, this field is set to null when the order doesn't have an explicit billing address set.
Instance Attribute Summary collapse
-
#name ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(name = nil) ⇒ BillingAddress
constructor
A new instance of BillingAddress.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(name = nil) ⇒ BillingAddress
Returns a new instance of BillingAddress.
35 36 37 |
# File 'lib/new_store_api/models/billing_address.rb', line 35 def initialize(name = nil) @name = name end |
Instance Attribute Details
#name ⇒ String
TODO: Write general description for this method
16 17 18 |
# File 'lib/new_store_api/models/billing_address.rb', line 16 def name @name end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
40 41 42 43 44 45 46 47 48 |
# File 'lib/new_store_api/models/billing_address.rb', line 40 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. name = hash.key?('name') ? hash['name'] : nil # Create object from extracted values. BillingAddress.new(name) end |
.names ⇒ Object
A mapping from model property names to API property names.
19 20 21 22 23 |
# File 'lib/new_store_api/models/billing_address.rb', line 19 def self.names @_hash = {} if @_hash.nil? @_hash['name'] = 'name' @_hash end |
.nullables ⇒ Object
An array for nullable fields
31 32 33 |
# File 'lib/new_store_api/models/billing_address.rb', line 31 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
26 27 28 |
# File 'lib/new_store_api/models/billing_address.rb', line 26 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
57 58 59 60 |
# File 'lib/new_store_api/models/billing_address.rb', line 57 def inspect class_name = self.class.name.split('::').last "<#{class_name} name: #{@name.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
51 52 53 54 |
# File 'lib/new_store_api/models/billing_address.rb', line 51 def to_s class_name = self.class.name.split('::').last "<#{class_name} name: #{@name}>" end |