Class: NewStoreApi::CashDenominationsResponseDto
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- NewStoreApi::CashDenominationsResponseDto
- Defined in:
- lib/new_store_api/models/cash_denominations_response_dto.rb
Overview
CashDenominationsResponseDto Model.
Instance Attribute Summary collapse
-
#bills ⇒ Array[CashDenominationDto]
Bill denominations for the given currency code.
-
#coins ⇒ Array[CashDenominationDto]
Coin denominations for the given currency code.
-
#currency ⇒ String
Currency code in ISO 4217 format.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(bills = nil, coins = nil, currency = nil) ⇒ CashDenominationsResponseDto
constructor
A new instance of CashDenominationsResponseDto.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(bills = nil, coins = nil, currency = nil) ⇒ CashDenominationsResponseDto
Returns a new instance of CashDenominationsResponseDto.
43 44 45 46 47 |
# File 'lib/new_store_api/models/cash_denominations_response_dto.rb', line 43 def initialize(bills = nil, coins = nil, currency = nil) @bills = bills @coins = coins @currency = currency end |
Instance Attribute Details
#bills ⇒ Array[CashDenominationDto]
Bill denominations for the given currency code.
14 15 16 |
# File 'lib/new_store_api/models/cash_denominations_response_dto.rb', line 14 def bills @bills end |
#coins ⇒ Array[CashDenominationDto]
Coin denominations for the given currency code.
18 19 20 |
# File 'lib/new_store_api/models/cash_denominations_response_dto.rb', line 18 def coins @coins end |
#currency ⇒ String
Currency code in ISO 4217 format.
22 23 24 |
# File 'lib/new_store_api/models/cash_denominations_response_dto.rb', line 22 def currency @currency end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/new_store_api/models/cash_denominations_response_dto.rb', line 50 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it bills = nil unless hash['bills'].nil? bills = [] hash['bills'].each do |structure| bills << (CashDenominationDto.from_hash(structure) if structure) end end bills = nil unless hash.key?('bills') # Parameter is an array, so we need to iterate through it coins = nil unless hash['coins'].nil? coins = [] hash['coins'].each do |structure| coins << (CashDenominationDto.from_hash(structure) if structure) end end coins = nil unless hash.key?('coins') currency = hash.key?('currency') ? hash['currency'] : nil # Create object from extracted values. CashDenominationsResponseDto.new(bills, coins, currency) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/new_store_api/models/cash_denominations_response_dto.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['bills'] = 'bills' @_hash['coins'] = 'coins' @_hash['currency'] = 'currency' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/new_store_api/models/cash_denominations_response_dto.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/new_store_api/models/cash_denominations_response_dto.rb', line 34 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
89 90 91 92 93 |
# File 'lib/new_store_api/models/cash_denominations_response_dto.rb', line 89 def inspect class_name = self.class.name.split('::').last "<#{class_name} bills: #{@bills.inspect}, coins: #{@coins.inspect}, currency:"\ " #{@currency.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
83 84 85 86 |
# File 'lib/new_store_api/models/cash_denominations_response_dto.rb', line 83 def to_s class_name = self.class.name.split('::').last "<#{class_name} bills: #{@bills}, coins: #{@coins}, currency: #{@currency}>" end |