Class: NewStoreApi::CashboxConfigNewStoreBeV1Dto
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- NewStoreApi::CashboxConfigNewStoreBeV1Dto
- Defined in:
- lib/new_store_api/models/cashbox_config_new_store_be_v1_dto.rb
Overview
CashboxConfigNewStoreBeV1Dto Model.
Instance Attribute Summary collapse
-
#company_number ⇒ String
The Belgian company registration number (BCE/KBO number).
-
#receipt_number_prefix ⇒ String
Receipt number prefix that is used to construct the series name.
-
#vat_number ⇒ String
The VAT identification number of the legal entity.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(company_number = nil, receipt_number_prefix = nil, vat_number = nil) ⇒ CashboxConfigNewStoreBeV1Dto
constructor
A new instance of CashboxConfigNewStoreBeV1Dto.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(company_number = nil, receipt_number_prefix = nil, vat_number = nil) ⇒ CashboxConfigNewStoreBeV1Dto
Returns a new instance of CashboxConfigNewStoreBeV1Dto.
43 44 45 46 47 48 |
# File 'lib/new_store_api/models/cashbox_config_new_store_be_v1_dto.rb', line 43 def initialize(company_number = nil, receipt_number_prefix = nil, vat_number = nil) @company_number = company_number @receipt_number_prefix = receipt_number_prefix @vat_number = vat_number end |
Instance Attribute Details
#company_number ⇒ String
The Belgian company registration number (BCE/KBO number).
14 15 16 |
# File 'lib/new_store_api/models/cashbox_config_new_store_be_v1_dto.rb', line 14 def company_number @company_number end |
#receipt_number_prefix ⇒ String
Receipt number prefix that is used to construct the series name.
18 19 20 |
# File 'lib/new_store_api/models/cashbox_config_new_store_be_v1_dto.rb', line 18 def receipt_number_prefix @receipt_number_prefix end |
#vat_number ⇒ String
The VAT identification number of the legal entity.
22 23 24 |
# File 'lib/new_store_api/models/cashbox_config_new_store_be_v1_dto.rb', line 22 def vat_number @vat_number end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/new_store_api/models/cashbox_config_new_store_be_v1_dto.rb', line 51 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. company_number = hash.key?('company_number') ? hash['company_number'] : nil receipt_number_prefix = hash.key?('receipt_number_prefix') ? hash['receipt_number_prefix'] : nil vat_number = hash.key?('vat_number') ? hash['vat_number'] : nil # Create object from extracted values. CashboxConfigNewStoreBeV1Dto.new(company_number, receipt_number_prefix, vat_number) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/new_store_api/models/cashbox_config_new_store_be_v1_dto.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['company_number'] = 'company_number' @_hash['receipt_number_prefix'] = 'receipt_number_prefix' @_hash['vat_number'] = 'vat_number' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/new_store_api/models/cashbox_config_new_store_be_v1_dto.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/new_store_api/models/cashbox_config_new_store_be_v1_dto.rb', line 34 def self.optionals [] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/new_store_api/models/cashbox_config_new_store_be_v1_dto.rb', line 69 def self.validate(value) if value.instance_of? self return ( APIHelper.valid_type?(value.company_number, ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value.receipt_number_prefix, ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value.vat_number, ->(val) { val.instance_of? String }) ) end return false unless value.instance_of? Hash ( APIHelper.valid_type?(value['company_number'], ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value['receipt_number_prefix'], ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value['vat_number'], ->(val) { val.instance_of? String }) ) end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
101 102 103 104 105 |
# File 'lib/new_store_api/models/cashbox_config_new_store_be_v1_dto.rb', line 101 def inspect class_name = self.class.name.split('::').last "<#{class_name} company_number: #{@company_number.inspect}, receipt_number_prefix:"\ " #{@receipt_number_prefix.inspect}, vat_number: #{@vat_number.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
94 95 96 97 98 |
# File 'lib/new_store_api/models/cashbox_config_new_store_be_v1_dto.rb', line 94 def to_s class_name = self.class.name.split('::').last "<#{class_name} company_number: #{@company_number}, receipt_number_prefix:"\ " #{@receipt_number_prefix}, vat_number: #{@vat_number}>" end |