Class: NewStoreApi::Conditions
- Defined in:
- lib/new_store_api/models/conditions.rb
Overview
A collection of conditions, implicitly joined by AND.
Instance Attribute Summary collapse
-
#filters ⇒ Array[Condition]
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(filters = nil) ⇒ Conditions
constructor
A new instance of Conditions.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(filters = nil) ⇒ Conditions
Returns a new instance of Conditions.
33 34 35 |
# File 'lib/new_store_api/models/conditions.rb', line 33 def initialize(filters = nil) @filters = filters end |
Instance Attribute Details
#filters ⇒ Array[Condition]
TODO: Write general description for this method
14 15 16 |
# File 'lib/new_store_api/models/conditions.rb', line 14 def filters @filters end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/new_store_api/models/conditions.rb', line 38 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it filters = nil unless hash['filters'].nil? filters = [] hash['filters'].each do |structure| filters << (Condition.from_hash(structure) if structure) end end filters = nil unless hash.key?('filters') # Create object from extracted values. Conditions.new(filters) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/new_store_api/models/conditions.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['filters'] = 'filters' @_hash end |
.nullables ⇒ Object
An array for nullable fields
29 30 31 |
# File 'lib/new_store_api/models/conditions.rb', line 29 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 |
# File 'lib/new_store_api/models/conditions.rb', line 24 def self.optionals [] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/new_store_api/models/conditions.rb', line 59 def self.validate(value) if value.instance_of? self return APIHelper.valid_type?(value.filters, ->(val) { Condition.validate(val) }, is_model_hash: true, is_inner_model_hash: true) end return false unless value.instance_of? Hash APIHelper.valid_type?(value['filters'], ->(val) { Condition.validate(val) }, is_model_hash: true, is_inner_model_hash: true) end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
82 83 84 85 |
# File 'lib/new_store_api/models/conditions.rb', line 82 def inspect class_name = self.class.name.split('::').last "<#{class_name} filters: #{@filters.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
76 77 78 79 |
# File 'lib/new_store_api/models/conditions.rb', line 76 def to_s class_name = self.class.name.split('::').last "<#{class_name} filters: #{@filters}>" end |