Class: NewStoreApi::DestinationRegion1
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- NewStoreApi::DestinationRegion1
- Defined in:
- lib/new_store_api/models/destination_region1.rb
Overview
DestinationRegion1 Model.
Instance Attribute Summary collapse
-
#country ⇒ String
Country in 2 chars (ISO 3166-1 alpha-2) definition.
-
#zip_code_region ⇒ String
Region identification that will cover that routing.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(country = SKIP, zip_code_region = SKIP) ⇒ DestinationRegion1
constructor
A new instance of DestinationRegion1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(country = SKIP, zip_code_region = SKIP) ⇒ DestinationRegion1
Returns a new instance of DestinationRegion1.
42 43 44 45 |
# File 'lib/new_store_api/models/destination_region1.rb', line 42 def initialize(country = SKIP, zip_code_region = SKIP) @country = country unless country == SKIP @zip_code_region = zip_code_region unless zip_code_region == SKIP end |
Instance Attribute Details
#country ⇒ String
Country in 2 chars (ISO 3166-1 alpha-2) definition
14 15 16 |
# File 'lib/new_store_api/models/destination_region1.rb', line 14 def country @country end |
#zip_code_region ⇒ String
Region identification that will cover that routing. Zip code region groups
is defined in zip_code_regions.
19 20 21 |
# File 'lib/new_store_api/models/destination_region1.rb', line 19 def zip_code_region @zip_code_region end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
48 49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/new_store_api/models/destination_region1.rb', line 48 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. country = hash.key?('country') ? hash['country'] : SKIP zip_code_region = hash.key?('zip_code_region') ? hash['zip_code_region'] : SKIP # Create object from extracted values. DestinationRegion1.new(country, zip_code_region) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/new_store_api/models/destination_region1.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['country'] = 'country' @_hash['zip_code_region'] = 'zip_code_region' @_hash end |
.nullables ⇒ Object
An array for nullable fields
38 39 40 |
# File 'lib/new_store_api/models/destination_region1.rb', line 38 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 33 34 35 |
# File 'lib/new_store_api/models/destination_region1.rb', line 30 def self.optionals %w[ country zip_code_region ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
63 64 65 66 67 68 69 |
# File 'lib/new_store_api/models/destination_region1.rb', line 63 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
78 79 80 81 82 |
# File 'lib/new_store_api/models/destination_region1.rb', line 78 def inspect class_name = self.class.name.split('::').last "<#{class_name} country: #{@country.inspect}, zip_code_region:"\ " #{@zip_code_region.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
72 73 74 75 |
# File 'lib/new_store_api/models/destination_region1.rb', line 72 def to_s class_name = self.class.name.split('::').last "<#{class_name} country: #{@country}, zip_code_region: #{@zip_code_region}>" end |