Class: NewStoreApi::InjectedOrderItemIds
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- NewStoreApi::InjectedOrderItemIds
- Defined in:
- lib/new_store_api/models/injected_order_item_ids.rb
Overview
InjectedOrderItemIds Model.
Instance Attribute Summary collapse
-
#external_item_id ⇒ String
The external order item id as specified in the request.
-
#id ⇒ String
An identifier that is assigned to the item by the system.
-
#product_id ⇒ String
The product id from the catalog.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(external_item_id = nil, id = nil, product_id = nil) ⇒ InjectedOrderItemIds
constructor
A new instance of InjectedOrderItemIds.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(external_item_id = nil, id = nil, product_id = nil) ⇒ InjectedOrderItemIds
Returns a new instance of InjectedOrderItemIds.
43 44 45 46 47 |
# File 'lib/new_store_api/models/injected_order_item_ids.rb', line 43 def initialize(external_item_id = nil, id = nil, product_id = nil) @external_item_id = external_item_id @id = id @product_id = product_id end |
Instance Attribute Details
#external_item_id ⇒ String
The external order item id as specified in the request.
14 15 16 |
# File 'lib/new_store_api/models/injected_order_item_ids.rb', line 14 def external_item_id @external_item_id end |
#id ⇒ String
An identifier that is assigned to the item by the system.
18 19 20 |
# File 'lib/new_store_api/models/injected_order_item_ids.rb', line 18 def id @id end |
#product_id ⇒ String
The product id from the catalog.
22 23 24 |
# File 'lib/new_store_api/models/injected_order_item_ids.rb', line 22 def product_id @product_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/new_store_api/models/injected_order_item_ids.rb', line 50 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. external_item_id = hash.key?('external_item_id') ? hash['external_item_id'] : nil id = hash.key?('id') ? hash['id'] : nil product_id = hash.key?('product_id') ? hash['product_id'] : nil # Create object from extracted values. InjectedOrderItemIds.new(external_item_id, id, product_id) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/new_store_api/models/injected_order_item_ids.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['external_item_id'] = 'external_item_id' @_hash['id'] = 'id' @_hash['product_id'] = 'product_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/new_store_api/models/injected_order_item_ids.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/new_store_api/models/injected_order_item_ids.rb', line 34 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
73 74 75 76 77 |
# File 'lib/new_store_api/models/injected_order_item_ids.rb', line 73 def inspect class_name = self.class.name.split('::').last "<#{class_name} external_item_id: #{@external_item_id.inspect}, id: #{@id.inspect},"\ " product_id: #{@product_id.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
66 67 68 69 70 |
# File 'lib/new_store_api/models/injected_order_item_ids.rb', line 66 def to_s class_name = self.class.name.split('::').last "<#{class_name} external_item_id: #{@external_item_id}, id: #{@id}, product_id:"\ " #{@product_id}>" end |