Class: NewStoreApi::InjectedOrderResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- NewStoreApi::InjectedOrderResponse
- Defined in:
- lib/new_store_api/models/injected_order_response.rb
Overview
InjectedOrderResponse Model.
Instance Attribute Summary collapse
-
#external_id ⇒ String
TODO: Write general description for this method.
-
#id ⇒ String
The identifier of the order assigned internally by the system.
-
#items ⇒ Array[InjectedOrderItemIds]
Identifiers of the order items.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(external_id = nil, id = nil, items = nil) ⇒ InjectedOrderResponse
constructor
A new instance of InjectedOrderResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(external_id = nil, id = nil, items = nil) ⇒ InjectedOrderResponse
Returns a new instance of InjectedOrderResponse.
43 44 45 46 47 |
# File 'lib/new_store_api/models/injected_order_response.rb', line 43 def initialize(external_id = nil, id = nil, items = nil) @external_id = external_id @id = id @items = items end |
Instance Attribute Details
#external_id ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/new_store_api/models/injected_order_response.rb', line 14 def external_id @external_id end |
#id ⇒ String
The identifier of the order assigned internally by the system.
18 19 20 |
# File 'lib/new_store_api/models/injected_order_response.rb', line 18 def id @id end |
#items ⇒ Array[InjectedOrderItemIds]
Identifiers of the order items.
22 23 24 |
# File 'lib/new_store_api/models/injected_order_response.rb', line 22 def items @items end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/new_store_api/models/injected_order_response.rb', line 50 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. external_id = hash.key?('external_id') ? hash['external_id'] : nil id = hash.key?('id') ? hash['id'] : nil # Parameter is an array, so we need to iterate through it items = nil unless hash['items'].nil? items = [] hash['items'].each do |structure| items << (InjectedOrderItemIds.from_hash(structure) if structure) end end items = nil unless hash.key?('items') # Create object from extracted values. InjectedOrderResponse.new(external_id, id, items) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/new_store_api/models/injected_order_response.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['external_id'] = 'external_id' @_hash['id'] = 'id' @_hash['items'] = 'items' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/new_store_api/models/injected_order_response.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/new_store_api/models/injected_order_response.rb', line 34 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
80 81 82 83 84 |
# File 'lib/new_store_api/models/injected_order_response.rb', line 80 def inspect class_name = self.class.name.split('::').last "<#{class_name} external_id: #{@external_id.inspect}, id: #{@id.inspect}, items:"\ " #{@items.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
74 75 76 77 |
# File 'lib/new_store_api/models/injected_order_response.rb', line 74 def to_s class_name = self.class.name.split('::').last "<#{class_name} external_id: #{@external_id}, id: #{@id}, items: #{@items}>" end |