Class: NewStoreApi::Item5
- Defined in:
- lib/new_store_api/models/item5.rb
Overview
Item5 Model.
Instance Attribute Summary collapse
-
#atp ⇒ Float
The number of items available to promise.
-
#fulfillment_node_id ⇒ String
The id of the fulfillment node for this unallocated count.
-
#product_id ⇒ String
The id of the product for this unallocated count.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(atp = nil, fulfillment_node_id = nil, product_id = nil) ⇒ Item5
constructor
A new instance of Item5.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(atp = nil, fulfillment_node_id = nil, product_id = nil) ⇒ Item5
Returns a new instance of Item5.
43 44 45 46 47 |
# File 'lib/new_store_api/models/item5.rb', line 43 def initialize(atp = nil, fulfillment_node_id = nil, product_id = nil) @atp = atp @fulfillment_node_id = fulfillment_node_id @product_id = product_id end |
Instance Attribute Details
#atp ⇒ Float
The number of items available to promise.
14 15 16 |
# File 'lib/new_store_api/models/item5.rb', line 14 def atp @atp end |
#fulfillment_node_id ⇒ String
The id of the fulfillment node for this unallocated count.
18 19 20 |
# File 'lib/new_store_api/models/item5.rb', line 18 def fulfillment_node_id @fulfillment_node_id end |
#product_id ⇒ String
The id of the product for this unallocated count.
22 23 24 |
# File 'lib/new_store_api/models/item5.rb', line 22 def product_id @product_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/new_store_api/models/item5.rb', line 50 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. atp = hash.key?('atp') ? hash['atp'] : nil fulfillment_node_id = hash.key?('fulfillment_node_id') ? hash['fulfillment_node_id'] : nil product_id = hash.key?('product_id') ? hash['product_id'] : nil # Create object from extracted values. Item5.new(atp, fulfillment_node_id, product_id) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/new_store_api/models/item5.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['atp'] = 'atp' @_hash['fulfillment_node_id'] = 'fulfillment_node_id' @_hash['product_id'] = 'product_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/new_store_api/models/item5.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/new_store_api/models/item5.rb', line 34 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
73 74 75 76 77 |
# File 'lib/new_store_api/models/item5.rb', line 73 def inspect class_name = self.class.name.split('::').last "<#{class_name} atp: #{@atp.inspect}, fulfillment_node_id: #{@fulfillment_node_id.inspect},"\ " product_id: #{@product_id.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
66 67 68 69 70 |
# File 'lib/new_store_api/models/item5.rb', line 66 def to_s class_name = self.class.name.split('::').last "<#{class_name} atp: #{@atp}, fulfillment_node_id: #{@fulfillment_node_id}, product_id:"\ " #{@product_id}>" end |