Class: NewStoreApi::JobIdResponse
- Defined in:
- lib/new_store_api/models/job_id_response.rb
Overview
Response model for job creation.
Instance Attribute Summary collapse
-
#created_at ⇒ DateTime
Job creation timestamp (ISO 8601 format).
-
#job_id ⇒ String
Unique job identifier.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(created_at = nil, job_id = nil) ⇒ JobIdResponse
constructor
A new instance of JobIdResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
- #to_custom_created_at ⇒ Object
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(created_at = nil, job_id = nil) ⇒ JobIdResponse
Returns a new instance of JobIdResponse.
39 40 41 42 |
# File 'lib/new_store_api/models/job_id_response.rb', line 39 def initialize(created_at = nil, job_id = nil) @created_at = created_at @job_id = job_id end |
Instance Attribute Details
#created_at ⇒ DateTime
Job creation timestamp (ISO 8601 format)
15 16 17 |
# File 'lib/new_store_api/models/job_id_response.rb', line 15 def created_at @created_at end |
#job_id ⇒ String
Unique job identifier
19 20 21 |
# File 'lib/new_store_api/models/job_id_response.rb', line 19 def job_id @job_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
45 46 47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/new_store_api/models/job_id_response.rb', line 45 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. created_at = if hash.key?('created_at') (DateTimeHelper.from_rfc3339(hash['created_at']) if hash['created_at']) end job_id = hash.key?('job_id') ? hash['job_id'] : nil # Create object from extracted values. JobIdResponse.new(created_at, job_id) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/new_store_api/models/job_id_response.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['created_at'] = 'created_at' @_hash['job_id'] = 'job_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
35 36 37 |
# File 'lib/new_store_api/models/job_id_response.rb', line 35 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 |
# File 'lib/new_store_api/models/job_id_response.rb', line 30 def self.optionals [] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/new_store_api/models/job_id_response.rb', line 65 def self.validate(value) if value.instance_of? self return ( APIHelper.valid_type?(value.created_at, ->(val) { val.instance_of? DateTime }) and APIHelper.valid_type?(value.job_id, ->(val) { val.instance_of? String }) ) end return false unless value.instance_of? Hash ( APIHelper.valid_type?(value['created_at'], ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value['job_id'], ->(val) { val.instance_of? String }) ) end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
92 93 94 95 |
# File 'lib/new_store_api/models/job_id_response.rb', line 92 def inspect class_name = self.class.name.split('::').last "<#{class_name} created_at: #{@created_at.inspect}, job_id: #{@job_id.inspect}>" end |
#to_custom_created_at ⇒ Object
59 60 61 |
# File 'lib/new_store_api/models/job_id_response.rb', line 59 def to_custom_created_at DateTimeHelper.to_rfc3339(created_at) end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
86 87 88 89 |
# File 'lib/new_store_api/models/job_id_response.rb', line 86 def to_s class_name = self.class.name.split('::').last "<#{class_name} created_at: #{@created_at}, job_id: #{@job_id}>" end |