Class: NewStoreApi::ListCountTaskLineItemsResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- NewStoreApi::ListCountTaskLineItemsResponse
- Defined in:
- lib/new_store_api/models/list_count_task_line_items_response.rb
Overview
ListCountTaskLineItemsResponse Model.
Instance Attribute Summary collapse
-
#count ⇒ Integer
Total number of line items.
-
#line_items ⇒ Array[CountTaskLineItemResponse]
Total number of line items.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(count = nil, line_items = nil) ⇒ ListCountTaskLineItemsResponse
constructor
A new instance of ListCountTaskLineItemsResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(count = nil, line_items = nil) ⇒ ListCountTaskLineItemsResponse
Returns a new instance of ListCountTaskLineItemsResponse.
38 39 40 41 |
# File 'lib/new_store_api/models/list_count_task_line_items_response.rb', line 38 def initialize(count = nil, line_items = nil) @count = count @line_items = line_items end |
Instance Attribute Details
#count ⇒ Integer
Total number of line items.
14 15 16 |
# File 'lib/new_store_api/models/list_count_task_line_items_response.rb', line 14 def count @count end |
#line_items ⇒ Array[CountTaskLineItemResponse]
Total number of line items.
18 19 20 |
# File 'lib/new_store_api/models/list_count_task_line_items_response.rb', line 18 def line_items @line_items end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/new_store_api/models/list_count_task_line_items_response.rb', line 44 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. count = hash.key?('count') ? hash['count'] : nil # Parameter is an array, so we need to iterate through it line_items = nil unless hash['line_items'].nil? line_items = [] hash['line_items'].each do |structure| line_items << (CountTaskLineItemResponse.from_hash(structure) if structure) end end line_items = nil unless hash.key?('line_items') # Create object from extracted values. ListCountTaskLineItemsResponse.new(count, line_items) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/new_store_api/models/list_count_task_line_items_response.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['count'] = 'count' @_hash['line_items'] = 'line_items' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/new_store_api/models/list_count_task_line_items_response.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/new_store_api/models/list_count_task_line_items_response.rb', line 29 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
72 73 74 75 |
# File 'lib/new_store_api/models/list_count_task_line_items_response.rb', line 72 def inspect class_name = self.class.name.split('::').last "<#{class_name} count: #{@count.inspect}, line_items: #{@line_items.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
66 67 68 69 |
# File 'lib/new_store_api/models/list_count_task_line_items_response.rb', line 66 def to_s class_name = self.class.name.split('::').last "<#{class_name} count: #{@count}, line_items: #{@line_items}>" end |