Class: NewStoreApi::ListProfilesResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- NewStoreApi::ListProfilesResponse
- Defined in:
- lib/new_store_api/models/list_profiles_response.rb
Overview
List profiles response.
Instance Attribute Summary collapse
-
#pagination_info ⇒ PaginationInfo
Pagination info.
-
#profiles ⇒ Array[ProfileResponse]
Pagination info.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(pagination_info = nil, profiles = nil) ⇒ ListProfilesResponse
constructor
A new instance of ListProfilesResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(pagination_info = nil, profiles = nil) ⇒ ListProfilesResponse
Returns a new instance of ListProfilesResponse.
38 39 40 41 |
# File 'lib/new_store_api/models/list_profiles_response.rb', line 38 def initialize(pagination_info = nil, profiles = nil) @pagination_info = pagination_info @profiles = profiles end |
Instance Attribute Details
#pagination_info ⇒ PaginationInfo
Pagination info.
14 15 16 |
# File 'lib/new_store_api/models/list_profiles_response.rb', line 14 def pagination_info @pagination_info end |
#profiles ⇒ Array[ProfileResponse]
Pagination info.
18 19 20 |
# File 'lib/new_store_api/models/list_profiles_response.rb', line 18 def profiles @profiles end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/new_store_api/models/list_profiles_response.rb', line 44 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. pagination_info = PaginationInfo.from_hash(hash['pagination_info']) if hash['pagination_info'] # Parameter is an array, so we need to iterate through it profiles = nil unless hash['profiles'].nil? profiles = [] hash['profiles'].each do |structure| profiles << (ProfileResponse.from_hash(structure) if structure) end end profiles = nil unless hash.key?('profiles') # Create object from extracted values. ListProfilesResponse.new(pagination_info, profiles) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/new_store_api/models/list_profiles_response.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['pagination_info'] = 'pagination_info' @_hash['profiles'] = 'profiles' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/new_store_api/models/list_profiles_response.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/new_store_api/models/list_profiles_response.rb', line 29 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
73 74 75 76 77 |
# File 'lib/new_store_api/models/list_profiles_response.rb', line 73 def inspect class_name = self.class.name.split('::').last "<#{class_name} pagination_info: #{@pagination_info.inspect}, profiles:"\ " #{@profiles.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
67 68 69 70 |
# File 'lib/new_store_api/models/list_profiles_response.rb', line 67 def to_s class_name = self.class.name.split('::').last "<#{class_name} pagination_info: #{@pagination_info}, profiles: #{@profiles}>" end |