Class: NewStoreApi::OptedIn
- Defined in:
- lib/new_store_api/models/opted_in.rb
Overview
Opt-in status information for a conversation between a customer and a store.
Instance Attribute Summary collapse
-
#opt_in_state ⇒ OptInStateEnum
The current opt-in state for this store.
-
#opt_in_state_modified_at ⇒ DateTime
Timestamp when the opt-in state was last modified.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(opt_in_state = nil, opt_in_state_modified_at = nil) ⇒ OptedIn
constructor
A new instance of OptedIn.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
- #to_custom_opt_in_state_modified_at ⇒ Object
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(opt_in_state = nil, opt_in_state_modified_at = nil) ⇒ OptedIn
Returns a new instance of OptedIn.
39 40 41 42 |
# File 'lib/new_store_api/models/opted_in.rb', line 39 def initialize(opt_in_state = nil, opt_in_state_modified_at = nil) @opt_in_state = opt_in_state @opt_in_state_modified_at = opt_in_state_modified_at end |
Instance Attribute Details
#opt_in_state ⇒ OptInStateEnum
The current opt-in state for this store.
15 16 17 |
# File 'lib/new_store_api/models/opted_in.rb', line 15 def opt_in_state @opt_in_state end |
#opt_in_state_modified_at ⇒ DateTime
Timestamp when the opt-in state was last modified.
19 20 21 |
# File 'lib/new_store_api/models/opted_in.rb', line 19 def opt_in_state_modified_at @opt_in_state_modified_at end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
45 46 47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/new_store_api/models/opted_in.rb', line 45 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. opt_in_state = hash.key?('opt_in_state') ? hash['opt_in_state'] : nil opt_in_state_modified_at = if hash.key?('opt_in_state_modified_at') (DateTimeHelper.from_rfc3339(hash['opt_in_state_modified_at']) if hash['opt_in_state_modified_at']) end # Create object from extracted values. OptedIn.new(opt_in_state, opt_in_state_modified_at) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/new_store_api/models/opted_in.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['opt_in_state'] = 'opt_in_state' @_hash['opt_in_state_modified_at'] = 'opt_in_state_modified_at' @_hash end |
.nullables ⇒ Object
An array for nullable fields
35 36 37 |
# File 'lib/new_store_api/models/opted_in.rb', line 35 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 |
# File 'lib/new_store_api/models/opted_in.rb', line 30 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
71 72 73 74 75 |
# File 'lib/new_store_api/models/opted_in.rb', line 71 def inspect class_name = self.class.name.split('::').last "<#{class_name} opt_in_state: #{@opt_in_state.inspect}, opt_in_state_modified_at:"\ " #{@opt_in_state_modified_at.inspect}>" end |
#to_custom_opt_in_state_modified_at ⇒ Object
59 60 61 |
# File 'lib/new_store_api/models/opted_in.rb', line 59 def to_custom_opt_in_state_modified_at DateTimeHelper.to_rfc3339(opt_in_state_modified_at) end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
64 65 66 67 68 |
# File 'lib/new_store_api/models/opted_in.rb', line 64 def to_s class_name = self.class.name.split('::').last "<#{class_name} opt_in_state: #{@opt_in_state}, opt_in_state_modified_at:"\ " #{@opt_in_state_modified_at}>" end |