Class: NewStoreApi::Origin
- Defined in:
- lib/new_store_api/models/origin.rb
Overview
The ship-from origin for this fulfillment group. Omitted when neither zip code nor country code is known.
Instance Attribute Summary collapse
-
#country_code ⇒ String
The ship-from country code (ISO 3166-1 alpha-2).
-
#zip_code ⇒ String
The ship-from postal code.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(country_code = SKIP, zip_code = SKIP) ⇒ Origin
constructor
A new instance of Origin.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(country_code = SKIP, zip_code = SKIP) ⇒ Origin
Returns a new instance of Origin.
42 43 44 45 |
# File 'lib/new_store_api/models/origin.rb', line 42 def initialize(country_code = SKIP, zip_code = SKIP) @country_code = country_code unless country_code == SKIP @zip_code = zip_code unless zip_code == SKIP end |
Instance Attribute Details
#country_code ⇒ String
The ship-from country code (ISO 3166-1 alpha-2).
15 16 17 |
# File 'lib/new_store_api/models/origin.rb', line 15 def country_code @country_code end |
#zip_code ⇒ String
The ship-from postal code.
19 20 21 |
# File 'lib/new_store_api/models/origin.rb', line 19 def zip_code @zip_code end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/new_store_api/models/origin.rb', line 48 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. country_code = hash.key?('country_code') ? hash['country_code'] : SKIP zip_code = hash.key?('zip_code') ? hash['zip_code'] : SKIP # Create object from extracted values. Origin.new(country_code, zip_code) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/new_store_api/models/origin.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['country_code'] = 'country_code' @_hash['zip_code'] = 'zip_code' @_hash end |
.nullables ⇒ Object
An array for nullable fields
38 39 40 |
# File 'lib/new_store_api/models/origin.rb', line 38 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 33 34 35 |
# File 'lib/new_store_api/models/origin.rb', line 30 def self.optionals %w[ country_code zip_code ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
67 68 69 70 |
# File 'lib/new_store_api/models/origin.rb', line 67 def inspect class_name = self.class.name.split('::').last "<#{class_name} country_code: #{@country_code.inspect}, zip_code: #{@zip_code.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
61 62 63 64 |
# File 'lib/new_store_api/models/origin.rb', line 61 def to_s class_name = self.class.name.split('::').last "<#{class_name} country_code: #{@country_code}, zip_code: #{@zip_code}>" end |