Class: NewStoreApi::PackageTypesResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- NewStoreApi::PackageTypesResponse
- Defined in:
- lib/new_store_api/models/package_types_response.rb
Overview
List of all package types configured.
Instance Attribute Summary collapse
-
#package_types ⇒ Array[PackageTypeResponse]
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(package_types = nil) ⇒ PackageTypesResponse
constructor
A new instance of PackageTypesResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(package_types = nil) ⇒ PackageTypesResponse
Returns a new instance of PackageTypesResponse.
33 34 35 |
# File 'lib/new_store_api/models/package_types_response.rb', line 33 def initialize(package_types = nil) @package_types = package_types end |
Instance Attribute Details
#package_types ⇒ Array[PackageTypeResponse]
TODO: Write general description for this method
14 15 16 |
# File 'lib/new_store_api/models/package_types_response.rb', line 14 def package_types @package_types end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/new_store_api/models/package_types_response.rb', line 38 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it package_types = nil unless hash['package_types'].nil? package_types = [] hash['package_types'].each do |structure| package_types << (PackageTypeResponse.from_hash(structure) if structure) end end package_types = nil unless hash.key?('package_types') # Create object from extracted values. PackageTypesResponse.new(package_types) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/new_store_api/models/package_types_response.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['package_types'] = 'package_types' @_hash end |
.nullables ⇒ Object
An array for nullable fields
29 30 31 |
# File 'lib/new_store_api/models/package_types_response.rb', line 29 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 |
# File 'lib/new_store_api/models/package_types_response.rb', line 24 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
64 65 66 67 |
# File 'lib/new_store_api/models/package_types_response.rb', line 64 def inspect class_name = self.class.name.split('::').last "<#{class_name} package_types: #{@package_types.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
58 59 60 61 |
# File 'lib/new_store_api/models/package_types_response.rb', line 58 def to_s class_name = self.class.name.split('::').last "<#{class_name} package_types: #{@package_types}>" end |