Class: NewStoreApi::Profiles
- Defined in:
- lib/new_store_api/models/profiles.rb
Overview
Clienteling profile information for multiple customers.
Instance Attribute Summary collapse
-
#meta ⇒ Meta
Additional response information.
-
#profiles ⇒ Array[Profile]
Additional response information.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(meta = nil, profiles = nil) ⇒ Profiles
constructor
A new instance of Profiles.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(meta = nil, profiles = nil) ⇒ Profiles
Returns a new instance of Profiles.
38 39 40 41 |
# File 'lib/new_store_api/models/profiles.rb', line 38 def initialize( = nil, profiles = nil) @meta = @profiles = profiles end |
Instance Attribute Details
#meta ⇒ Meta
Additional response information.
14 15 16 |
# File 'lib/new_store_api/models/profiles.rb', line 14 def @meta end |
#profiles ⇒ Array[Profile]
Additional response information.
18 19 20 |
# File 'lib/new_store_api/models/profiles.rb', line 18 def profiles @profiles end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/new_store_api/models/profiles.rb', line 44 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. = Meta.from_hash(hash['meta']) if hash['meta'] # Parameter is an array, so we need to iterate through it profiles = nil unless hash['profiles'].nil? profiles = [] hash['profiles'].each do |structure| profiles << (Profile.from_hash(structure) if structure) end end profiles = nil unless hash.key?('profiles') # Create object from extracted values. Profiles.new(, profiles) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/new_store_api/models/profiles.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['meta'] = 'meta' @_hash['profiles'] = 'profiles' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/new_store_api/models/profiles.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/new_store_api/models/profiles.rb', line 29 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
72 73 74 75 |
# File 'lib/new_store_api/models/profiles.rb', line 72 def inspect class_name = self.class.name.split('::').last "<#{class_name} meta: #{@meta.inspect}, profiles: #{@profiles.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
66 67 68 69 |
# File 'lib/new_store_api/models/profiles.rb', line 66 def to_s class_name = self.class.name.split('::').last "<#{class_name} meta: #{@meta}, profiles: #{@profiles}>" end |