Class: NewStoreApi::QuotationItemDto
- Defined in:
- lib/new_store_api/models/quotation_item_dto.rb
Overview
QuotationItemDto Model.
Instance Attribute Summary collapse
-
#consumer_uuid ⇒ String
UUID of the consumer.
-
#currency_consumer ⇒ String
ISO 4217 currency code shown and billed to the consumer.
-
#extended_attributes ⇒ Array[ExtAttrResource]
The item's list of extended attributes.
-
#handling_charges ⇒ Integer
Cost of handling.
-
#id ⇒ String
Unique identifier of the item.
-
#item_price ⇒ Integer
Price per quantity 1 of the item, can be incl.
-
#product_id ⇒ String
Unique identifier of the product.
-
#product_name ⇒ String
Human-readable name of the product.
-
#product_sku ⇒ String
SKU of the product.
-
#quantity ⇒ Integer
Item quantity.
-
#shipping_address ⇒ TransactionAddressDto
Consumer's shipping address.
-
#shipping_origin ⇒ TransactionAddressDto
The origin of goods address, e.g.
-
#tax_class ⇒ String
Tax classification identifier for the line item.
-
#tax_method ⇒ SalesOrderTaxMethodEnum
Tax classification identifier for the line item.
-
#type ⇒ ItemTypeEnum
Tax classification identifier for the line item.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(currency_consumer = nil, item_price = nil, quantity = nil, shipping_address = nil, shipping_origin = nil, tax_class = nil, tax_method = nil, type = nil, consumer_uuid = SKIP, extended_attributes = SKIP, handling_charges = SKIP, id = SKIP, product_id = SKIP, product_name = SKIP, product_sku = SKIP) ⇒ QuotationItemDto
constructor
A new instance of QuotationItemDto.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(currency_consumer = nil, item_price = nil, quantity = nil, shipping_address = nil, shipping_origin = nil, tax_class = nil, tax_method = nil, type = nil, consumer_uuid = SKIP, extended_attributes = SKIP, handling_charges = SKIP, id = SKIP, product_id = SKIP, product_name = SKIP, product_sku = SKIP) ⇒ QuotationItemDto
Returns a new instance of QuotationItemDto.
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/new_store_api/models/quotation_item_dto.rb', line 115 def initialize(currency_consumer = nil, item_price = nil, quantity = nil, shipping_address = nil, shipping_origin = nil, tax_class = nil, tax_method = nil, type = nil, consumer_uuid = SKIP, extended_attributes = SKIP, handling_charges = SKIP, id = SKIP, product_id = SKIP, product_name = SKIP, product_sku = SKIP) @consumer_uuid = consumer_uuid unless consumer_uuid == SKIP @currency_consumer = currency_consumer @extended_attributes = extended_attributes unless extended_attributes == SKIP @handling_charges = handling_charges unless handling_charges == SKIP @id = id unless id == SKIP @item_price = item_price @product_id = product_id unless product_id == SKIP @product_name = product_name unless product_name == SKIP @product_sku = product_sku unless product_sku == SKIP @quantity = quantity @shipping_address = shipping_address @shipping_origin = shipping_origin @tax_class = tax_class @tax_method = tax_method @type = type end |
Instance Attribute Details
#consumer_uuid ⇒ String
UUID of the consumer.
14 15 16 |
# File 'lib/new_store_api/models/quotation_item_dto.rb', line 14 def consumer_uuid @consumer_uuid end |
#currency_consumer ⇒ String
ISO 4217 currency code shown and billed to the consumer. Determines the minor-unit exponent used for all monetary fields (e.g. USD=2, JPY=0). Must be identical across all items.
20 21 22 |
# File 'lib/new_store_api/models/quotation_item_dto.rb', line 20 def currency_consumer @currency_consumer end |
#extended_attributes ⇒ Array[ExtAttrResource]
The item's list of extended attributes.
24 25 26 |
# File 'lib/new_store_api/models/quotation_item_dto.rb', line 24 def extended_attributes @extended_attributes end |
#handling_charges ⇒ Integer
Cost of handling. Expressed in the currency's minor unit.
28 29 30 |
# File 'lib/new_store_api/models/quotation_item_dto.rb', line 28 def handling_charges @handling_charges end |
#id ⇒ String
Unique identifier of the item.
32 33 34 |
# File 'lib/new_store_api/models/quotation_item_dto.rb', line 32 def id @id end |
#item_price ⇒ Integer
Price per quantity 1 of the item, can be incl. or excl. tax depending on tax_method. Expressed in the currency's minor unit.
37 38 39 |
# File 'lib/new_store_api/models/quotation_item_dto.rb', line 37 def item_price @item_price end |
#product_id ⇒ String
Unique identifier of the product.
41 42 43 |
# File 'lib/new_store_api/models/quotation_item_dto.rb', line 41 def product_id @product_id end |
#product_name ⇒ String
Human-readable name of the product.
45 46 47 |
# File 'lib/new_store_api/models/quotation_item_dto.rb', line 45 def product_name @product_name end |
#product_sku ⇒ String
SKU of the product.
49 50 51 |
# File 'lib/new_store_api/models/quotation_item_dto.rb', line 49 def product_sku @product_sku end |
#quantity ⇒ Integer
Item quantity. Positive number for sold items and negative number for returned items
54 55 56 |
# File 'lib/new_store_api/models/quotation_item_dto.rb', line 54 def quantity @quantity end |
#shipping_address ⇒ TransactionAddressDto
Consumer's shipping address.
58 59 60 |
# File 'lib/new_store_api/models/quotation_item_dto.rb', line 58 def shipping_address @shipping_address end |
#shipping_origin ⇒ TransactionAddressDto
The origin of goods address, e.g. physical address of a store.
62 63 64 |
# File 'lib/new_store_api/models/quotation_item_dto.rb', line 62 def shipping_origin @shipping_origin end |
#tax_class ⇒ String
Tax classification identifier for the line item.
66 67 68 |
# File 'lib/new_store_api/models/quotation_item_dto.rb', line 66 def tax_class @tax_class end |
#tax_method ⇒ SalesOrderTaxMethodEnum
Tax classification identifier for the line item.
70 71 72 |
# File 'lib/new_store_api/models/quotation_item_dto.rb', line 70 def tax_method @tax_method end |
#type ⇒ ItemTypeEnum
Tax classification identifier for the line item.
74 75 76 |
# File 'lib/new_store_api/models/quotation_item_dto.rb', line 74 def type @type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/new_store_api/models/quotation_item_dto.rb', line 139 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. currency_consumer = hash.key?('currency_consumer') ? hash['currency_consumer'] : nil item_price = hash.key?('item_price') ? hash['item_price'] : nil quantity = hash.key?('quantity') ? hash['quantity'] : nil shipping_address = TransactionAddressDto.from_hash(hash['shipping_address']) if hash['shipping_address'] shipping_origin = TransactionAddressDto.from_hash(hash['shipping_origin']) if hash['shipping_origin'] tax_class = hash.key?('tax_class') ? hash['tax_class'] : nil tax_method = hash.key?('tax_method') ? hash['tax_method'] : nil type = hash.key?('type') ? hash['type'] : nil consumer_uuid = hash.key?('consumer_uuid') ? hash['consumer_uuid'] : SKIP # Parameter is an array, so we need to iterate through it extended_attributes = nil unless hash['extended_attributes'].nil? extended_attributes = [] hash['extended_attributes'].each do |structure| extended_attributes << (ExtAttrResource.from_hash(structure) if structure) end end extended_attributes = SKIP unless hash.key?('extended_attributes') handling_charges = hash.key?('handling_charges') ? hash['handling_charges'] : SKIP id = hash.key?('id') ? hash['id'] : SKIP product_id = hash.key?('product_id') ? hash['product_id'] : SKIP product_name = hash.key?('product_name') ? hash['product_name'] : SKIP product_sku = hash.key?('product_sku') ? hash['product_sku'] : SKIP # Create object from extracted values. QuotationItemDto.new(currency_consumer, item_price, quantity, shipping_address, shipping_origin, tax_class, tax_method, type, consumer_uuid, extended_attributes, handling_charges, id, product_id, product_name, product_sku) end |
.names ⇒ Object
A mapping from model property names to API property names.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/new_store_api/models/quotation_item_dto.rb', line 77 def self.names @_hash = {} if @_hash.nil? @_hash['consumer_uuid'] = 'consumer_uuid' @_hash['currency_consumer'] = 'currency_consumer' @_hash['extended_attributes'] = 'extended_attributes' @_hash['handling_charges'] = 'handling_charges' @_hash['id'] = 'id' @_hash['item_price'] = 'item_price' @_hash['product_id'] = 'product_id' @_hash['product_name'] = 'product_name' @_hash['product_sku'] = 'product_sku' @_hash['quantity'] = 'quantity' @_hash['shipping_address'] = 'shipping_address' @_hash['shipping_origin'] = 'shipping_origin' @_hash['tax_class'] = 'tax_class' @_hash['tax_method'] = 'tax_method' @_hash['type'] = 'type' @_hash end |
.nullables ⇒ Object
An array for nullable fields
111 112 113 |
# File 'lib/new_store_api/models/quotation_item_dto.rb', line 111 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/new_store_api/models/quotation_item_dto.rb', line 98 def self.optionals %w[ consumer_uuid extended_attributes handling_charges id product_id product_name product_sku ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/new_store_api/models/quotation_item_dto.rb', line 192 def self.validate(value) if value.instance_of? self return ( APIHelper.valid_type?(value.currency_consumer, ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value.item_price, ->(val) { val.instance_of? Integer }) and APIHelper.valid_type?(value.quantity, ->(val) { val.instance_of? Integer }) and APIHelper.valid_type?(value.shipping_address, ->(val) { TransactionAddressDto.validate(val) }, is_model_hash: true) and APIHelper.valid_type?(value.shipping_origin, ->(val) { TransactionAddressDto.validate(val) }, is_model_hash: true) and APIHelper.valid_type?(value.tax_class, ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value.tax_method, ->(val) { SalesOrderTaxMethodEnum.validate(val) }) and APIHelper.valid_type?(value.type, ->(val) { ItemTypeEnum.validate(val) }) ) end return false unless value.instance_of? Hash ( APIHelper.valid_type?(value['currency_consumer'], ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value['item_price'], ->(val) { val.instance_of? Integer }) and APIHelper.valid_type?(value['quantity'], ->(val) { val.instance_of? Integer }) and APIHelper.valid_type?(value['shipping_address'], ->(val) { TransactionAddressDto.validate(val) }, is_model_hash: true) and APIHelper.valid_type?(value['shipping_origin'], ->(val) { TransactionAddressDto.validate(val) }, is_model_hash: true) and APIHelper.valid_type?(value['tax_class'], ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value['tax_method'], ->(val) { SalesOrderTaxMethodEnum.validate(val) }) and APIHelper.valid_type?(value['type'], ->(val) { ItemTypeEnum.validate(val) }) ) end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
252 253 254 255 256 257 258 259 260 261 262 |
# File 'lib/new_store_api/models/quotation_item_dto.rb', line 252 def inspect class_name = self.class.name.split('::').last "<#{class_name} consumer_uuid: #{@consumer_uuid.inspect}, currency_consumer:"\ " #{@currency_consumer.inspect}, extended_attributes: #{@extended_attributes.inspect},"\ " handling_charges: #{@handling_charges.inspect}, id: #{@id.inspect}, item_price:"\ " #{@item_price.inspect}, product_id: #{@product_id.inspect}, product_name:"\ " #{@product_name.inspect}, product_sku: #{@product_sku.inspect}, quantity:"\ " #{@quantity.inspect}, shipping_address: #{@shipping_address.inspect}, shipping_origin:"\ " #{@shipping_origin.inspect}, tax_class: #{@tax_class.inspect}, tax_method:"\ " #{@tax_method.inspect}, type: #{@type.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
241 242 243 244 245 246 247 248 249 |
# File 'lib/new_store_api/models/quotation_item_dto.rb', line 241 def to_s class_name = self.class.name.split('::').last "<#{class_name} consumer_uuid: #{@consumer_uuid}, currency_consumer: #{@currency_consumer},"\ " extended_attributes: #{@extended_attributes}, handling_charges: #{@handling_charges}, id:"\ " #{@id}, item_price: #{@item_price}, product_id: #{@product_id}, product_name:"\ " #{@product_name}, product_sku: #{@product_sku}, quantity: #{@quantity}, shipping_address:"\ " #{@shipping_address}, shipping_origin: #{@shipping_origin}, tax_class: #{@tax_class},"\ " tax_method: #{@tax_method}, type: #{@type}>" end |