Class: NewStoreApi::Remove
- Defined in:
- lib/new_store_api/models/remove.rb
Overview
Remove Model.
Instance Attribute Summary collapse
-
#op ⇒ String
readonly
The operation to perform.
-
#path ⇒ String
A JSON Pointer path.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(path = nil) ⇒ Remove
constructor
A new instance of Remove.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(path = nil) ⇒ Remove
Returns a new instance of Remove.
38 39 40 41 |
# File 'lib/new_store_api/models/remove.rb', line 38 def initialize(path = nil) @op = 'remove' @path = path end |
Instance Attribute Details
#op ⇒ String (readonly)
The operation to perform.
14 15 16 |
# File 'lib/new_store_api/models/remove.rb', line 14 def op @op end |
#path ⇒ String
A JSON Pointer path.
18 19 20 |
# File 'lib/new_store_api/models/remove.rb', line 18 def path @path end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
44 45 46 47 48 49 50 51 52 |
# File 'lib/new_store_api/models/remove.rb', line 44 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. path = hash.key?('path') ? hash['path'] : nil # Create object from extracted values. Remove.new(path) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/new_store_api/models/remove.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['op'] = 'op' @_hash['path'] = 'path' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/new_store_api/models/remove.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/new_store_api/models/remove.rb', line 29 def self.optionals [] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/new_store_api/models/remove.rb', line 56 def self.validate(value) if value.instance_of? self return ( APIHelper.valid_type?(value.op, ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value.path, ->(val) { val.instance_of? String }) ) end return false unless value.instance_of? Hash ( APIHelper.valid_type?(value['op'], ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value['path'], ->(val) { val.instance_of? String }) ) end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
83 84 85 86 |
# File 'lib/new_store_api/models/remove.rb', line 83 def inspect class_name = self.class.name.split('::').last "<#{class_name} op: #{@op.inspect}, path: #{@path.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
77 78 79 80 |
# File 'lib/new_store_api/models/remove.rb', line 77 def to_s class_name = self.class.name.split('::').last "<#{class_name} op: #{@op}, path: #{@path}>" end |