Class: NewStoreApi::ReservationSummaryResponseV2
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- NewStoreApi::ReservationSummaryResponseV2
- Defined in:
- lib/new_store_api/models/reservation_summary_response_v2.rb
Overview
ReservationSummaryResponseV2 Model.
Instance Attribute Summary collapse
-
#associate_id ⇒ String
ID of the associate that created the reservation.
-
#created_at ⇒ DateTime
Date and time the reservation was created.
-
#customer_profile_id ⇒ String
Profile ID of the customer the reservation is for.
-
#display_id ⇒ String
Short, human-readable identifier for the reservation.
-
#expires_at ⇒ DateTime
Date and time the reservation expires.
-
#external_id ⇒ String
Value used by an external system to refer to the reservation.
-
#id ⇒ UUID | String
Unique identifier for the reservation.
-
#items ⇒ Array[ReservationItemSummaryResponse]
Items associated with the reservation.
-
#location_id ⇒ String
ID of the fulfillment location the reservation is for.
-
#reserved_item_count ⇒ Integer
Number of items in the RESERVED state.
-
#status ⇒ ReservationStatusEnum
The status of a reservation.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(associate_id = nil, created_at = nil, customer_profile_id = nil, display_id = nil, expires_at = nil, external_id = nil, id = nil, items = nil, location_id = nil, reserved_item_count = nil, status = nil) ⇒ ReservationSummaryResponseV2
constructor
A new instance of ReservationSummaryResponseV2.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
- #to_custom_created_at ⇒ Object
- #to_custom_expires_at ⇒ Object
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(associate_id = nil, created_at = nil, customer_profile_id = nil, display_id = nil, expires_at = nil, external_id = nil, id = nil, items = nil, location_id = nil, reserved_item_count = nil, status = nil) ⇒ ReservationSummaryResponseV2
Returns a new instance of ReservationSummaryResponseV2.
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/new_store_api/models/reservation_summary_response_v2.rb', line 88 def initialize(associate_id = nil, created_at = nil, customer_profile_id = nil, display_id = nil, expires_at = nil, external_id = nil, id = nil, items = nil, location_id = nil, reserved_item_count = nil, status = nil) @associate_id = associate_id @created_at = created_at @customer_profile_id = customer_profile_id @display_id = display_id @expires_at = expires_at @external_id = external_id @id = id @items = items @location_id = location_id @reserved_item_count = reserved_item_count @status = status end |
Instance Attribute Details
#associate_id ⇒ String
ID of the associate that created the reservation
15 16 17 |
# File 'lib/new_store_api/models/reservation_summary_response_v2.rb', line 15 def associate_id @associate_id end |
#created_at ⇒ DateTime
Date and time the reservation was created
19 20 21 |
# File 'lib/new_store_api/models/reservation_summary_response_v2.rb', line 19 def created_at @created_at end |
#customer_profile_id ⇒ String
Profile ID of the customer the reservation is for
23 24 25 |
# File 'lib/new_store_api/models/reservation_summary_response_v2.rb', line 23 def customer_profile_id @customer_profile_id end |
#display_id ⇒ String
Short, human-readable identifier for the reservation. This field was previously called external_id in v1 of the API
28 29 30 |
# File 'lib/new_store_api/models/reservation_summary_response_v2.rb', line 28 def display_id @display_id end |
#expires_at ⇒ DateTime
Date and time the reservation expires
32 33 34 |
# File 'lib/new_store_api/models/reservation_summary_response_v2.rb', line 32 def expires_at @expires_at end |
#external_id ⇒ String
Value used by an external system to refer to the reservation
36 37 38 |
# File 'lib/new_store_api/models/reservation_summary_response_v2.rb', line 36 def external_id @external_id end |
#id ⇒ UUID | String
Unique identifier for the reservation
40 41 42 |
# File 'lib/new_store_api/models/reservation_summary_response_v2.rb', line 40 def id @id end |
#items ⇒ Array[ReservationItemSummaryResponse]
Items associated with the reservation
44 45 46 |
# File 'lib/new_store_api/models/reservation_summary_response_v2.rb', line 44 def items @items end |
#location_id ⇒ String
ID of the fulfillment location the reservation is for
48 49 50 |
# File 'lib/new_store_api/models/reservation_summary_response_v2.rb', line 48 def location_id @location_id end |
#reserved_item_count ⇒ Integer
Number of items in the RESERVED state
52 53 54 |
# File 'lib/new_store_api/models/reservation_summary_response_v2.rb', line 52 def reserved_item_count @reserved_item_count end |
#status ⇒ ReservationStatusEnum
The status of a reservation.
56 57 58 |
# File 'lib/new_store_api/models/reservation_summary_response_v2.rb', line 56 def status @status end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/new_store_api/models/reservation_summary_response_v2.rb', line 106 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. associate_id = hash.key?('associate_id') ? hash['associate_id'] : nil created_at = if hash.key?('created_at') (DateTimeHelper.from_rfc3339(hash['created_at']) if hash['created_at']) end customer_profile_id = hash.key?('customer_profile_id') ? hash['customer_profile_id'] : nil display_id = hash.key?('display_id') ? hash['display_id'] : nil expires_at = if hash.key?('expires_at') (DateTimeHelper.from_rfc3339(hash['expires_at']) if hash['expires_at']) end external_id = hash.key?('external_id') ? hash['external_id'] : nil id = hash.key?('id') ? hash['id'] : nil # Parameter is an array, so we need to iterate through it items = nil unless hash['items'].nil? items = [] hash['items'].each do |structure| items << (ReservationItemSummaryResponse.from_hash(structure) if structure) end end items = nil unless hash.key?('items') location_id = hash.key?('location_id') ? hash['location_id'] : nil reserved_item_count = hash.key?('reserved_item_count') ? hash['reserved_item_count'] : nil status = hash.key?('status') ? hash['status'] : nil # Create object from extracted values. ReservationSummaryResponseV2.new(associate_id, created_at, customer_profile_id, display_id, expires_at, external_id, id, items, location_id, reserved_item_count, status) end |
.names ⇒ Object
A mapping from model property names to API property names.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/new_store_api/models/reservation_summary_response_v2.rb', line 59 def self.names @_hash = {} if @_hash.nil? @_hash['associate_id'] = 'associate_id' @_hash['created_at'] = 'created_at' @_hash['customer_profile_id'] = 'customer_profile_id' @_hash['display_id'] = 'display_id' @_hash['expires_at'] = 'expires_at' @_hash['external_id'] = 'external_id' @_hash['id'] = 'id' @_hash['items'] = 'items' @_hash['location_id'] = 'location_id' @_hash['reserved_item_count'] = 'reserved_item_count' @_hash['status'] = 'status' @_hash end |
.nullables ⇒ Object
An array for nullable fields
81 82 83 84 85 86 |
# File 'lib/new_store_api/models/reservation_summary_response_v2.rb', line 81 def self.nullables %w[ associate_id external_id ] end |
.optionals ⇒ Object
An array for optional fields
76 77 78 |
# File 'lib/new_store_api/models/reservation_summary_response_v2.rb', line 76 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
169 170 171 172 173 174 175 176 |
# File 'lib/new_store_api/models/reservation_summary_response_v2.rb', line 169 def inspect class_name = self.class.name.split('::').last "<#{class_name} associate_id: #{@associate_id.inspect}, created_at: #{@created_at.inspect},"\ " customer_profile_id: #{@customer_profile_id.inspect}, display_id: #{@display_id.inspect},"\ " expires_at: #{@expires_at.inspect}, external_id: #{@external_id.inspect}, id:"\ " #{@id.inspect}, items: #{@items.inspect}, location_id: #{@location_id.inspect},"\ " reserved_item_count: #{@reserved_item_count.inspect}, status: #{@status.inspect}>" end |
#to_custom_created_at ⇒ Object
151 152 153 |
# File 'lib/new_store_api/models/reservation_summary_response_v2.rb', line 151 def to_custom_created_at DateTimeHelper.to_rfc3339(created_at) end |
#to_custom_expires_at ⇒ Object
155 156 157 |
# File 'lib/new_store_api/models/reservation_summary_response_v2.rb', line 155 def to_custom_expires_at DateTimeHelper.to_rfc3339(expires_at) end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
160 161 162 163 164 165 166 |
# File 'lib/new_store_api/models/reservation_summary_response_v2.rb', line 160 def to_s class_name = self.class.name.split('::').last "<#{class_name} associate_id: #{@associate_id}, created_at: #{@created_at},"\ " customer_profile_id: #{@customer_profile_id}, display_id: #{@display_id}, expires_at:"\ " #{@expires_at}, external_id: #{@external_id}, id: #{@id}, items: #{@items}, location_id:"\ " #{@location_id}, reserved_item_count: #{@reserved_item_count}, status: #{@status}>" end |