Class: NewStoreApi::ResponseCreateBookings
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- NewStoreApi::ResponseCreateBookings
- Defined in:
- lib/new_store_api/models/response_create_bookings.rb
Overview
A single booking can map to one or more packages, mapping to one or more shipments. A few examples: * One Package, outbound only: -> one booking -> one package -> one -outbound- shipment * One Package, outbound + return:
-> one booking -> one package -> one outbound shipment AND one return
shipment * Two Packages, outbound + return: -> one booking -> two packages -> for EACH PACKAGE, you will have one outbound and one return shipment. -> total of 4 shipments (2 packages * (1 outbound shipment + 1 return shipment) = 4 shipments) * Three Packages, return only:
-> one booking -> three packages -> 1 return shipment for EACH package =
3 -return- shipments You noticed that no matter the case, there is always exactly ONE booking.
Instance Attribute Summary collapse
-
#booking_id ⇒ UUID | String
TODO: Write general description for this method.
-
#bookings ⇒ Array[ResponseBookedPackageTransaction]
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(booking_id = nil, bookings = nil) ⇒ ResponseCreateBookings
constructor
A new instance of ResponseCreateBookings.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(booking_id = nil, bookings = nil) ⇒ ResponseCreateBookings
Returns a new instance of ResponseCreateBookings.
48 49 50 51 |
# File 'lib/new_store_api/models/response_create_bookings.rb', line 48 def initialize(booking_id = nil, bookings = nil) @booking_id = booking_id @bookings = bookings end |
Instance Attribute Details
#booking_id ⇒ UUID | String
TODO: Write general description for this method
24 25 26 |
# File 'lib/new_store_api/models/response_create_bookings.rb', line 24 def booking_id @booking_id end |
#bookings ⇒ Array[ResponseBookedPackageTransaction]
TODO: Write general description for this method
28 29 30 |
# File 'lib/new_store_api/models/response_create_bookings.rb', line 28 def bookings @bookings end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/new_store_api/models/response_create_bookings.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. booking_id = hash.key?('booking_id') ? hash['booking_id'] : nil # Parameter is an array, so we need to iterate through it bookings = nil unless hash['bookings'].nil? bookings = [] hash['bookings'].each do |structure| bookings << (ResponseBookedPackageTransaction.from_hash(structure) if structure) end end bookings = nil unless hash.key?('bookings') # Create object from extracted values. ResponseCreateBookings.new(booking_id, bookings) end |
.names ⇒ Object
A mapping from model property names to API property names.
31 32 33 34 35 36 |
# File 'lib/new_store_api/models/response_create_bookings.rb', line 31 def self.names @_hash = {} if @_hash.nil? @_hash['booking_id'] = 'booking_id' @_hash['bookings'] = 'bookings' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/new_store_api/models/response_create_bookings.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 |
# File 'lib/new_store_api/models/response_create_bookings.rb', line 39 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
82 83 84 85 |
# File 'lib/new_store_api/models/response_create_bookings.rb', line 82 def inspect class_name = self.class.name.split('::').last "<#{class_name} booking_id: #{@booking_id.inspect}, bookings: #{@bookings.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
76 77 78 79 |
# File 'lib/new_store_api/models/response_create_bookings.rb', line 76 def to_s class_name = self.class.name.split('::').last "<#{class_name} booking_id: #{@booking_id}, bookings: #{@bookings}>" end |