Class: NewStoreApi::RouteTo
- Defined in:
- lib/new_store_api/models/route_to.rb
Overview
Contains the fulfillment node identifier where the sales order item should be routed to (used for manual routing action).
Instance Attribute Summary collapse
-
#fulfillment_node_id ⇒ String
The fulfillment node id where the sales_order_item should be routed to.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(fulfillment_node_id = nil) ⇒ RouteTo
constructor
A new instance of RouteTo.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(fulfillment_node_id = nil) ⇒ RouteTo
Returns a new instance of RouteTo.
34 35 36 |
# File 'lib/new_store_api/models/route_to.rb', line 34 def initialize(fulfillment_node_id = nil) @fulfillment_node_id = fulfillment_node_id end |
Instance Attribute Details
#fulfillment_node_id ⇒ String
The fulfillment node id where the sales_order_item should be routed to.
15 16 17 |
# File 'lib/new_store_api/models/route_to.rb', line 15 def fulfillment_node_id @fulfillment_node_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
39 40 41 42 43 44 45 46 47 48 |
# File 'lib/new_store_api/models/route_to.rb', line 39 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. fulfillment_node_id = hash.key?('fulfillment_node_id') ? hash['fulfillment_node_id'] : nil # Create object from extracted values. RouteTo.new(fulfillment_node_id) end |
.names ⇒ Object
A mapping from model property names to API property names.
18 19 20 21 22 |
# File 'lib/new_store_api/models/route_to.rb', line 18 def self.names @_hash = {} if @_hash.nil? @_hash['fulfillment_node_id'] = 'fulfillment_node_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
30 31 32 |
# File 'lib/new_store_api/models/route_to.rb', line 30 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
25 26 27 |
# File 'lib/new_store_api/models/route_to.rb', line 25 def self.optionals [] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/new_store_api/models/route_to.rb', line 52 def self.validate(value) if value.instance_of? self return APIHelper.valid_type?(value.fulfillment_node_id, ->(val) { val.instance_of? String }) end return false unless value.instance_of? Hash APIHelper.valid_type?(value['fulfillment_node_id'], ->(val) { val.instance_of? String }) end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
71 72 73 74 |
# File 'lib/new_store_api/models/route_to.rb', line 71 def inspect class_name = self.class.name.split('::').last "<#{class_name} fulfillment_node_id: #{@fulfillment_node_id.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
65 66 67 68 |
# File 'lib/new_store_api/models/route_to.rb', line 65 def to_s class_name = self.class.name.split('::').last "<#{class_name} fulfillment_node_id: #{@fulfillment_node_id}>" end |