Class: NewStoreApi::SalesOrderListResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- NewStoreApi::SalesOrderListResponse
- Defined in:
- lib/new_store_api/models/sales_order_list_response.rb
Overview
Order history for a customer retrieved from external OMS
Instance Attribute Summary collapse
-
#orders ⇒ Array[SalesOrder]
Customer's order history.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(orders = nil) ⇒ SalesOrderListResponse
constructor
A new instance of SalesOrderListResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(orders = nil) ⇒ SalesOrderListResponse
Returns a new instance of SalesOrderListResponse.
33 34 35 |
# File 'lib/new_store_api/models/sales_order_list_response.rb', line 33 def initialize(orders = nil) @orders = orders end |
Instance Attribute Details
#orders ⇒ Array[SalesOrder]
Customer's order history
14 15 16 |
# File 'lib/new_store_api/models/sales_order_list_response.rb', line 14 def orders @orders end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/new_store_api/models/sales_order_list_response.rb', line 38 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it orders = nil unless hash['orders'].nil? orders = [] hash['orders'].each do |structure| orders << (SalesOrder.from_hash(structure) if structure) end end orders = nil unless hash.key?('orders') # Create object from extracted values. SalesOrderListResponse.new(orders) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/new_store_api/models/sales_order_list_response.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['orders'] = 'orders' @_hash end |
.nullables ⇒ Object
An array for nullable fields
29 30 31 |
# File 'lib/new_store_api/models/sales_order_list_response.rb', line 29 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 |
# File 'lib/new_store_api/models/sales_order_list_response.rb', line 24 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
64 65 66 67 |
# File 'lib/new_store_api/models/sales_order_list_response.rb', line 64 def inspect class_name = self.class.name.split('::').last "<#{class_name} orders: #{@orders.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
58 59 60 61 |
# File 'lib/new_store_api/models/sales_order_list_response.rb', line 58 def to_s class_name = self.class.name.split('::').last "<#{class_name} orders: #{@orders}>" end |