Class: NewStoreApi::StoreConfigV1Dto
- Defined in:
- lib/new_store_api/models/store_config_v1_dto.rb
Overview
StoreConfigV1Dto Model.
Instance Attribute Summary collapse
-
#auto_report_types ⇒ Array[PeriodTypeEnum]
List of periodic report types that should be closed automatically before the first transaction in the next period.
-
#report_types ⇒ Array[PeriodTypeEnum]
List of supported periodic report types.
-
#timezone ⇒ TimezoneEnum
List of supported periodic report types.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(auto_report_types = nil, report_types = nil, timezone = nil) ⇒ StoreConfigV1Dto
constructor
A new instance of StoreConfigV1Dto.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(auto_report_types = nil, report_types = nil, timezone = nil) ⇒ StoreConfigV1Dto
Returns a new instance of StoreConfigV1Dto.
44 45 46 47 48 |
# File 'lib/new_store_api/models/store_config_v1_dto.rb', line 44 def initialize(auto_report_types = nil, report_types = nil, timezone = nil) @auto_report_types = auto_report_types @report_types = report_types @timezone = timezone end |
Instance Attribute Details
#auto_report_types ⇒ Array[PeriodTypeEnum]
List of periodic report types that should be closed automatically before the first transaction in the next period.
15 16 17 |
# File 'lib/new_store_api/models/store_config_v1_dto.rb', line 15 def auto_report_types @auto_report_types end |
#report_types ⇒ Array[PeriodTypeEnum]
List of supported periodic report types.
19 20 21 |
# File 'lib/new_store_api/models/store_config_v1_dto.rb', line 19 def report_types @report_types end |
#timezone ⇒ TimezoneEnum
List of supported periodic report types.
23 24 25 |
# File 'lib/new_store_api/models/store_config_v1_dto.rb', line 23 def timezone @timezone end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/new_store_api/models/store_config_v1_dto.rb', line 51 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. auto_report_types = hash.key?('auto_report_types') ? hash['auto_report_types'] : nil report_types = hash.key?('report_types') ? hash['report_types'] : nil timezone = hash.key?('timezone') ? hash['timezone'] : nil # Create object from extracted values. StoreConfigV1Dto.new(auto_report_types, report_types, timezone) end |
.names ⇒ Object
A mapping from model property names to API property names.
26 27 28 29 30 31 32 |
# File 'lib/new_store_api/models/store_config_v1_dto.rb', line 26 def self.names @_hash = {} if @_hash.nil? @_hash['auto_report_types'] = 'auto_report_types' @_hash['report_types'] = 'report_types' @_hash['timezone'] = 'timezone' @_hash end |
.nullables ⇒ Object
An array for nullable fields
40 41 42 |
# File 'lib/new_store_api/models/store_config_v1_dto.rb', line 40 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
35 36 37 |
# File 'lib/new_store_api/models/store_config_v1_dto.rb', line 35 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
74 75 76 77 78 |
# File 'lib/new_store_api/models/store_config_v1_dto.rb', line 74 def inspect class_name = self.class.name.split('::').last "<#{class_name} auto_report_types: #{@auto_report_types.inspect}, report_types:"\ " #{@report_types.inspect}, timezone: #{@timezone.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
67 68 69 70 71 |
# File 'lib/new_store_api/models/store_config_v1_dto.rb', line 67 def to_s class_name = self.class.name.split('::').last "<#{class_name} auto_report_types: #{@auto_report_types}, report_types: #{@report_types},"\ " timezone: #{@timezone}>" end |